﻿PROC GLOBAL
set explicit;
{ Working variables -- check the lengths needed for all fields }
alpha(32) CSPro;					{ CSPro executables directory }
alpha(99) proj;						{ project directory name }
alpha(8)  app, dic;					{ application name and dictionary name }
alpha(8)  opid;						{ operator ID }
alpha(2)  datakey;	                { !!! NETWORK !!! make sure length of variable to store transfer drive is long enough }
alpha(2)  wrkdrv, netdrv;           { length of var to store workdrive letters, e.g. "C:","F:" }
alpha(99) wrkprj, data, veri, entry, dicts;        	{ data entry machine directories }
alpha(99) netprj, netdat, netver, netent, netdic;	{ suervisor machine directories }
alpha(99) fname, fnameN;			{ auxiliary filenames for main, and network version of main }
alpha(3)  xcluster;                 { !!! CLUSTER !!! make sure length is correct }
alpha(2)  fcodes;                   { file codes - M = Main, V = Verification }

numeric always, choice, chkok, err, keychoice;

file pfffile mdata vdata jstone state;

{ ---------------------------------------------------------------------------- }

function chkdir(alpha(99) xdir)
  if fileexist(xdir) <> 1 then
{+EN} errmsg( "Directory %s does not exist", {EN+}
{{ES} errmsg( "El directorio %s no existe" , {ES}}
{{FR} errmsg( "Répertoire %s n'exist pas"  , {FR}}
              xdir );
    stop(-1);
  endif;
end;

function chkexist(addmode,mainver)
  chkok = 1;
  if mainver = 1 then {if main data}
    if !fileexist(mdata) & !addmode then {main data doesn't exist and in modify mode}
  {+EN} errmsg("Main data file for cluster %s does not exist  - use Option %s",xcluster,"A");            {EN+}
  {{ES} errmsg("Archivo principal para el cluster %s no existe  - use Opcion %s",xcluster,"A");          {ES}}
  {{FR} errmsg("Fichier saisie principale grappe %s n'existe pas  - utiliser l'option %s",xcluster,"A"); {FR}}
        chkok = 0;
    elseif !fileexist(mdata) & fileexist( concat(strip(netdat), "\", fcodes[mainver:1], xcluster, ".dat" ) ) then
  {+EN} errmsg("Main data file for cluster %s does not exist, but is already on the network - Request Superevisor to check",xcluster);{EN+}
  {{ES} errmsg("Archivo principal para el cluster %s no existe, pero ya es en cadena - consulte con el Superevisor",xcluster);{ES}}
  {{FR} errmsg("Fichier saisie principale grappe %s n'existe pas, mais il exist deja sur le reseau - Prévenez votre superviseur",xcluster);{FR}} 
       chkok = 0;
    endif;
  else {if verification data}
    if !fileexist(vdata) & !addmode then {verification data doesn't exist and in modify mode}
  {+EN} errmsg("Verification data file for cluster %s does not exist  - use Option %s",xcluster,"R");         {EN+}
  {{ES} errmsg("El archivo de datos verificados para el cluster %s no existe  - use Opcion %s",xcluster,"R"); {ES}}
  {{FR} errmsg("Fichier verification de la grappe %s n'existe pas  - utuliser l'option %s",xcluster,"R");     {FR}}
      chkok = 0;
    endif;
    if chkok then {if verification data file exists on this machine...}
      if fileexist(mdata) then {...AND main data file exists on this machine}
    {+EN} errmsg("Cluster %s can not be verified in this machine",xcluster);                   {EN+}
    {{ES} errmsg("El Cluster %s no puede ser verificado en esta maquina",xcluster);            {ES}}
    {{FR} errmsg("Grappe %s ne peut pas etre verifiee dans cette sur cette machine",xcluster); {FR}}
        chkok = 0; {prevent data entry}
      endif;
    endif;
  endif;
  chkexist = chkok;
end;

function backupf(mainver)
  if wrkprj <> netprj then
    if FileExist( netprj ) then        { still connected to network }
      fname = concat( fcodes[mainver:1], xcluster, ".dat" );
      if filesize( concat(strip(data), "\", strip(fname))) = 0 then
    {+EN} errmsg("Data file %s for cluster %s is empty - File will not be backed up to server",strip(fname),xcluster); {EN+}
    {{ES} errmsg("Porcentajes de archivo de datas %s para el cluster %s es vacio - Archivo no va a ser apoyado en el servidor",strip(fname),xcluster); {ES}}
    {{FR} errmsg("Ficher de donnees %s de la grappe %s est vide - le fichier ne sera pas sauvegarde sur le serveur",strip(fname),xcluster); {FR}}
      else
        if mainver = 1 then { if the main data }
          FileCopy( concat(strip(data), "\", strip(fname)), concat(strip(netdat), "\", strip(fname)) );
          FileDelete( concat(strip(netdat), "\", strip(fname), ".idx") );   { Delete index files - if they exist }
        else
          FileCopy( concat(strip(veri), "\", strip(fname)), concat(strip(netver),"\", strip(fname)) );
          { index file is required for verification purposes }
          fname = concat( fcodes[mainver:1], xcluster, ".dat.idx" );
          FileCopy( concat(strip(veri), "\", strip(fname)), concat(strip(netver),"\", strip(fname)) );
        endif;
      endif;
    else
      { Computer was disconnected from the network }
{+EN} errmsg( "!!! ALERT Computer disconnected from the network, check with your SUPERVISOR" ); {EN+}
{{ES} errmsg( "!!! ERROR El computador está desconectado de la red, chequee con el SUPERVISOR" ); {ES}}
{{FR} errmsg( "!!! ALERTE Ordinateur déconnecté du réseau, vérifiez avec votre SUPERVISEUR" ); {FR}}
{+EN} errmsg( concat( "Use option %s to transfer main data using data key\n",
                      "or option %s to transfer verification data using data key" ), {EN+}
{{ES} errmsg( concat( "Use la opcion %s para transferir los datos maestros usando clave des datos\n",
                      "o la opcion %s para transferir los datos verificados usando clave de datos" ), {ES}}
{{FR} errmsg( concat( "Utilisez l'option %s pour transférer les données principales en utilisant un clé de données\n",
                      "ou l'option %s pour transférer les données de vérification en utilisant un clé de données" ), {FR}}
                      "T", "V" );
    endif;
  endif;
end;

function genpff(addmode,mainver)
  { set pff file name }
  setfile(pfffile,concat(strip(entry), "\", strip(app), ".pff"));
  filecreate(pfffile);
  filewrite(pfffile, "[Run Information]");
  filewrite(pfffile, "Version=CSPro 5.0");
  filewrite(pfffile, "AppType=Entry");
  filewrite(pfffile, "");
  filewrite(pfffile, "[DataEntryInit]");
  filewrite(pfffile, concat("OperatorID=", strip(opid)));
  if addmode then
    filewrite(pfffile, "StartMode=ADD");
    filewrite(pfffile, "Lock=Verify");
    filewrite(pfffile, "Fullscreen=Yes");
  else
    { no StartMode for modify }
    filewrite(pfffile, "Lock=Add,Verify");
  endif;
  filewrite(pfffile, "NoFileOpen=Yes");
  filewrite(pfffile, "");
  filewrite(pfffile, "[Files]");
  filewrite(pfffile, concat("Application=", strip(entry), "\", strip(app), ".enc"));
  if mainver = 1 then
    filewrite(pfffile, concat("InputData=", strip(data), "\", fcodes[mainver:1], xcluster, ".DAT"));
  else
    filewrite(pfffile, concat("InputData=", strip(veri), "\", fcodes[mainver:1], xcluster, ".DAT"));
  endif;
  filewrite(pfffile, "");
  filewrite(pfffile, "[Parameters]");
  filewrite(pfffile, concat("Parameter=", xcluster));
  close(pfffile);
end;

function runpff();
  { Using single quotes instead of double quotes as double quotes are needed in the string generated }
  Execsystem(concat('"', strip(CSPro), '\CSEntry.exe" ',
                    strip(entry), "\", strip(app), '.pff'),
             maximized,wait);
end;

function csrun(addmode,mainver)
  if chkexist(addmode,mainver) then
    genpff(addmode,mainver);
    runpff();
    backupf(mainver);
  endif;
end;

{ copy data to data key/flash disk to transfer to supervisor machine }
{ to be used when a network is not available }
function transfer( mainver )
  if chkexist( 0, mainver ) then
    keychoice = accept(
{+EN}     "Insert data key and select drive",					{EN+}
{{ES}     "Coloque clave de datos y selecionar el puerto",		{ES}}
{{FR}     "Insérez le clé de données et selectionner l'unité",	{FR}}
          "E:","F:","G:","H:","I:");
    if keychoice then
      datakey = concat( "EFGHI"[keychoice:1],":" );
      fname = concat( fcodes[mainver:1], xcluster, ".dat" );
      if fileexist( concat(strip(datakey), "\", strip(fname)) ) then
{+EN}   errmsg( "*** Cluster %s already exists on drive %s -- Please check",				{EN+}
{{ES}   errmsg( "*** El conglomerado % existe en el puerto %s -- Revise por favor",			{ES}}
{{FR}   errmsg( "*** Grappe %s existe déjà dans le lecteur %s -- Veuillez vous en assurer",	{FR}}
                xcluster, strip(datakey) );
      endif;
      filecopy( concat(strip(data), "\", strip(fname)), concat(strip(datakey), "\", strip(fname)) );
{+EN} errmsg( "Copying data files for cluster %s to data key",						{EN+}
{{ES} errmsg( "Copiando los datos para el conglomerado %s a clave de datos",		{ES}}
{{FR} errmsg( "Copie des fichiers de données de la grappe %s à un clé de données",	{FR}}
              xcluster );
      if fileexist( concat(strip(datakey), "\", strip(fname)) ) then
{+EN}   errmsg( "*** Cluster %s copied to drive %s",				{EN+}
{{ES}   errmsg( "*** El conglomerado % copiando en el puerto %s",	{ES}}
{{FR}   errmsg( "*** Grappe %s a copié dans l'unité %s",			{FR}}
                xcluster, strip(datakey) );
      else
{+EN}   errmsg( "*** Cluster %s not copied to drive %s",					{EN+}
{{ES}   errmsg( "*** El conglomerado % no esta copiando en el puerto %s",	{ES}}
{{FR}   errmsg( "*** Grappe %s ne copié pas dans l'unité %s",				{FR}}
                xcluster, strip(datakey) );
      endif;
    endif;
  else
{+EN} errmsg( "Data files for cluster %s not found",					{EN+}
{{ES} errmsg( "Los datos para el conglomerado %s non existant",			{ES}}
{{FR} errmsg( "Le fichiers de données de la grappe %s non trouvées",	{FR}}
              xcluster );
  endif;
end;

{ Copy all files needed in the client from the server to execute data entry }
function CopyFromServer()
  { copies files related to the data entry application }
  FileCopy( concat(strip(netent), "\", strip(app), ".enc"), concat(strip(entry), "\", strip(app), ".enc") );
  FileCopy( concat(strip(netent), "\Entry_menu.enc"), concat(strip(entry), "\Entry_menu.enc") );
end;

PROC ENTER_FF
preproc

{ The following directories are assumed }
{ \MICS4        Main survey directory (some files located here)}
{ \MICS4\ENTRY  Data entry programs located here               }
{ \MICS4\DICTS  Directory used to store dictionaries           }
{ \MICS4\DATA   Directory used to store data                   }
{ \MICS4\VERI   Directory used to store verification data      }

CSPro  = "C:\Program Files\CSPro 5.0";		{ CSPro directory }
proj   = "MICS5\CSPro";						{ Project directory }
{ proj   = "Projects\UNICEF\MICS4\DP\MICS4\CSPro"; { for testing } }
app    = "ENTRY";							{ Entry application name }
dic    = "MICS5";							{ Dictionary name }
opid   = "MICS5";							{ Operator ID }
datakey= "E:";								{ Transfer drive for data key }
fcodes = "MV";								{ File codes - M = Main, V = Verification,) }
wrkdrv = "C:";								{ Set work drive }
wrkprj = concat(strip(wrkdrv), "\", strip(proj));	{ Project directory }
data   = concat(strip(wrkprj), "\DATA");	{ Main data directory }
veri   = concat(strip(wrkprj), "\VERI");	{ Verification data directory }
entry  = concat(strip(wrkprj), "\ENTRY");	{ Entry programs directory name }
dicts  = concat(strip(wrkprj), "\DICTS");	{ Dictionry directory name }

{ Check that all directories needed exist }
chkdir(wrkprj);
chkdir(entry);
chkdir(data);
chkdir(veri);

{ !!! NETWORK !!! Set network drive letter to the drive to use }
netdrv = "F:";
  { Alternatively the following form can be used }
  { netdrv="\\supervisorcomputer\sharename";     }
  { if no network, use local directories         }
  
netprj = concat( strip(netdrv), "\", strip(proj) );		{ Can change this to a different structure if desired }
{ For testing - use C:\MICS4\NETWORK\CSPro }
  netdrv = "C:";
  netprj = concat( strip(netdrv), "\MICS5\NETWORK" );
{ if no network, use local directories }
if !fileexist( strip(netprj) ) then
  {+EN} errmsg("Network directory %s does not exist using work directory %s", strip(netprj), strip(wrkprj)); {EN+}
  {{ES} errmsg("PREVESTI!!!!!!!!!!!", strip(netprj), strip(wrkprj)); {ES}}
  {{FR} errmsg("Repertoire de reseau %s n'exist pas. Utilisant repertoire de travail %s", strip(netprj), strip(wrkprj)); {FR}}
  netdrv = wrkdrv;
  netprj = wrkprj;
endif;

{ Set network drive directories }
netent = concat( strip(netprj), "\ENTRY" );
netdat = concat( strip(netprj), "\DATA" );
netver = concat( strip(netprj), "\VERI" );

{ Copy network programs and data to client machine }
if strip(netprj) <> strip(wrkprj) then
  { Check that all directories needed exist }
  chkdir(netprj);
  chkdir(netent);
  chkdir(netdat);
  chkdir(netver);
  { Copy latest files from server }
  CopyFromServer();
endif;

{ create the file name variable justone}
setfile(jstone,concat(strip(wrkprj),"\justone.txt"));

{ Check that there are not two concurrent sessions of CSPro loaded at the same time }
if fileexist(jstone) then
  errmsg(
{+EN}     "There is another session running or the computer crashed while running"                       {EN+}
{{ES}     "Hay otra sesión corriendo o el computador falló mientras corría"                              {ES}}
{{FR}     "Il y a une autre session en cours ou bien que l'ordinateur s'est planté en cours d'exécution" {FR}}
        );
  if accept(
{+EN}        "Reset","Yes","No"           {EN+}
{{ES}        "Reiniciar","Si","No"        {ES}}
{{FR}        "Re-initialiser","Oui","Non" {FR}}
           ) = 1 then
    filedelete(jstone)
  else
    stop(-1);
  endif;
endif;

filewrite( jstone,
{+EN}      "There is another session running or the computer crashed while running"                       {EN+}
{{ES}      "Hay otra sesión corriendo o el computador falló mientras corría"                              {ES}}
{{FR}      "Il y a une autre session en cours ou bien que l'ordinateur s'est planté en cours d'exécution" {FR}}
         );
close( jstone );

PROC ENTER_LEVEL
preproc
{ Get the cluster, supervisor and interviewer numbers if already used before }
setfile( state, concat( strip(entry), "\cluster.txt" ) );
if fileexist(state) then
  fileread( state, xcluster );
  ecluster = tonumber(xcluster);
endif;

PROC ECLUSTER
{ !!! CLUSTER !!! check that cluster entered is valid }
recode ecluster => err;
        001-800 => 0;    { Give list of valid cluster numbers }
                => 1;
endrecode;

{ !!! CLUSTER !!! check length of edit pattern matches length of largest cluster number }
xcluster = edit("999",$);

if err then
{+EN} errmsg( "*** Cluster %s not valid", {EN+}
{{ES} errmsg( "*** Archivo '%s' no valide", {ES}}
{{FR} errmsg( "*** Grappe numéro %s non valide", {FR}}
              xcluster );
  reenter;
endif;


setfile(state, concat( strip(entry), "\cluster.txt" ), create);
filewrite(state, xcluster);

{ set cluster data file names }
setfile(mdata,concat(strip(data), "\", fcodes[1:1], xcluster, ".DAT"));
setfile(vdata,concat(strip(veri), "\", fcodes[2:1], xcluster, ".DAT"));

always = 1;
while always do   { loop forever }
  { Get the selected option }
{+EN}
  choice = accept(  "Data entry menu options",
                    "A  Add data to the data file....................A",
                    "M  Modify the data file.........................M",
                    "T  Transfer data ...............................T",
                    "-------------------------------------------------",
                    "R  Re-enter data for verification...............R",
                    "U  Update verification data.....................U",
                    "V  Transfer verification data...................V",
                    "-------------------------------------------------",
                    "N  New cluster number...........................N",
                    "Q  Quit.........................................Q");
{EN+}         
{{ES}
    choice = accept( "Opciónes del menu de entrada de datos",
                     "A  Agregar datos al archivo de datos...........A",
                     "M  Modificar el archivo de datos...............M",
                     "T  Transferir datos............................T",
                     "------------------------------------------------",
                     "R  Reingresar datos para verificaci¢n..........R",
                     "U  Actualizar datos verificados................U",
                     "V  Transferir datos verificados ...............V",
                     "------------------------------------------------",
                     "N  Nuevo número de conglomerado................N",
                     "Q  Salir.......................................Q" );
{ES}}
{{FR}
    choice = accept( "Options du menu de saisie de données",
                     "A  Ajouter de nouvelles données au fichier.....A",
                     "M  Modifier le fichier de données..............M",
                     "T  Transférer les données .....................T",
                     "------------------------------------------------",
                     "R  Re-saisir les données pour la vérification..R",
                     "U  Modifier les données de vérification........U",
                     "V  Transférer le fichier de vérification.......V",
                     "------------------------------------------------",
                     "N  Nouveau numéro de grappe....................N",
                     "Q  Quitter.....................................Q" );
{FR}}               
      if choice =  0 then {ESC} reenter; { escape from menu & allow entry of new cluster number }
  elseif choice =  1 then {ADD} csrun(1,1); {Main}
  elseif choice =  2 then {MOD} csrun(0,1); {Main}
  elseif choice =  3 then Transfer(1);		{Main}
  elseif choice =  4 then {---} { do nothing }
  elseif choice =  5 then {ADD} csrun(1,2); {Verification}
  elseif choice =  6 then {MOD} csrun(0,2); {Verification}
  elseif choice =  7 then Transfer(2);		{Verification}
  elseif choice =  8 then {---} { do nothing }
  elseif choice =  9 then {NEW} reenter; { get the new cluster number }
  elseif choice = 10 then {QUIT}
    if fileexist(jstone) then
      filedelete(jstone);
    endif;
    stop(-1);       { quit the process }
  endif;
enddo;
