﻿* Call include file for the working directory and the survey name.
include "surveyname.sps".

get file = "hh.sav"
  /keep hh1 hh2 team.
sort cases by hh1 hh2.
save outfile = "tmpteam.sav".


get file = 'hl.sav'.
sort cases by hh1 hh2 hl1.

save outfile = 'tmp.sav' /keep hh1 hh2 hl1 hl4 hl6 /rename (hl1=hl15) (hl4=ctsex) (hl6=ctage).

* Choose only the children under 5.
select if (hl6 >= 0 and hl6 <= 4).

* Sort data according to caretaker's line number.
sort cases by hh1 hh2 hl15.
* Add sex of caretaker to household listing file.
match files
  /file = *
  /table = 'tmp.sav'
  /by HH1 HH2 HL15.

* Add supervisors number to household listing file.
match files
  /file = *
  /table = 'tmpteam.sav'
  /by HH1 HH2.

compute mother = 0.
if (hl12 > 0) mother = 100.

compute inter = 0.
if (hl15 = hl12) inter = 100.

variable labels mother "Who live in the same household with their mothers".
variable labels inter "Whose mothers were interviewed".

compute layer = 1.
variable labels layer " ".
value labels layer 1 "Percentage of children under five:".
	
compute total = 1.
variable labels total "".
value labels total 1 "Number of completed under-5 questionnaires".

compute tot1 = 100.
variable label tot1  "Total".
value label tot1 100 "".

ctables
  /vlabels variables  = total layer display = none
  /table total[c] + team[c] by layer [c] > (mother[s][mean,'',f5.1] + inter[s][mean,'',f5.1]) + total [c][count,'',f5.0]
  /categories var = all empty = exclude missing = exclude
  /slabels visible = no
  /titles title=
    "F5. Respondent to the under-5 questionnaire" 
    "Percentage of children under 5 who live in the same household with their mother, percentage of children whose mothers were interviewed for the under-5 questionnaire, and proportion of mothers who were interviewed, "+
    "according to interviewer team" + surveyname.

new file.
erase file 'tmp.sav'.
erase file 'tmpteam.sav'.

