﻿* Call include file for the working directory and the survey name.
include "surveyname.sps".

* Observation of bednets.
get file = "hh.sav"
  /keep hh1 hh2 team.
sort cases by hh1 hh2.
save outfile = "tmp.sav".

get file = "tn.sav".
match files / file = *
 /table = 'tmp.sav'
 /by hh1 hh2.

compute obs = 0.
if (tn4 = 1) obs = 100.
variable labels obs "Percent of bednets observed by interviewer".

compute total = 1.
variable labels total " ".
value label total 1 "Total number of bednets".

compute tot = 1.
variable labels tot "Total".
value labels tot 1 " ".

aggregate 
  /outfile = "tmp1.sav"
  /break = team
  /mobs = mean (obs).

aggregate 
  /outfile = "tmp2.sav"
  /break = tot2
  /mobs = mean (obs).

* Add this summary information .
get file = 'tmp.sav'.
add files
  /file = *
  /file = 'tmp1.sav'
  /file = 'tmp2.sav'.

* target should be set to 90 - at least 90% of nets should be seen.
do if (mobs < 90).
+ compute target = mobs.
end if.

* to calculate correct number of women exclude temporarily generated cases needed for calculation of target reached.
do if (sysmis (mobs)).
+ compute tnn = 1.
end if.

variable labels target "Target not met".

variable labels tnn = " ".
value labels tnn 1 "Total number of bednets".

ctables
  /vlabels variables = total display = none
  /table tot [c]  + team [c] by  
	mobs [s] [mean,'' ,f7.1] + tnn [c][count,'',f5.0] + target [s] [mean,'' ,f7.1]
  /categories var= all empty = exclude
  /slabels visible = no 
  /titles title="F9D. Observation of bednets"  
	"Percentage of bednets in all households observed by the interviewers, " + surveyname.

new file.

erase file = "tmp.sav".						
erase file = "tmp1.sav".
erase file = "tmp2.sav".	

* Observations of places for handwashing.

get file = 'hh.sav'.

select if (HH9 = 1).

recode hw1 (1=100)(else=0) into hwash1.
recode hw1 (2=100)(else=0) into hwash2.
recode hw1 (3=100)(else=0) into hwash3.
recode hw1 (6=100)(else=0) into hwash4.
variable labels hwash1 "Percent of households where place for handwashing was observed".
variable labels hwash2 "Place for handwashing not in the dwelling, plot or yard".
variable labels hwash3 "No permission to see place for handwashing".
variable labels hwash4 "Other".

compute total = 1.
variable labels total " ".
value labels total 1 "Number of households".

compute tot1 = 100.
variable labels tot1 "Total".
value labels tot1 100 " ".

compute tot2 = 1.
variable labels tot2 "Total".
value labels tot2 1 " ".

save outfile = "tmp.sav".

aggregate 
  /outfile = "tmp1.sav"
  /break = team
  /hwash1m = mean (hwash1).

aggregate 
  /outfile = "tmp2.sav"
  /break = tot2
  /hwash1m = mean (hwash1).

* Add this summary information .
get file = 'tmp.sav'.
add files
  /file = *
  /file = 'tmp1.sav'
  /file = 'tmp2.sav'.

* target should be set to 99 - at least 99% of handwashing places should be seen.
do if (hwash1m < 90).
+ compute target = hwash1m.
end if.

do if (sysmis (hwash1m)).
+ compute hhn = 1.
end if.

variable labels target "Target not met".

variable labels hhn = " ".
value labels hhn 1 "Number of households".

ctables
  /vlabels variables = total display = none
  /table  tot2 [c] + team [c]  by  
	hwash1 [s] [mean,'' ,f7.1] + hwash2 [s] [mean,'' ,f7.1] + hwash3 [s] [mean,'' ,f7.1] + hwash4 [s] [mean,'' ,f7.1] + hhn [c][count,'',f5.0] + target [s] [mean,'' ,f7.1]
  /categories var= all empty = exclude
  /slabels visible = no 
  /titles title="F9D. Observation of places for hand washing"  
	"Percentage of places for handwashing observed by the interviewer in all interviewed households, according to interviewer team" + surveyname.

new file.	

erase file = "tmp.sav".						
erase file = "tmp1.sav".
erase file = "tmp2.sav".		


