﻿PROC GLOBAL
{+------------------------------------------------------------------------------------------------+}
{+                                                                                                +}
{+  Maternal Mortality                                                     30-Nov-2012            +}
{+                                                                                                +}
{+  RH.17A    Adult mortality rates                                                               +}
{+  RH.17B    Adult mortality probabilities                                                       +}
{+  RH.17     Maternal mortality (results are presented in tables RH.17 and RH.17C)               +}
{+  DQ.20     Completeness of information on siblings                                             +}
{+  DQ.20W    Completeness of Information for dead sisters                                        +}
{+  DQ.21     Sibship size and sex ratio of siblings                                              +}
{+                                                                                                +}
{+  WORKING TABLES                                                                                +}
{+                                                                                                +}
{+  F1W     Fertility rates                                                                       +}
{+  MMTW    Maternal Mortality Rates for Five Years Preceding the Survey                          +}
{+  AMFW    Female adult mortality rates                                                          +}
{+  AMMW    Male adult mortality rates                                                            +}
{+                                                                                                +}
{+  Notes:  Working tables are not printed by default and they are tallyed for seven different    +}
{+          periods.  If analysts request to look at them, just delete the NOPRINT command in     +}
{+          the PRM file.  Analysts may also want to to publish a different period.  In this      +}
{+          case just change the code for variable PIDX to the appropriate layer as defined in    +}
{+          level 0 postproc.  Keep in mind that in this case the title needs to be adjusted      +}
{+          to the corresponding period                                                           +}
{+                                                                                                +}
{+          Tables RH.17A, RH.17B and RH17 are consructed from working tables F1W, MMTW,          +}
{+          AMF and AMM in level 0 postproc                                                       +}
{+                                                                                                +}
{+------------------------------------------------------------------------------------------------+}

  set explicit;

  numeric i, j, k, p, x, y, z, imax, itot, kmin, kmax, kextra;
  numeric itot1, itot2, itot3, jtot, death, expo, pidx;
  numeric emsample, awfactor;
  numeric percntn, percntx, xyd, xad;
  numeric rate, ratei, qx, probd, prmr;
  numeric higcm, lowcm, higage, higexp, lowexp, rweight;
  numeric xpreg, totexp, oldcm, newcm, rwt;
  numeric intc;

  array upplim(20);      { months before survey for upper period limit }
  array lowlim(20);      { months before survey for lower period limit }

  crosstab float(0) txxx unweight runday+runmonth+runyear
    exclude(specval, rowzero, colzero, totals, percents)
    title( "Maternal Mortality Tables, Country, Year" );

  crosstab float(3) tmm1  gage+tot1549, mort, isex
    exclude(rowzero,colzero,percents,totals,specval)
    title( "RH.17A: Adult mortality rates","",
           "Direct estimates of female and male mortality rates for the seven",
           "years preceding the survey, by five-year age groups, Country, Year" )
    stub( "Age" );
    
  crosstab float(0) tmm2 rowtmm2, isex*coltmm2
    exclude(rowzero,colzero,specval,totals,percents)
    title( "RH-17B: Adult mortality probabilities", "",
           "The probability of dying between the ages of 15 and 50 for women and",
           "men for the seven years preceding the survey, Country, Year" )
    stub( "Survey" );
        
  crosstab float(0) tmm31 gage+tot1549 coltmm3
    exclude(rowzero,colzero,specval,totals,percents)
    title( "Table RH.17: Maternal mortality	","",
	          "Direct estimates of maternal mortality for the 0-6 years preceding the survey",
           ", Country, Year" )
    stub( "Age" );
  crosstab float(0) tmm32 rowtmm3 estimate
    exclude(rowzero,colzero,specval,totals,percents)
    title( "Table RH.17C  Maternal mortality (Continuation)","",
	          "This table must be appended to the previous table (RH.17) for publication purposes,",
           "Country, Year" )

  crosstab float(1) tc8 rowc8 colc8a+colc8b+colc8c
    exclude(rowzero,colzero,specval,totals,percents)
    title( "DQ.20  Completeness of Information on Siblings","",
           "Completeness of data on survival status of sisters and brothers reported by interviewed women, ",
           "age of living siblings and age at death (AD) and years since death (YSD) of dead siblings",
           "(unweighted), Country, Year" );

  crosstab float(1) tmw rowmw colmw
    exclude(rowzero,colzero,specval,totals,percents)
    title( "DQ.20W  Completeness of information for dead sisters","",
           "Percentage of sisters who died at ages 15-49 with information missing on",
           "whether or not the death was maternal (unweighted), Country, Year" );

  crosstab float(1) tc9 v013w+total colc9
    exclude(rowzero,colzero,specval,totals,percents)
    title( "DQ.21 Sibship size and sex ratio of siblings","",
           "Mean sibship size and sex ratio of siblings at birth, Country, Year" )
     stub( "Age of respondents" );
  crosstab float(1) tc9w v013w+total colc9w
    exclude(rowzero,colzero,specval,totals,percents)
    noprint;

  crosstab float(3) agedis   gage+tot1549+general, totalp
    exclude(rowzero,colzero,percents,totals,specval)
    title( "Respondent's age distribution used to adjust fertility (f1w) ",
           "and mortality tables (mmtw), Country, Year" );

  crosstab float(3) f1w   gage+tot1549+general, fert, periods
    exclude(rowzero,colzero,percents,totals,specval)
    title( "F1W: Total Fertility","",
           "Total fertility rate for different periods prior to the survey",
           "by age,  Country, Year" );

  crosstab float(3) mmtw   gage+tot1549+general, mort, periods
    exclude(rowzero,colzero,percents,totals,specval)
    title( "MMTW: Maternal Mortality Rates,","",
           "Maternal mortality rates for different periods prior to the survey",
           "by age,  Country, Year" );

  crosstab float(3) amfw  gage+tot1549, mort, periods
    exclude(rowzero,colzero,percents,totals,specval)
    title( "AMFW. Adult mortality rates for women","",
           "Adult mortality rates for women for the different periods prior to the survey",
           "by age, Country, Year" );

  crosstab float(3) ammw  gage+tot1549, mort, periods
    exclude(rowzero,colzero,percents,totals,specval)
    title( "AMMW. Adult mortality rates for men","",
           "Adult mortality rates for men for different periods prior to the survey",
           "by age,  Country, Year" );

  { valid values for a two digits variable }
  Function valid(xvar);
    valid = (!special(xvar) & xvar <= 96)
  end;

  { valid values for a four digits year variable }
  function validyr(xvar);
    validyr = (!special(xvar) & xvar <= 9996)
  end;

PROC MICS4_FF
preproc

  { initalize for different periods for adult and maternal mortality }
  upplim(1) = 1;    {  0 *  12 + 1 }
  lowlim(1) = 84;   {  6 *  12 +12 }
  upplim(2) = 85;   {  7 *  12 + 1 }
  lowlim(2) = 168;  { 13 *  12 +12 }
  upplim(3) = 1;    {  0 *  12 + 1 }
  lowlim(3) = 168;  { 13 *  12 +12 }
  upplim(4) = 1;    {  0 *  12 + 1 }
  lowlim(4) = 120;  {  9 *  12 +12 }
  upplim(5) = 1;    {  0 *  12 + 1 }
  lowlim(5) = 60;   {  4 *  12 +12 }
  upplim(6) = 61;   {  5 *  12 + 1 }
  lowlim(6) = 120;  {  9 *  12 +12 }
  upplim(7) = 121;  { 10 *  12 + 1 }
  lowlim(7) = 180;  { 14 *  12 +12 }
  percntn   = 1;
  percntx   = 7;    { number of analysis periods }

  total     = 0;
  estimate  = 0;
  totalp    = 0;

  pidx      = 0;    { 0 -> 0-6   }
                    { 1 -> 7-13  }
                    { 2 -> 0-13  }
                    { 3 -> 0-9   }
                 	{ 4 -> 0-4   }
		            { 5 -> 5-9   }
		            { 6 -> 10-14 }

  emsample = 0;	    { Ever married sample = 1, All woman sample	= 0 }

  unweight = ( sysparm()[1:1] = "U" );   { 0-Weighted, 1-unweighted }

postproc

  { constructs table to determine whether run is weighted/unweighted }
  txxx(unweight,0) = sysdate( "dd" );      { day   }
  txxx(unweight,1) = sysdate( "mm" );      { month }
  txxx(unweight,2) = sysdate( "yyyy" );    { year  }

  { processing table AGEDIS }
  { note that imax is used in the post-processing of all }
  { remaining tables where adjustment by age is needed   }
  imax = tblrow( agedis, gage );
  itot = imax + 2;
  agedis[itot,0] = tblsum( row agedis[0:imax,0] );
  do i = 0 while i <= imax
    agedis(i,1) = agedis(i,0) / agedis(itot,0);
  enddo;
  agedis[itot,1] = tblsum( row agedis[0:imax,1] );

  { processing table F1W }
  { age-specfic and general fertility rate }
  f1w[*,1,*] = f1w[*,1,*]/12;
  f1w[imax+1,*,*] = tblsum( row f1w[0:imax,*,*] );
  f1w[*,2,*] = f1w[*,0,*]/f1w[*,1,*];
  { adjustments to fertility rates }
  {  7-13 adjustment }
  f1w(imax,2,1)   = f1w(imax-1,2,1)/f1w(imax-1,2,0)*f1w(imax,2,0);
  f1w(imax,2,5)   = f1w(imax,2,4);                            {  5- 9 adjustment }
  f1w(imax-1,2,6) = f1w(imax-1,2,5);                          {  5- 9 adjustment }
  f1w(imax,2,6)   = f1w(imax,2,4);                            { 10-14 adjustment }
  { total fertility rate calculations }
  f1w[itot,*,*] = default;
  do k = 0 while k < percntx
    f1w[itot,2,k] = tblsum( row f1w[0:imax,2,k] );
  enddo;
  f1w[itot,2,*] = 5*f1w[itot,2,*];
  { adjustment by age distribution     }
  do i = 0 while i <= imax
    do k = 0 while k < percntx
      f1w[i,3,k] = f1w[i,2,k] * agedis[i,1];
    enddo;
  enddo;
  do k = 0 while k < percntx
    f1w[imax+1,3,k] = tblsum( row f1w[0:imax,3,k] );
  enddo;
  f1w[itot,3,*]   = default;

  { processing table mmtw }
  { Maternal mortality rate }
  mmtw[*,1,*]      = mmtw[*,1,*]/12;
  mmtw[imax+1,*,*] = tblsum( row mmtw[0:imax,*,*] );
  mmtw[*,2,*]      = 1000*mmtw[*,0,*]/mmtw[*,1,*];
  mmtw[itot,*,*]   = default;
  { adjusting by respondent's age distribution }
   do i = 0 while i <= imax
     do k = 0 while k < percntx
       mmtw(i,3,k) = mmtw(i,2,k) * agedis(i,1);
    enddo;
  enddo;
  do k = 0 while k < percntx
    mmtw[imax+1,3,k] = tblsum( row mmtw[0:imax,3,k] );
  enddo;
  mmtw[itot,3,*]   = 100 * mmtw[imax+1,3,*] / f1w[imax+1,3,*];

  { processing tables AMFW and AMMW }
  { adult mortality for females and females }
  amfw[*,1,*] = amfw[*,1,*]/12;
  ammw[*,1,*] = ammw[*,1,*]/12;
  amfw[imax+1,*,*] = tblsum( row amfw[0:imax,*,*] );
  ammw[imax+1,*,*] = tblsum( row ammw[0:imax,*,*] );
  amfw[*,2,*] = 1000 * amfw[*,0,*] / amfw[*,1,*];
  ammw[*,2,*] = 1000 * ammw[*,0,*] / ammw[*,1,*];
  { adjusting by respondent's age distribution }
  do i = 0 while i <= imax
    do k = 0 while k < percntx
      amfw(i,3,k) = amfw(i,2,k) * agedis(i,1);
      ammw(i,3,k) = ammw(i,2,k) * agedis(i,1);
    enddo;
  enddo;
  do k = 0 while k < percntx
    amfw[imax+1,3,k] = tblsum( row amfw[0:imax,3,k] );
    ammw[imax+1,3,k] = tblsum( row ammw[0:imax,3,k] );
  enddo;

  { processing table MM.1 }
  jtot = tblcol( tmm1 );
  tmm1[*,*,0]  = amfw[*,*,pidx];
  tmm1[*,*,1]  = ammw[*,*,pidx];
  tmm1[imax+1,jtot-1,*] = tmm1[imax+1,jtot,*];		{ Copy adjusted 15-49 mortality rate to unadjusted column }
  tmm1[*,jtot,*] = default;          { to eliminate printing the adjusted mortality rates for each age group }

  { construction of table MM.2 }
  itot  = tblrow( amfw );
  jtot  = tblcol( amfw );
  death = tblcol( amfw, mort = 0 );
  expo  = tblcol( amfw, mort = 1 );
  rate  = tblcol( amfw, mort = 2 );
  { female adult mortality }
  { calculate probability of dying between exact ages 15 and 50 for women }
  probd = 1;
  do i = 0 while i < itot
    ratei = amfw(i,rate,pidx) / 1000;
    qx    = 1 - ( 5 * ratei / (1+2.4*ratei) );
    probd = probd * qx;
{   errmsg( "i=%d ratei=%8.6f qx=%8.6f probd=%8.6f", i, ratei, qx, probd ); }
  enddo;
  tmm2(0,0)  =  1000 * (1 - probd);                      { 35q15                           }
  { male adult mortality }
  { calculate probability of dying between exact ages 15 and 50 for men }
  probd = 1;
  do i = 0 while i < itot
    ratei = ammw(i,rate,pidx) / 1000;
    qx    = 1 - ( 5 * ratei / (1+2.4*ratei) );
    probd = probd * qx;
  enddo;
  tmm2(0,1)  =  1000 * (1 - probd);                      { 35q15                           }

  { processing table MM.3 }
  itot = tblrow( tmm31 );
  tmm31[0:itot,0] = tmm1[0:itot,0,0];                        { number of female deaths }
  tmm31[0:itot,1] = mmtw[0:itot,0,pidx];                     { number of maternal deaths }
  tmm31[0:itot,2] = mmtw[0:itot,1,pidx];                     { exposure in years }
  tmm31[0:itot-1,3] = mmtw[0:itot-1,2,pidx];                     { maternal mortality rates (unadjusted for the age groups) }
  tmm31[itot,3] = mmtw[itot,3,pidx];                     { maternal mortality rates (adjusted by age for the total) }
  tmm31[0:itot,0] = tmm31[0:itot,1]*100 / tmm31[0:itot,0];   { percentage of female deaths that are maternal }
  { processing table MM.3.2 - continuation of previous table }
  tmm32(0,0)      = f1w(itot,3,pidx) * 1000;                 { general fertility rate (GFR) }
  tmm32(1,0)      = tmm31(itot,3) / tmm32(0,0) * 100000;     { maternal mortality ratio (MMR) }
  prmr            = tmm32(1,0) / 100000;
  tmm32(2,0)      = 1 - (1-prmr)^f1w(itot+1,rate,pidx);      { lifetime risk of maternal death }

  { processing table tc8 }
  itot  = tblrow( tc8 );
  itot1 = tblrow( tc8, rowc8 = 0 );
  itot2 = tblrow( tc8, rowc8 = 4 );
  itot3 = tblrow( tc8, rowc8 = 7 );
  tc8[itot1,*] = tblsum( row tc8[itot1+1:itot2-1,*] );
  tc8[itot2,*] = tblsum( row tc8[itot2+1:itot3-1,*] );
  tc8[itot3,*] = tblsum( row tc8[itot3+1:itot,*] );
  { percentages }
  do j = 1 while j <= 5 by 2
    { % for all siblings }
    do i = itot1 while i <= itot2-1
      tc8(i,j) = 100 * tc8(i,j-1) / tc8(itot1,j-1);
    enddo;
    { % surviving siblings }
    do i = itot2 while i <= itot3-1
      tc8(i,j) = 100 * tc8(i,j-1) / tc8(itot2,j-1);
    enddo;
    { % deceased siblings }
    do i = itot3 while i <= itot
      tc8(i,j) = 100 * tc8(i,j-1) / tc8(itot3,j-1);
    enddo;
  enddo;

  { processing table tmw }
  itot  = tblrow( tmw );
  do i = 0 while i < itot
    tmw(i,0) = 100 * tmw(i,0) / tmw(itot,0);
  enddo;

  { processing table tc9 }
  tc9[*,0] = (tc9w[*,0] + tc9w[*,1] + tc9w[*,2]) / tc9w[*,0];
  tc9[*,1] = tc9w[*,1] / tc9w[*,2] * 100;


PROC HH
preproc
  if hh1 <> wcluster then
    wcluster = hh1;
    loadcase(weights_dict, wcluster);
  endif;
  
PROC WMMNCH
preproc

  if WM7 <> 1 then skip case endif;
  intc = cmcode(WM6M, WM6Y);

postproc

  if unweight then
    rweight = 1
  else
    rweight = WMWEIGHT;
  endif;

  v013w = int(WB2C/5)-2;
  awfactor = 1;

{ --------------------------------------------------------------------------- }
{ table AGEDIS used to adjust fertility (f1w) and maternal mortality rates (mmtw) }
  gage = int(WB2C/5)-2;
  xtab( AGEDIS, rweight*awfactor );

{ --------------------------------------------------------------------------- }
{ table tc8, table is unweighted  by definition }

  for i in MODMM_EDT do;
    if MM5 in 1,2 then        { valid sex }
      colc8a = notappl;
      colc8b = notappl;
      colc8c = 1;
      if MM5 = 2 then
        colc8a = 1;
      else
        colc8b = 1;
      endif;
      box   MM6 => rowc8;
             1  => 1;
             2  => 2;
                => 3;
      endbox;
      xtab( tc8 );
      if MM6  = 1 then      { Survival status, sibling alive }
        rowc8 = 5;
        if !valid(MM7) then rowc8 = 6 endif;
        xtab( tc8 );
      elseif MM6 = 2  then
        xyd = ( valid(MM8) );
        xad = ( valid(MM9) );
        box xyd :  xad => rowc8;
             1  :   1  => 8;
             1  :      => 9;
                :   1  => 10;
                :      => 11;
        endbox;
        xtab( tc8 );
      endif;
    endif;
  enddo;

{ --------------------------------------------------------------------------- }
{ table tmw, table is unweighted  by definition }

  for i in MODMM_EDT do;
    colmw = 1;
    kmax = intc - upplim(pidx+1);
    kmin = intc - lowlim(pidx+1);
    if MM5 = 2 & MM6 = 2 & int((MM8C-MM7C)/12) in 15:49 & MM8C in kmin:kmax then        { women who died at ages 15-49 in the period of analysis (noramlly 0-6 years) }
      rowmw = 2;
      xtab( tmw );
      if (MM10=9 or MM11=9 or MM12=9) then    { missing on timing at death }
        rowmw = 1;
        xtab( tmw );
      endif;
    endif;
  enddo;

{ --------------------------------------------------------------------------- }
{ table tc9 }

  if MM1 in 0:90 then                 { if valid number of siblings }
    colc9w = 0;
    xtab( tc9w, rweight*awfactor );
    for i in MODMM_EDT do;
      if MM5 in 1,2 then              { women who died }
        colc9w = MM5;
        xtab( tc9w, rweight*awfactor );
      endif;
    enddo;
  endif;

{ --------------------------------------------------------------------------- }
{ tables f1w, ammw, amfw, mmtw  }
{ fertility, adult mortality (total, male, female) and maternal mortality     }

  do p = 1 while  p <= percntx         { for each period of analysis }
    { TFR for use in the Indirect Method }
    periods = p	- 1;
    kmin = upplim(p);
    kmax = lowlim(p);
    kextra = kmax - kmin - 59;
    if kextra >	0 then
      kmax = kmin + 59;
    endif;

    while kmax - kmin > 0 do               { for 59 months segments in a period }
      higcm = intc - kmin;
      lowcm = intc - kmax;
      totexp = higcm - lowcm + 1;
      higage = int( (higcm-WB1C) / 60 );
      higexp = higcm - WB1C - higage*60	+ 1;
      if higexp	> totexp then higexp = totexp endif;
      lowexp = totexp -	higexp;
      fert = 1;
      gage = higage - 2;
      { exposure for fertility }
      if gage >	0 and gage < 8 then
        rwt = higexp*rweight*awfactor;
        xtab( f1w, rwt );
      endif;
      gage = gage - 1;
      if gage >	0 then
        rwt = lowexp*rweight*awfactor;
        xtab( f1w, rwt );
      endif;
      { births in period }
      fert = 0;
      for i in MODBH_EDT
        if BH4C >= lowcm and BH4C <= higcm then
          gage = int( (BH4C - WB1C) / 60 ) - 2;
          if gage > 0 and gage < 8 then
            xtab( f1w, rweight );
          endif;
        endif;
      enddo;

      { MMR for the Direct Method }
      for i in MODMM_EDT do                { for all siblings in a period }
        xpreg    = ( MM10 = 1 or MM11 = 1 or MM12 = 1 );
        if MM5 in 1,2 then                 { valid sex }
          higcm = intc - kmin;
          lowcm = intc - kmax;
          totexp = higcm - lowcm + 1;
          higage = 0;

          { calculate exposure limits based on whether sibling dead or alive }
          if MM6 = 1 then             { survival status }
            if intc - MM7C >= 180 then
              higage = int( (higcm - MM7C) / 60 );
              higexp = higcm - MM7C - higage*60 + 1;
              if higexp > totexp then higexp = totexp endif;
              lowexp = totexp - higexp;
            else
              higage = 0;
            endif;
          elseif MM6 = 2 then
            if MM8C - MM7C >= 180 then   { died at 15+ years old }
              oldcm = higcm;
              newcm = MM8C;
              if newcm < higcm then higcm = newcm endif;
              totexp = higcm - lowcm + 1;
              if totexp < 0 then totexp = 0 endif;
              higage = int( (higcm - MM7C) / 60 );
              higexp = higcm - MM7C - higage*60 + 1;
              if higexp > totexp then higexp = totexp endif;
              lowexp = totexp - higexp;
              if newcm >= lowcm and newcm <= oldcm then
                mort = 0;
                gage = higage - 2;
                if gage > 0 and gage < 8 then
                  if MM5 = 1 then
                    xtab( ammw,  rweight*awfactor );
                  elseif MM5 = 2 then
                    xtab( amfw, rweight*awfactor );
                    if xpreg then
                      xtab( mmtw, rweight*awfactor );
                    endif;
                  endif;
                endif;
              endif;
            else
              higage = 0;
            endif;                  { end died at 15+ years old }
          endif;                { end survival status }

          { calculate numerator }
          if higage <> 0 then              { alive and 15+ years old or died at 15+ }
            mort = 1;
            gage = higage - 2;
            if gage > 0 and gage < 8 then
              if MM5 = 1 then
                xtab( ammw, higexp*rweight*awfactor );
              elseif MM5 = 2 then
                xtab( amfw, higexp*rweight*awfactor );
                xtab( mmtw, higexp*rweight*awfactor );
              endif;
            endif;
            gage = gage - 1;
            if gage > 0 and gage < 8 then
              if MM5 = 1 then
                xtab( ammw, lowexp*rweight*awfactor );
              elseif MM5 = 2 then
                xtab( amfw, lowexp*rweight*awfactor );
                xtab( mmtw, lowexp*rweight*awfactor );
              endif;
            endif;
          endif;                   { and allive 15+ or died at 15+ }
        endif;                  { end valid sex }
      enddo;                  { end for all siblings }
      { to establish if another iteration is required for period }
      if kextra	> 0 then
        kmin = kmax+1;
        kmax = lowlim(p);
        kextra = kmax - kmin - 59;
        if kextra > 0 then kmax = kmin + 59 endif;
      else
        kmin = 0;
        kmax = 0;
      endif;

    enddo;                  { end 59 months segments in a period }

  enddo;                 { end for each period of analysis }
