﻿PROC GLOBAL

  { Version 11/2012. Look for !!! to adapt programming to local implementation }

  set explicit;

  { --- Event table variables --------------------------------------------------------- }

  array type     (30);        { event type }
  array norder   (30);        { event order }
  array twincode (30);        { if a child is twin or not }
  array surv     (30);        { child's survival status }
  array sflag    (30);        { date flag }
  array smonth   (30);        { if month for event was given }
  array errflag  (30);        { event error flag }
  array lcmc     (30);        { event lower CMC }
  array ucmc     (30);        { event upper CMC }
  array cmc      (30);        { event imputed CMC }
  array interv   (30);        { interval to following event }
  array cdelay   (30);        { delay for pregnancy between events }
  array flagdth  (30);        { flag for age at death }
  array deathl   (30);        { age at death lower limit }
  array deathu   (30);        { age at death upper limit }
  array lstdu    (30);        { age adt death untis for hot deck imputation }
  array lstdn    (30);        { age at death number of units for hot deck imputation }
  { Arrays to check duplicate HH line numbers in birth histories }
  array persline(50);
  array mothline(50);
  alpha(5)  sdeath;           { to display age at death as a string }
  alpha(1) asterisk spaces;

  numeric zscoeff zsr zsb1 zsb2 zsb3 zsb4 zsb5 zsdz zst;
  numeric zsdzp zsfx zsll zsul zsa zsknot zsi zsj zsk zsl;
  numeric zsz zsc zsy1 zsy2 zsy3 zssd1 zssd2 zshta zspmed;
  numeric zsv zshac zshap zshaz zswap zswaz zswac zshtw;
  numeric zswhp zswhz zswhc fhaz fwaz fwhz zsflag;
  numeric leapday x xdays1 y xdays2 vcheckx addmode qmark lx l totlen;
  numeric aok alphsize a maxmem hhnum minage maxage minab;
  numeric chhlth chlabl chlabu mindi cln err i dd ss di lev grd j xline xwomen xchild;
  numeric ddw diwm udob ldob t ldobfc udobfc ldoblc udoblc;
  numeric dich hwsex hwage hwerr birthd birthm birthy age xweight xheight minbednets;
  numeric rok xmother momhl3 memhl3 mline_valid xfather dadhl3 fline_valid;
  numeric ldofm udofm minam frstrun cnt ddm dimm mminage mmaxage mminab mminam mlev mgrd;

  numeric temp minpd mincd maxevent doimp ignorey;
  numeric inunion nevents ismonth isyear isage flag lcmcb ucmcb mindb maxdb minai maxai;
  numeric everunion chadj lcmcm ucmcm fsexflag ceb;
  numeric agedu agedn maxd mind aged currpreg umin lmax ntwin k x1 x2 eno lsex;
  numeric lsexflag jinterv gap gap2 xgap du dn dmonths e etsuppress;
  numeric xdeath xdatemin xdatemax fsex lper lperflag BirthHis;
  numeric swrt aold iold aoldest anew;                            { Maternal mortality related }

  { --------------------------------------------------------------------------- }

  function valid(xvar);
    valid = (!special(xvar) and xvar < 96)
  end;

  { returns true if a valid 4 digits year variable }
  function validyr( xvar );
    validyr = ( !special(xvar) & xvar <= 9996 )
  end;

  { Function to get a month from a CMC }
  function cmc2m( xcmc );
    cmc2m = (xcmc-1)%12+1;
  end;

  { Function to get a 4 digits year from a CMC }
  function cmc2y( xcmc );
    cmc2y = int( (xcmc-1)/12 ) + 1900;
  end;

  function NAtoZero(xvar);
    if xvar = notappl then
      xvar = 0
    endif;
    NAtoZero = xvar;
  end;

  { function to adjust lower bound dates based on age }
  function ndjlba( lowera, uppera, lowerb, upperb, agetofit )
    temp = lowerb - 12 * (agetofit + 1);
    if temp > uppera then
      temp = -1
    else
      if temp < uppera then
        temp = temp + 1
      endif;
      if lowera > temp then
        temp = lowera
      endif
    endif;
    ndjlba = temp
  end;

  { Height and Weight Z-score functions }

  function zscoef(zsip,zsjp,zskp,zslp);
    recode zsip:zsjp:zskp:zslp => zscoeff;
      1:1:1:1=> 0.461824*100    ;  1:1:1:2=> 0.401257*10     ;  1:1:1:3=>-0.255449        ;  1:1:1:4=> 0.789966*0.01   ;
      1:1:2:1=> 0.673630*100    ;  1:1:2:2=> 0.133410*10     ;  1:1:2:3=>-0.421583*0.1    ;  1:1:2:4=> 0.101581*0.01   ;
      1:1:3:1=> 0.813173*100    ;  1:1:3:2=> 0.755023        ;  1:1:3:3=> 0.355289*0.01   ;  1:1:3:4=>-0.590137*0.001  ;
      1:2:1:1=> 0.504849*100    ;  1:2:1:2=> 0.438155*10     ;  1:2:1:3=>-0.312088        ;  1:2:1:4=> 0.105514*0.1    ;
      1:2:2:1=> 0.723318*100    ;  1:2:2:2=> 0.132797*10     ;  1:2:2:3=>-0.271990*0.1    ;  1:2:2:4=> 0.448522*0.001  ;
      1:2:3:1=> 0.876453*100    ;  1:2:3:2=> 0.814752        ;  1:2:3:3=>-0.701552*0.01   ;  1:2:3:4=> 0.609604*0.0001 ;
      1:3:1:1=> 0.547862*100    ;  1:3:1:2=> 0.475220*10     ;  1:3:1:3=>-0.368845        ;  1:3:1:4=> 0.132042*0.1    ;
      1:3:2:1=> 0.773055*100    ;  1:3:2:2=> 0.132163*10     ;  1:3:2:3=>-0.123304*0.1    ;  1:3:2:4=>-0.113662*0.001  ;
      1:3:3:1=> 0.939720*100    ;  1:3:3:2=> 0.874997        ;  1:3:3:3=>-0.174451*0.1    ;  1:3:3:4=> 0.693745*0.001  ;
      2:1:1:1=> 0.457829*100    ;  2:1:1:2=> 0.367323*10     ;  2:1:1:3=>-0.237212        ;  2:1:1:4=> 0.779334*0.01   ;
      2:1:2:1=> 0.653091*100    ;  2:1:2:2=> 0.129719*10     ;  2:1:2:3=>-0.267922*0.1    ;  2:1:2:4=> 0.466010*0.001  ;
      2:1:3:1=> 0.803115*100    ;  2:1:3:2=> 0.807980        ;  2:1:3:3=>-0.582173*0.01   ;  2:1:3:4=>-0.184636*0.001  ;
      2:2:1:1=> 0.498644*100    ;  2:2:1:2=> 0.393746*10     ;  2:2:1:3=>-0.262999        ;  2:2:1:4=> 0.884779*0.01   ;
      2:2:2:1=> 0.704487*100    ;  2:2:2:2=> 0.135350*10     ;  2:2:2:3=>-0.241086*0.1    ;  2:2:2:4=> 0.339627*0.001  ;
      2:2:3:1=> 0.864730*100    ;  2:2:3:2=> 0.859488        ;  2:2:3:3=>-0.882537*0.01   ;  2:2:3:4=> 0.322490*0.0001 ;
      2:3:1:1=> 0.539292*100    ;  2:3:1:2=> 0.421102*10     ;  2:3:1:3=>-0.290055        ;  2:3:1:4=> 0.995372*0.01   ;
      2:3:2:1=> 0.755903*100    ;  2:3:2:2=> 0.140880*10     ;  2:3:2:3=>-0.213041*0.1    ;  2:3:2:4=> 0.210055*0.001  ;
      2:3:3:1=> 0.926378*100    ;  2:3:3:2=> 0.911461        ;  2:3:3:3=>-0.118516*0.1    ;  2:3:3:4=> 0.242960*0.001  ;
      3:1:1:1=> 0.249740*10     ;  3:1:1:2=> 0.462056        ;  3:1:1:3=> 0.481125*0.1    ;  3:1:1:4=>-0.458894*0.01   ;
      3:1:2:1=> 0.601058*10     ;  3:1:2:2=> 0.543800        ;  3:1:2:3=>-0.344885*0.1    ;  3:1:2:4=> 0.973626*0.001  ;
      3:1:3:1=> 0.925227*10     ;  3:1:3:2=> 0.136684        ;  3:1:3:3=> 0.562077*0.001  ;  3:1:3:4=>-0.236327*0.0001 ;
      3:2:1:1=> 0.326804*10     ;  3:2:1:2=> 0.108795*10     ;  3:2:1:3=>-0.677657*0.1    ;  3:2:1:4=> 0.226565*0.01   ;
      3:2:2:1=> 0.784554*10     ;  3:2:2:2=> 0.519450        ;  3:2:2:3=>-0.269840*0.1    ;  3:2:2:4=> 0.738014*0.001  ;
      3:2:3:1=> 0.114685*100    ;  3:2:3:2=> 0.190655        ;  3:2:3:3=>-0.415541*0.001  ;  3:2:3:4=>-0.133747*0.0001 ;
      3:3:1:1=> 0.420915*10     ;  3:3:1:2=> 0.145910*10     ;  3:3:1:3=>-0.124212        ;  3:3:1:4=> 0.546698*0.01   ;
      3:3:2:1=> 0.967299*10     ;  3:3:2:2=> 0.558989        ;  3:3:2:3=>-0.258067*0.1    ;  3:3:2:4=> 0.644479*0.001  ;
      3:3:3:1=> 0.137784*100    ;  3:3:3:2=> 0.218043        ;  3:3:3:3=>-0.260545*0.01   ;  3:3:3:4=> 0.106811*0.001  ;
      4:1:1:1=> 0.230235*10     ;  4:1:1:2=> 0.545715        ;  4:1:1:3=> 0.131161*0.1    ;  4:1:1:4=>-0.221402*0.01   ;
      4:1:2:1=> 0.557059*10     ;  4:1:2:2=> 0.463994        ;  4:1:2:3=>-0.267363*0.1    ;  4:1:2:4=> 0.773006*0.001  ;
      4:1:3:1=> 0.862425*10     ;  4:1:3:2=> 0.156261        ;  4:1:3:3=> 0.109190*0.01   ;  4:1:3:4=>-0.898380*0.0001 ;
      4:2:1:1=> 0.322751*10     ;  4:2:1:2=> 0.768817        ;  4:2:1:3=>-0.124130*0.1    ;  4:2:1:4=>-0.857452*0.001  ;
      4:2:2:1=> 0.720834*10     ;  4:2:2:2=> 0.527256        ;  4:2:2:3=>-0.278471*0.1    ;  4:2:2:4=> 0.752199*0.001  ;
      4:2:3:1=> 0.108252*100    ;  4:2:3:2=> 0.183875        ;  4:2:3:3=>-0.767982*0.001  ;  4:2:3:4=> 0.714597*0.00001;
      4:3:1:1=> 0.391945*10     ;  4:3:1:2=> 0.115426*10     ;  4:3:1:3=>-0.635733*0.1    ;  4:3:1:4=> 0.176581*0.01   ;
      4:3:2:1=> 0.893781*10     ;  4:3:2:2=> 0.582092        ;  4:3:2:3=>-0.317886*0.1    ;  4:3:2:4=> 0.930288*0.001  ;
      4:3:3:1=> 0.129529*100    ;  4:3:3:2=> 0.221049        ;  4:3:3:3=> 0.170173*0.01   ;  4:3:3:4=>-0.906913*0.0001 ;
      5:1:1:1=> 0.250836*10     ;  5:1:1:2=> 0.681768*0.1    ;  5:1:1:3=> 0.126871*0.1    ;  5:1:1:4=>-0.259413*0.001  ;
      5:1:2:1=> 0.763160*10     ;  5:1:2:2=> 0.240094        ;  5:1:2:3=>-0.521241*0.01   ;  5:1:2:4=> 0.150006*0.001  ;
      5:1:3:1=> 0.111393*100    ;  5:1:3:2=> 0.198252        ;  5:1:3:3=> 0.288790*0.01   ;  5:1:3:4=>-0.207356*0.0001 ;
      5:2:1:1=> 0.314986*10     ;  5:2:1:2=> 0.148592        ;  5:2:1:3=> 0.947678*0.01   ;  5:2:1:4=>-0.205609*0.001  ;
      5:2:2:1=> 0.907905*10     ;  5:2:2:2=> 0.258223        ;  5:2:2:3=>-0.471024*0.01   ;  5:2:2:4=> 0.132953*0.001  ;
      5:2:3:1=> 0.129763*100    ;  5:2:3:2=> 0.217885        ;  5:2:3:3=> 0.246924*0.01   ;  5:2:3:4=> 0.104389*0.001  ;
      5:3:1:1=> 0.409354*10     ;  5:3:1:2=> 0.188963        ;  5:3:1:3=> 0.873912*0.01   ;  5:3:1:4=>-0.193446*0.001  ;
      5:3:2:1=> 0.107090*100    ;  5:3:2:2=> 0.283963        ;  5:3:2:3=>-0.460866*0.01   ;  5:3:2:4=> 0.113211*0.001  ;
      5:3:3:1=> 0.149874*100    ;  5:3:3:2=> 0.228093        ;  5:3:3:3=> 0.150476*0.01   ;  5:3:3:4=> 0.133490*0.001  ;
      6:1:1:1=> 0.260988*10     ;  6:1:1:2=> 0.630037*0.1    ;  6:1:1:3=> 0.115431*0.1    ;  6:1:1:4=>-0.231559*0.001  ;
      6:1:2:1=> 0.734790*10     ;  6:1:2:2=> 0.226503        ;  6:1:2:3=>-0.443447*0.01   ;  6:1:2:4=> 0.137357*0.001  ;
      6:1:3:1=> 0.107892*100    ;  6:1:3:2=> 0.200373        ;  6:1:3:3=> 0.298280*0.01   ;  6:1:3:4=> 0.891100*0.0001 ;
      6:2:1:1=> 0.329545*10     ;  6:2:1:2=> 0.103651        ;  6:2:1:3=> 0.119637*0.1    ;  6:2:1:4=>-0.255793*0.001  ;
      6:2:2:1=> 0.889598*10     ;  6:2:2:2=> 0.248036        ;  6:2:2:3=>-0.568606*0.01   ;  6:2:2:4=> 0.181276*0.001  ;
      6:2:3:1=> 0.125756*100    ;  6:2:3:2=> 0.219539        ;  6:2:3:3=> 0.410286*0.01   ;  6:2:3:4=>-0.204386*0.0001 ;
      6:3:1:1=> 0.393902*10     ;  6:3:1:2=> 0.201926        ;  6:3:1:3=> 0.746380*0.01   ;  6:3:1:4=>-0.178154*0.001  ;
      6:3:2:1=> 0.103641*100    ;  6:3:2:2=> 0.262530        ;  6:3:2:3=>-0.482882*0.01   ;  6:3:2:4=> 0.154783*0.001  ;
      6:3:3:1=> 0.144278*100    ;  6:3:3:2=> 0.239142        ;  6:3:3:3=> 0.352948*0.01   ;  6:3:3:4=> 0.139341*0.001  ;
      7:1:1:1=> 0.322108*100    ;  7:1:1:2=> 0.258812*10     ;  7:1:1:3=>-0.249611        ;  7:1:1:4=> 0.111355*0.1    ;
      7:1:2:1=> 0.411588*100    ;  7:1:2:2=> 0.795414        ;  7:1:2:3=>-0.491726*0.1    ;  7:1:2:4=> 0.131269*0.01   ;
      7:1:3:1=> 0.458912*100    ;  7:1:3:2=> 0.182354        ;  7:1:3:3=>-0.191581*0.01   ;  7:1:3:4=>-0.463902*0.0001 ;
      7:2:1:1=> 0.348510*100    ;  7:2:1:2=> 0.253355*10     ;  7:2:1:3=>-0.235109        ;  7:2:1:4=> 0.101480*0.1    ;
      7:2:2:1=> 0.437804*100    ;  7:2:2:2=> 0.808235        ;  7:2:2:3=>-0.524443*0.1    ;  7:2:2:4=> 0.140200*0.01   ;
      7:2:3:1=> 0.483499*100    ;  7:2:3:2=> 0.155234        ;  7:2:3:3=>-0.197246*0.01   ;  7:2:3:4=>-0.549570*0.00001;
      7:3:1:1=> 0.373458*100    ;  7:3:1:2=> 0.284554*10     ;  7:3:1:3=>-0.312001        ;  7:3:1:4=> 0.150148*0.1    ;
      7:3:2:1=> 0.464302*100    ;  7:3:2:2=> 0.723126        ;  7:3:2:3=>-0.417343*0.1    ;  7:3:2:4=> 0.106348*0.01   ;
      7:3:3:1=> 0.509357*100    ;  7:3:3:2=> 0.180925        ;  7:3:3:3=>-0.344910*0.01   ;  7:3:3:4=> 0.218012*0.0001 ;
      8:1:1:1=> 0.320688*100    ;  8:1:1:2=> 0.210232*10     ;  8:1:1:3=>-0.165974        ;  8:1:1:4=> 0.640051*0.01   ;
      8:1:2:1=> 0.400902*100    ;  8:1:2:2=> 0.801885        ;  8:1:2:3=>-0.507646*0.1    ;  8:1:2:4=> 0.138010*0.01   ;
      8:1:3:1=> 0.447875*100    ;  8:1:3:2=> 0.179737        ;  8:1:3:3=>-0.108106*0.01   ;  8:1:3:4=>-0.652464*0.0001 ;
      8:2:1:1=> 0.342817*100    ;  8:2:1:2=> 0.231444*10     ;  8:2:1:3=>-0.217205        ;  8:2:1:4=> 0.966608*0.01   ;
      8:2:2:1=> 0.424368*100    ;  8:2:2:2=> 0.751914        ;  8:2:2:3=>-0.432157*0.1    ;  8:2:2:4=> 0.108307*0.01   ;
      8:2:3:1=> 0.471083*100    ;  8:2:3:2=> 0.182624        ;  8:2:3:3=>-0.422515*0.01   ;  8:2:3:4=> 0.400879*0.0001 ;
      8:3:1:1=> 0.359806*100    ;  8:3:1:2=> 0.283176*10     ;  8:3:1:3=>-0.317336        ;  8:3:1:4=> 0.154859*0.1    ;
      8:3:2:1=> 0.448920*100    ;  8:3:2:2=> 0.696214        ;  8:3:2:3=>-0.385893*0.1    ;  8:3:2:4=> 0.942081*0.001  ;
      8:3:3:1=> 0.493177*100    ;  8:3:3:2=> 0.177050        ;  8:3:3:3=>-0.467440*0.01   ;  8:3:3:4=> 0.903841*0.0001 ;
      9:1:1:1=> 0.796017*100    ;  9:1:1:2=> 0.725005        ;  9:1:1:3=>-0.394565*0.01   ;  9:1:1:4=> 0.149043*0.0001 ;
      9:1:2:1=> 0.133056*1000   ;  9:1:2:2=> 0.406485        ;  9:1:2:3=> 0.115162*0.01   ;  9:1:2:4=> 0.272229*0.0001 ;
      9:1:3:1=> 0.147022*1000   ;  9:1:3:2=> 0.549084        ;  9:1:3:3=> 0.360168*0.01   ;  9:1:3:4=>-0.162614*0.001  ;
      9:1:4:1=> 0.163870*1000   ;  9:1:4:2=> 0.176161        ;  9:1:4:3=>-0.139606*0.1    ;  9:1:4:4=> 0.257402*0.001  ;
      9:2:1:1=> 0.855931*100    ;  9:2:1:2=> 0.837795        ;  9:2:1:3=>-0.533792*0.01   ;  9:2:1:4=> 0.233837*0.0001 ;
      9:2:2:1=> 0.146374*1000   ;  9:2:2:2=> 0.532432        ;  9:2:2:3=> 0.265930*0.01   ;  9:2:2:4=>-0.599481*0.0001 ;
      9:2:3:1=> 0.163122*1000   ;  9:2:3:2=> 0.530131        ;  9:2:3:3=>-0.273603*0.01   ;  9:2:3:4=>-0.522667*0.0001 ;
      9:2:4:1=> 0.176222*1000   ;  9:2:4:2=> 0.129924        ;  9:2:4:3=>-0.838083*0.01   ;  9:2:4:4=> 0.143430*0.001  ;
      9:3:1:1=> 0.915767*100    ;  9:3:1:2=> 0.950895        ;  9:3:1:3=>-0.673349*0.01   ;  9:3:1:4=> 0.318732*0.0001 ;
      9:3:2:1=> 0.159692*1000   ;  9:3:2:2=> 0.658332        ;  9:3:2:3=> 0.416714*0.01   ;  9:3:2:4=>-0.147054*0.001  ;
      9:3:3:1=> 0.179222*1000   ;  9:3:3:2=> 0.511316        ;  9:3:3:3=>-0.906767*0.01   ;  9:3:3:4=> 0.577848*0.0001 ;
      9:3:4:1=> 0.188574*1000   ;  9:3:4:2=> 0.831110*0.1    ;  9:3:4:3=>-0.282691*0.01   ;  9:3:4:4=> 0.382714*0.0001 ;
     10:1:1:1=> 0.784609*100    ; 10:1:1:2=> 0.769969        ; 10:1:1:3=>-0.579066*0.01   ; 10:1:1:4=> 0.299200*0.0001 ;
     10:1:2:1=> 0.100071*1000   ; 10:1:2:2=> 0.469370        ; 10:1:2:3=>-0.255930*0.01   ; 10:1:2:4=> 0.298134*0.0001 ;
     10:1:3:1=> 0.131726*1000   ; 10:1:3:2=> 0.564490        ; 10:1:3:3=> 0.388040*0.01   ; 10:1:3:4=>-0.211730*0.001  ;
     10:1:4:1=> 0.144582*1000   ; 10:1:4:2=> 0.384879        ; 10:1:4:3=>-0.113642*0.1    ; 10:1:4:4=> 0.132304*0.001  ;
     10:1:5:1=> 0.149882*1000   ; 10:1:5:2=> 0.810578*0.1    ; 10:1:5:3=> 0.292469*0.01   ; 10:1:5:4=>-0.738429*0.0001 ;
     10:2:1:1=> 0.844872*100    ; 10:2:1:2=> 0.877385        ; 10:2:1:3=>-0.854191*0.01   ; 10:2:1:4=> 0.726632*0.0001 ;
     10:2:2:1=> 0.105083*1000   ; 10:2:2:2=> 0.561061        ; 10:2:2:3=>-0.200222*0.01   ; 10:2:2:4=> 0.171075*0.0001 ;
     10:2:3:1=> 0.144783*1000   ; 10:2:3:2=> 0.560961        ; 10:2:3:3=> 0.200094*0.01   ; 10:2:3:4=>-0.164240*0.001  ;
     10:2:4:1=> 0.157128*1000   ; 10:2:4:2=> 0.373200        ; 10:2:4:3=>-0.982432*0.01   ; 10:2:4:4=> 0.982153*0.0001 ;
     10:2:5:1=> 0.162413*1000   ; 10:2:5:2=> 0.477105*0.1    ; 10:2:5:3=> 0.782933*0.001  ; 10:2:5:4=>-0.217935*0.0001 ;
     10:3:1:1=> 0.905784*100    ; 10:3:1:2=> 0.973526        ; 10:3:1:3=>-0.108372*0.1    ; 10:3:1:4=> 0.109954*0.001  ;
     10:3:2:1=> 0.112999*1000   ; 10:3:2:2=> 0.620169        ; 10:3:2:3=>-0.941330*0.001  ; 10:3:2:4=> 0.461746*0.00001;
     10:3:3:1=> 0.157837*1000   ; 10:3:3:2=> 0.557600        ; 10:3:3:3=> 0.139156*0.001  ; 10:3:3:4=>-0.117406*0.001  ;
     10:3:4:1=> 0.169676*1000   ; 10:3:4:2=> 0.361401        ; 10:3:4:3=>-0.831408*0.01   ; 10:3:4:4=> 0.648912*0.0001 ;
     10:3:5:1=> 0.174939*1000   ; 10:3:5:2=> 0.150850*0.1    ; 10:3:5:3=>-0.130583*0.01   ; 10:3:5:4=> 0.268575*0.0001 ;
     11:1:1:1=> 0.102271*100    ; 11:1:1:2=> 0.110605        ; 11:1:1:3=> 0.502728*0.001  ; 11:1:1:4=>-0.356088*0.00001;
     11:1:2:1=> 0.194677*100    ; 11:1:2:2=> 0.127619        ; 11:1:2:3=>-0.266421*0.001  ; 11:1:2:4=> 0.234381*0.0001 ;
     11:1:3:1=> 0.312284*100    ; 11:1:3:2=> 0.348780        ; 11:1:3:3=> 0.395244*0.01   ; 11:1:3:4=>-0.674519*0.0001 ;
     11:1:4:1=> 0.496166*100    ; 11:1:4:2=> 0.261986        ; 11:1:4:3=>-0.576064*0.01   ; 11:1:4:4=> 0.333672*0.0001 ;
     11:2:1:1=> 0.123424*100    ; 11:2:1:2=> 0.202445        ; 11:2:1:3=>-0.116412*0.01   ; 11:2:1:4=> 0.118225*0.0001 ;
     11:2:2:1=> 0.252964*100    ; 11:2:2:2=> 0.218676        ; 11:2:2:3=> 0.138954*0.01   ; 11:2:2:4=> 0.709375*0.00001;
     11:2:3:1=> 0.449515*100    ; 11:2:3:2=> 0.462032        ; 11:2:3:3=> 0.266641*0.01   ; 11:2:3:4=>-0.629917*0.0001 ;
     11:2:4:1=> 0.663061*100    ; 11:2:4:2=> 0.282610        ; 11:2:4:3=>-0.640439*0.01   ; 11:2:4:4=> 0.619515*0.0001 ;
     11:3:1:1=> 0.154874*100    ; 11:3:1:2=> 0.219986        ; 11:3:1:3=>-0.841307*0.001  ; 11:3:1:4=> 0.189821*0.0001 ;
     11:3:2:1=> 0.340501*100    ; 11:3:2:2=> 0.394048        ; 11:3:2:3=> 0.325883*0.01   ; 11:3:2:4=>-0.164077*0.0001 ;
     11:3:3:1=> 0.658807*100    ; 11:3:3:2=> 0.607904        ; 11:3:3:3=> 0.305441*0.001  ; 11:3:3:4=>-0.377818*0.0001 ;
     11:3:4:1=> 0.915854*100    ; 11:3:4:2=> 0.376078        ; 11:3:4:3=>-0.513514*0.01   ; 11:3:4:4=>-0.177567*0.0001 ;
     12:1:1:1=> 0.958878*10     ; 12:1:1:2=> 0.162168        ; 12:1:1:3=>-0.158785*0.01   ; 12:1:1:4=> 0.141728*0.0001 ;
     12:1:2:1=> 0.166639*100    ; 12:1:2:2=> 0.124691        ; 12:1:2:3=> 0.963245*0.001  ; 12:1:2:4=> 0.307446*0.00001;
     12:1:3:1=> 0.282771*100    ; 12:1:3:2=> 0.273485        ; 12:1:3:3=> 0.151665*0.01   ; 12:1:3:4=>-0.370240*0.0001 ;
     12:1:4:1=> 0.408042*100    ; 12:1:4:2=> 0.163173        ; 12:1:4:3=>-0.381481*0.01   ; 12:1:4:4=> 0.315956*0.0001 ;
     12:2:1:1=> 0.117963*100    ; 12:2:1:2=> 0.219662        ; 12:2:1:3=>-0.262788*0.01   ; 12:2:1:4=> 0.292835*0.0001 ;
     12:2:2:1=> 0.218409*100    ; 12:2:2:2=> 0.220578        ; 12:2:2:3=> 0.264314*0.01   ; 12:2:2:4=>-0.141618*0.0001 ;
     12:2:3:1=> 0.415319*100    ; 12:2:3:2=> 0.384808        ; 12:2:3:3=> 0.940228*0.0001 ; 12:2:3:4=>-0.391686*0.0001 ;
     12:2:4:1=> 0.558876*100    ; 12:2:4:2=> 0.123101        ; 12:2:4:3=>-0.554625*0.01   ; 12:2:4:4=> 0.702252*0.0001 ;
     12:3:1:1=> 0.144385*100    ; 12:3:1:2=> 0.322835        ; 12:3:1:3=>-0.438366*0.01   ; 12:3:1:4=> 0.540144*0.0001 ;
     12:3:2:1=> 0.296945*100    ; 12:3:2:2=> 0.380152        ; 12:3:2:3=> 0.533894*0.01   ; 12:3:2:4=>-0.449181*0.0001 ;
     12:3:3:1=> 0.620215*100    ; 12:3:3:2=> 0.535709        ; 12:3:3:3=>-0.274632*0.01   ; 12:3:3:4=>-0.206170*0.0001 ;
     12:3:4:1=> 0.791280*100    ; 12:3:4:2=> 0.129558        ; 12:3:4:3=>-0.571516*0.01   ; 12:3:4:4=> 0.648512*0.0001 ;
     13:1:1:1=> 0.288221*10     ; 13:1:1:2=> 0.311757        ; 13:1:1:3=>-0.339993*0.01   ; 13:1:1:4=> 0.332712*0.0001 ;
     13:1:2:1=> 0.907104*10     ; 13:1:2:2=> 0.204144        ; 13:1:2:3=>-0.904587*0.001  ; 13:1:2:4=> 0.465496*0.0001 ;
     13:1:3:1=> 0.171038*100    ; 13:1:3:2=> 0.311893        ; 13:1:3:3=> 0.398312*0.01   ; 13:1:3:4=>-0.276662*0.0001 ;
     13:2:1:1=> 0.431260*10     ; 13:2:1:2=> 0.371447        ; 13:2:1:3=>-0.633119*0.01   ; 13:2:1:4=> 0.877037*0.0001 ;
     13:2:2:1=> 0.110122*100    ; 13:2:2:2=> 0.219333        ; 13:2:2:3=> 0.246595*0.001  ; 13:2:2:4=> 0.313171*0.0001 ;
     13:2:3:1=> 0.203336*100    ; 13:2:3:2=> 0.351685        ; 13:2:3:3=> 0.353489*0.01   ; 13:2:3:4=> 0.104383*0.001  ;
     13:3:1:1=> 0.658687*10     ; 13:3:1:2=> 0.352637        ; 13:3:1:3=>-0.345830*0.01   ; 13:3:1:4=> 0.293354*0.0001 ;
     13:3:2:1=> 0.136997*100    ; 13:3:2:2=> 0.234726        ; 13:3:2:3=>-0.125814*0.01   ; 13:3:2:4=> 0.889698*0.0001 ;
     13:3:3:1=> 0.241885*100    ; 13:3:3:2=> 0.473620        ; 13:3:3:3=> 0.808368*0.01   ; 13:3:3:4=> 0.103298*0.001  ;
     14:1:1:1=> 0.303896*10     ; 14:1:1:2=> 0.276098        ; 14:1:1:3=>-0.226928*0.01   ; 14:1:1:4=> 0.201277*0.0001 ;
     14:1:2:1=> 0.982301*10     ; 14:1:2:2=> 0.194286        ; 14:1:2:3=>-0.457785*0.001  ; 14:1:2:4=> 0.537775*0.0001 ;
     14:1:3:1=> 0.147037*100    ; 14:1:3:2=> 0.258573        ; 14:1:3:3=> 0.325286*0.01   ; 14:1:3:4=> 0.168530*0.0001 ;
     14:2:1:1=> 0.430208*10     ; 14:2:1:2=> 0.364667        ; 14:2:1:3=>-0.629446*0.01   ; 14:2:1:4=> 0.835936*0.0001 ;
     14:2:2:1=> 0.118341*100    ; 14:2:2:2=> 0.212702        ; 14:2:2:3=> 0.122896*0.01   ; 14:2:2:4=> 0.201561*0.0001 ;
     14:2:3:1=> 0.176216*100    ; 14:2:3:2=> 0.301222        ; 14:2:3:3=> 0.261973*0.01   ; 14:2:3:4=> 0.121334*0.001  ;
     14:3:1:1=> 0.658206*10     ; 14:3:1:2=> 0.363970        ; 14:3:1:3=>-0.609859*0.01   ; 14:3:1:4=> 0.885250*0.0001 ;
     14:3:2:1=> 0.144026*100    ; 14:3:2:2=> 0.237072        ; 14:3:2:3=> 0.186866*0.01   ; 14:3:2:4=> 0.269321*0.0001 ;
     14:3:3:1=> 0.211715*100    ; 14:3:3:2=> 0.365772        ; 14:3:3:3=> 0.372698*0.01   ; 14:3:3:4=> 0.332188*0.001  ;
    endrecode;
    zscoef = zscoeff;
  end;

  function dabs(dval);
    if dval < 0 then dval = - dval endif;
    dabs = dval;
  end;

  function zspct(zssd);
    if zssd > 9.985 then
      zspct = 99.9
    else
      zsr  =  0.2316419;
      zsb1 =  0.31938153;
      zsb2 = -0.356563782;
      zsb3 =  1.781477937;
      zsb4 = -1.821255978;
      zsb5 =  1.330274429;
      zsdz = dabs(zssd);
      zst = 1/(1+zsdz*zsr);
      zsdzp = zsb1*zst+zsb2*zst^2+zsb3*zst^3+zsb4*zst^4+zsb5*zst^5;
      zsfx = 1/sqrt(8*0.785398163)*exp(-0.5*zsdz^2);
                     { ATAN(1.0) }
      zsdzp = zsdzp*zsfx*100;
      if zssd >= 0 then zsdzp= 100 - zsdzp endif;
      if zsdzp > 99.8 then zsdzp = 99.8 endif;
      zspct = zsdzp;
    endif;
  end;

  function zseval(zsx,zsy);
    if (zsx < zsll or zsx > zsul) and zsll <> zsul then
      zseval = 999.9
    else
      recode zsi => zsk;
         9,11,12 => 4;
              10 => 5;
                 => 3;
      endrecode;
      zsj = zsy;
      zsa = -1;
      while zsk > 0 and zsa < 0 do
        recode zsi : zsk => zsknot;
              1 : 1 =>  0;  1 : 2 =>  9;  1 : 3 => 24;
              2 : 1 =>  0;  2 : 2 =>  9;  2 : 3 => 24;
              3 : 1 =>  0;  3 : 2 =>  6;  3 : 3 => 18;
              4 : 1 =>  0;  4 : 2 =>  6;  4 : 3 => 18;
              5 : 1 => 49;  5 : 2 => 72;  5 : 3 => 90;
              6 : 1 => 49;  6 : 2 => 72;  6 : 3 => 90;
           {  7 : 1 =>  0;  7 : 2 =>  6;  7 : 3 => 18;
              8 : 1 =>  0;  8 : 2 =>  6;  8 : 3 => 18; }
              9 : 1 => 24;  9 : 2 =>138;  9 : 3 =>168;  9 : 4 =>204;
             10 : 1 => 24; 10 : 2 => 54; 10 : 3 =>132; 10 : 4 =>156; 10 : 5 =>192;
             11 : 1 => 24; 11 : 2 => 96; 11 : 3 =>156; 11 : 4 =>204;
             12 : 1 => 24; 12 : 2 => 84; 12 : 3 =>144; 12 : 4 =>192;
             13 : 1 => 55; 13 : 2 => 80; 13 : 3 =>115;
             14 : 1 => 55; 14 : 2 => 85; 14 : 3 =>108;
                :   => default;
        endrecode;
        if zsi = 10 and zsj = 1 and zsk = 2 then zsknot = 60 endif;
        zsa = zsx-zsknot;
        if zsa < 0 then zsk = zsk-1 endif;
      enddo;
      if zsk = 0 then zsk = 1 endif;
      zsl = 4;
      zsz = 0;
      while zsl > 0 do
        zsz = zsz*zsa+zscoef(zsi,zsj,zsk,zsl);
        zsl = zsl-1;
      enddo;
      zseval=zsz;
    endif;
  end;

  function zscr(zsx,zsms);
    if ((zsx < zsll or zsx > zsul) and zsll <> zsul) then
      zsc=9.99
    else
      zsy1=zseval(zsx,1);
      zsy2=zseval(zsx,2);
      zsy3=zseval(zsx,3);
      zssd1=(zsy2-zsy1)/1.8807936; if zssd1 < 0 then zssd1 = -zssd1 endif;
      zssd2=(zsy2-zsy3)/1.8807936; if zssd2 < 0 then zssd2 = -zssd2 endif;
      if zsll = zsul then
        zsc=zsy2;
        zsll=zssd1;
        zsul=zssd2;
      else
        if zsms < zsy2 then
          zsc=(zsms-zsy2)/zssd1;
          if zsc < -9.98 then zsc=-9.98 endif;
        else
          zsc=(zsms-zsy2)/zssd2;
          if zsc > 9.98 then zsc=9.98 endif;
        endif;
      endif;
    endif;
    zscr = zsc;
  end;

  function zsanth(zsage,zssex,zswt,zsht,zsageok)
    if zssex = 1 or zssex = 2 then
      if (zsageok = 1 and zsage >= 24) or (zsageok <> 1 and zsht >= 85) then
        { FELS REFERENCE THROUGH 36 MONTHS      }
        { CHANGE TO >= 24 FOR REGULAR REFERENCE }
        zsi=zssex+8
      else
        zsi=zssex
      endif;
      if zsageok = 1 then
        { Ht/Age }
        if zsage < 24 then
          zshta = zsht;
          zsll=0; zsul=36;
        else
          zshta = zsht {- 1} ;    { Subtract 1 if lying after 24 months !!! }
          zsll=24; zsul=216;
        endif;
        if zsage < zsll or zsage > zsul or
           zshta > 999 or zshta <= 0.01 then
          zspmed=999.9;
          zsc=9.99;
        else
          zsv = zseval(zsage,2);
          zsc = zscr(zsage,zshta);
          zspmed = (zshta/zsv)*100;
        endif;
        zshap=zspmed;
        zshaz=zsc;
        zshac=zspct(zsc);
      endif;
      { Wt/Age }
      zsi = zsi + 2;
      if zsageok = 1 then
        if zsage < 24 then
          zsll=0; zsul=36;
        else
          zsll=24; zsul=216;
        endif;
        if zsage < zsll or zsage > zsul or
           zswt > 999 or zswt <= 0.01 then
          zspmed=999.9;
          zsc=9.99;
        else
          zsv = zseval(zsage,2);
          zsc = zscr(zsage,zswt);
          zspmed = (zswt/zsv)*100;
        endif;
        zswap=zspmed;
        zswaz=zsc;
        zswac=zspct(zsc);
      endif;
      { Wt/Ht }
      zsi = zsi + 2;
      if (zsageok = 1 and zsage < 24) or (zsageok <> 1 and zshtw < 85) then
        zshtw = zsht;
        zsll=49; if zssex = 1 then zsul=103 else zsul=101 endif;
      else
        zshtw = zsht {- 1} ;      { Subtract 1 if lying after 24 months !!! }
        zsll=55; if zssex = 1 then zsul=145 else zsul=137 endif;
      endif;
      if zshtw < zsll or zshtw > zsul or
         zswt > 999 or zswt <= 0.01 then
        zspmed=999.9;
        zsc=9.99;
      else
        zsv = zseval(zshtw,2);
        zsc = zscr(zshtw,zswt);
        zspmed = (zswt/zsv)*100;
      endif;
      zswhp=zspmed;
      zswhz=zsc;
      zswhc=zspct(zsc);
      if zsageok = 1 then
        if zsage < 24 then
          zsll=0; zsul=36;
        else
          zsll=24; if zssex = 1 then zsul=138 else zsul=120 endif;
        endif;
        if zsage < zsll or zsage > zsul then
          zswhc=99.9;
          zswhp=999.9;
          zswhz=9.99;
        endif;
      endif;
      zsanth = 1;
    else
      zshac=99.9;
      zshap=999.9;
      zshaz=9.99;
      zswac=99.9;
      zswap=999.9;
      zswaz=9.99;
      zswhc=99.9;
      zswhp=999.9;
      zswhz=9.99;
      zsanth = 0;
    endif;
    fhaz = 0; fwaz = 0; fwhz = 0;
    if zshaz <= -6.00 or zshaz >= 6.00 then      { h/a out of range }
      fhaz = 1;
    endif;
    if zswaz <= -6.00 or zswaz >= 6.00 then      { w/a out of range }
      fwaz = 1;
    endif;
    if zswhz <= -4.00 or zswhz >= 6.00 then      { w/h out of range }
      fwhz = 1;
    endif;
    if zshaz <  -3.09 and  zswhz >  3.09 then      { height too low  }
      fhaz = 1; fwhz = 1;
    endif;
    if zshaz >   3.09 and  zswhz < -3.09 then      { height too high }
      fhaz = 1; fwhz = 1;
    endif;
    zsflag = 4*fwaz+2*fwhz+fhaz;
  end;

  function agemth(xhwbd,xhwbm,xhwby,xhwmd,xhwmm,xhwmy);
    { if birth month and year and measurement day, month and year are all valid }
    if valid(xhwbm) and xhwby < 9996 and valid(xhwmd) and valid(xhwmm) and xhwmy < 9996 then
      { if day of birth inconsistent, don't know or missing }
      if not(valid(xhwbd)) then
        { impute day of birth }
        xhwbd = 15;
      endif;
      leapday = (xhwby % 4 = 0);
      xdays1 = xhwbd;
      do x = 1 while x < xhwbm
        recode x        => y;
           1,3,5,7,8,10 => 31;
                      2 => 28+leapday;
               4,6,9,11 => 30;
        endrecode;
        xdays1 = xdays1 + y;
      enddo;
      leapday = (xhwmy % 4 = 0);
      xdays2 = xhwmd;
      do x = 1 while x < xhwmm
        recode x        => y;
           1,3,5,7,8,10 => 31;
                      2 => 28+leapday;
               4,6,9,11 => 30;
        endrecode;
        xdays2 = xdays2 + y;
      enddo;
      do x = xhwby while x < xhwmy
        xdays2 = xdays2 + 365 + (x % 4 = 0);
      enddo;
      agemth = int(((xdays2 - xdays1)/30.4375)*100+0.5)/100;
    else
      agemth = 9999;
    endif;
  end;

  { Function to check all possible combinations of day, month and year in vaccinations }
  function vdvalid(vcheckd,vcheckm,vchecky);
    { 0 = no problem, 1 = inconsistency }
    vdvalid = 0;
    { Check day, month and year are consistent }
    recode    vchecky   : vcheckm               : vcheckd    => vcheckx; { !!! }
    2008-2015,9996-9999 : 1,3,5,7,8,10,12,96-99 : 1-31,96-99 => 0;
    2008-2015,9996-9999 : 4,6,9,11              : 1-30,96-99 => 0;
    2008-2015,9996-9999 : 2                     : 1-28,96-99 => 0;
         2008,2012      : 2                     : 29         => 0;       { leap year }
                   6666 : 66                    : 66         => 0;
                   4444 : 44                    : 44         => 0;
                notappl : notappl               : 0          => 0;
                        :                       :            => 1;
    endrecode;
    if vcheckx then
      vdvalid = 1;
    endif;
    vdvalid = 0;
  end;

  { Check vaccination date is before date of interview }
  function vdoi(vcheckd,vcheckm,vchecky);
    { 0 = no problem, 1 = inconsistency: vaccination date after date of interview }
    vdoi = 0;
    { if vac date has valid day, month and year }
    if (vcheckd in 1:31) and vcheckm in 1:12 and vchecky < 4444 then
      { if vac date is after interview date }
      if (cmcode(vcheckm,vchecky) > cmcode(UF8M,UF8Y)) |
         (cmcode(vcheckm,vchecky) = cmcode(UF8M,UF8Y) and vcheckd > UF8D) then
        vdoi = 1;
      endif;
    { else if vac date has valid month and year only }
    elseif vcheckm in 1:12 and vchecky <4444 then
      { if vac date is after interview date }
      if (cmcode(vcheckm,vchecky) > cmcode(UF8M,UF8Y)) then
        vdoi = 1;
      endif;
    { else if vac date has valid year only }
    elseif vchecky < 4444 then
      { if vac date is after interview date }
      if vchecky > UF8Y then
        vdoi = 1;
      endif;
    endif;
  end;

  { Check vaccination date is after date of birth }
  function vdob(vcheckd,vcheckm,vchecky);
    { 0 = no problem, 1 = inconsistency: vaccination date before date of birth }
    vdob = 0;
    { if date of birth has valid day, month and year }
    if valid(AG1D) and valid(AG1M) and AG1Y < 9996 then
      { if vac date has valid day, month and year }
      if vcheckd in 1:31 and vcheckm in 1:12 and vchecky < 4444 then
        if cmcode(vcheckm,vchecky) < cmcode(AG1M,AG1Y) | (cmcode(vcheckm,vchecky) = cmcode(AG1M,AG1Y) and vcheckd < AG1D) then
          vdob = 1;
        endif;
      { else if vac date has valid month and year only }
      elseif vcheckm in 1:12 and vchecky < 4444 then
        if cmcode(vcheckm,vchecky) < cmcode(AG1M,AG1Y) then
          vdob = 1;
        endif;
      { else if vac date has valid year only }
      elseif vchecky < 4444 then
        if vchecky < AG1Y then
          vdob = 1;
        endif;
      endif;
    { else if date of birth has valid month and year only }
    elseif valid(AG1M) and AG1Y < 9996 then
      { if vac date has valid month and year only }
      if vcheckm in 1:12 and vchecky < 4444 then
        if cmcode(vcheckm,vchecky) < cmcode(AG1M,AG1Y) then
          vdob = 1;
        endif;
      { else if vac date has valid year only }
      elseif vchecky < 4444 then
        if vchecky < AG1Y then
          vdob = 1;
        endif;
      endif;
    { if date of birth has valid year only }
    elseif AG1Y < 9996 then
      { if vac date has valid year only }
      if vchecky < 4444 then
        if vchecky < AG1Y then
          vdob = 1;
        endif;
      endif;
    endif;
  end;

  { Check vaccination 1 (e.g., Polio 2) was given before vaccination 2 (e.g., Polio 3) }
  function vseq(vcheckd1,vcheckm1,vchecky1,vcheckd2,vcheckm2,vchecky2);
    { 0 = no problem, 1 = inconsistency: vaccination 1's date before vaccination 2's date }
    vseq = 0;
    { if vac 1's date has valid day, month and year }
    if vcheckd1 < 44 and vcheckd1 <> 0 and valid(vcheckm1) and vchecky1 < 9996 then
      { if vac 2's date has valid day, month and year }
      if vcheckd2 < 44 and vcheckd2 <> 0 and valid(vcheckm2) and vchecky2 < 9996 then
        if cmcode(vcheckm2,vchecky2) < cmcode(vcheckm1,vchecky1) |
          (cmcode(vcheckm2,vchecky2) = cmcode(vcheckm1,vchecky1) and vcheckd2 < vcheckd1) then
          vseq = 1;
        endif;
      { else if vac 2's date has valid month and year only }
      elseif valid(vcheckm2) and vchecky2 < 9996 then
        if cmcode(vcheckm2,vchecky2) < cmcode(vcheckm1,vchecky1) then
          vseq = 1;
        endif;
      { else if vac 2's date has valid year only }
      elseif vchecky2 < 9996 then
        if vchecky2 < vchecky1 then
          vseq = 1;
        endif;
      endif;
    { else if vac 1's date has valid month and year only }
    elseif valid(vcheckm1) and vchecky1 < 9996 then
      { if vac 2's date has valid month and year only }
      if valid(vcheckm2) and vchecky2 < 9996 then
        if cmcode(vcheckm2,vchecky2) < cmcode(vcheckm1,vchecky1) then
          vseq = 1;
        endif;
      { else if vac 2's date has valid year only }
      elseif vchecky2 < 9996 then
        if vchecky2 < vchecky1 then
          vseq = 1;
        endif;
      endif;
    { else if vac 1's date has valid year only }
    elseif vchecky1 < 9996 then
      { if vac 2's date has valid year only }
      if vchecky2 < 9996 then
        if vchecky2 < vchecky1 then
          vseq = 1;
        endif;
      endif;
    endif;
  end;

  { Check two vaccinations are given on the same date, e.g. Polio 1 and DPT 1 }
  function vmatch(vcheckd1,vcheckm1,vchecky1,vcheckd2,vcheckm2,vchecky2);
    { 0 = no problem, 1 = inconsistency: vaccinations given on different dates }
    vmatch = 0;
    { if day, month or year of vaccinations are different }
    if vcheckd1 <> vcheckd2 or vcheckm1 <> vcheckm2 or vchecky1 <> vchecky2 then
      vmatch = 1;
    endif;
  end;

PROC MICS5_FF
preproc

  seed(101);            { Seed to start the random number generator }
  { set application parameters }

  maxmem  = 50;       { maximum number of household members       }
  hhnum   = 0;        { last household number used                }
  minage  = 15;       { minimum age of eligible women             }
  maxage  = 49;       { maximum age of eligible women             }
  mminage = 15;       { !!! minimum age of eligible men           }
  mmaxage = 49;       { !!! maximum age of eligible men           }
  minab   = 144;      { !!! minimum age at birth in months = 12 years }
  minam   = 120;      { !!! minimum age at first marriage = 10 years  }
  mminab  = 144;      { minimum age at birth in months = 12 years - men }
  mminam  = 120;      { minimum age at first marriage = 4 years - men  }
  chhlth  = 4;        { maximum age at which child is included in child health module - excludes exact age 5 }
  chlabl  = 5;        { minimum age at which child is included in child labor module - includes exact age 5 }
  chlabu  = 14;       { maximum age at which child is included in child labor module - excludes exact age 15 }
  mindi   = 20120901; { !!! replace "20120901" with earliest interview date in yyyymmdd format }

  { frstrun equals 1 if warning messages on for this cluster, 0 otherwise }
  frstrun=tonumber(sysparm());
  {+EN}display("Warning messages on = %d",frstrun);          {EN+}
  {{ES}display("ES = %d",frstrun);                           {ES}}
  {{FR}display("Les messages d'avertisssement = %d",frstrun);{FR}}

  { Initializing the application before the first questionnaire }

  minpd    = 7;         { !!! Minimum pregnancy duration               }
  mincd    = 2;         { !!! Minimum conception delay after birth     }
  maxevent = 30;        { !!! Maximum number of events                 }
  doimp    = 1;         { 1 if doing imputation - 0 if no imputation   }
  ignorey  = 0;         { 1 if ignoring year when age + year = interview year
                          0 if using year when age + year = interview year  }

  { initialize hot deck to impute age at death }
  do i = 1 while i <= maxevent
    lstdu(i) = 2;               { Units set initially as months }
    lstdn(i) = int((i-1)/10);   { Numbers within units as 0, 1, 2, 3 and 4 }
  enddo;

PROC HH
preproc
  { initialize arrays to check duplicates betwen birth history and HH members and }
  { to store the individual interview result to use when assining HIV weights     }
  do i = 1 while i <= maxmem
    persline(i) = 0;
    mothline(i) = 0;
  enddo;

postproc

  { Household questionnaire     }

  { HOUSEHOLD INFORMATION PANEL }

  { Check HH date of interview is valid }
  recode HH5Y  :     HH5M        : HH5D => err;
     2012-2015 : 1,3,5,7,8,10,12 : 1-31 => 0;
     2012-2015 : 4,6,9,11        : 1-30 => 0;
     2013-2015 : 2               : 1-28 => 0;
          2012 : 2               : 1-29 => 0;
               :                 :      => 1;
  endrecode;
  if err then
    {+EN}errmsg(0016,"Household's",HH5D,HH5M,HH5Y); {EN+}
    {{ES}errmsg(0016,"ES",HH5D,HH5M,HH5Y);          {ES}}
    {{FR}errmsg(0016,"Du menage",HH5D,HH5M,HH5Y);   {FR}}
  endif;
  dd = (HH5Y*100 + HH5M)*100 + HH5D;
  ss = sysdate("yyyymmdd");
  if dd >= ss or dd < mindi then
    {+EN} errmsg(0016,"Household's",HH5D,HH5M,HH5Y);{EN+}
    {{ES} errmsg(0016,"ES",HH5D,HH5M,HH5Y);         {ES}}
    {{FR} errmsg(0016,"Du menage",HH5D,HH5M,HH5Y);  {FR}}
  endif;

  di = cmcode(HH5M,HH5Y);

  { Check region agrees with cluster number }
  recode HH1  : HH6 => err;
      001-100 :  1  => 0;
      101-200 :  2  => 0;
      201-300 :  1  => 0;
      301-400 :  2  => 0;
      401-500 :  1  => 0;
      501-600 :  2  => 0;
      601-700 :  1  => 0;
      701-800 :  2  => 0;
              :     => 1;
  endrecode;
  if err then
    errmsg(0011,HH1,"HH6",HH6);
  endif;

  { Check region agrees with cluster number }
  recode HH1  : HH7 => err;
      001-100 :  1  => 0;
      101-200 :  1  => 0;
      201-300 :  2  => 0;
      301-400 :  2  => 0;
      401-500 :  3  => 0;
      501-600 :  3  => 0;
      601-700 :  4  => 0;
      701-800 :  4  => 0;
              :     => 1;
  endrecode;
  if err then
    errmsg(0011,HH1,"HH7",HH7);
  endif;

  { If household interview complete }
  if HH9 = 1 then

    { Check not more eligible women than HH members }
    if HH12 > HH11 then
      errmsg(0015,HH12,HH14,HH11);
    endif;

    { Check not more interviews than eligible women }
    if HH13 > HH12 then
      errmsg(0014,HH13,HH12);
    endif;

    { Check not more women and under-5s than HH members }
    if HH12+HH14 > HH11 then
      errmsg(0015,HH12,HH14,HH11);
    endif;

    { Check not more interviews than eligible children }
    if HH15 > HH14 then
      errmsg(0013,HH15,HH14);
    endif;

    { HOUSEHOLD LISTING }

    i = 1;
    while i <= noccurs(MODHL_EDT) do {loop through the household members }
      { Head of household must be on first line }
      if frstrun then
        if (HL3(i) = 1) <=> (HL1(i) <> 1) then
          errmsg(0141,i,HL3(i));
        endif;
      endif;

       { Relationship checks }
      if frstrun then
        { Check the spouse of head of household is of opposite sex }
        if HL3(i) = 2 and HL4(i) = HL4(1) then
          errmsg(0142,i,HL4(i),HL4(1));
        { Check children of head of household are at least minab/12 years younger }
        elseif HL3(i) = 3 and HL6(1) < HL6(i)+(minab/12) then
          errmsg(0143,minab/12,i,HL6(i),HL6(1));
        { Check grandchildren of head of household are at least minab/6 years younger }
        elseif HL3(i) = 5 and HL6(1) < HL6(i)+(minab/6) then
          errmsg(0145,minab/6,i,HL6(i),HL6(1));
        { Check parents of head of household are at least minab/12 years older }
        elseif HL3(i) = 6 and HL6(1)+(minab/12) > HL6(i) then
          errmsg(0146,minab/12,i,HL6(i),HL6(1));
        endif;
      endif;

      if HL5Y(i) < 9997 then
        ldob = setlb(HL5M(i),HL5Y(i),0);
        udob = setub(HL5M(i),HL5Y(i),9999);
        if ldob > di then
          errmsg(0031,i);
        endif;
      else
        udob = di;
        ldob = 0;
      endif;

      if HL6(i) < 95 then
        { Lower bound of CMC date of birth }
        t = adjlba(ldob,udob,di,di,HL6(i));
        if t < 0 then
          errmsg(0031,i);
        else
         ldob = t
        endif;
       { Upper bound of CMC date of birth }
        t = adjuba(ldob,udob,di,di,HL6(i));
        if t < 0 then
          errmsg(0031,i);
        else
           udob = t
        endif;
      elseif HL6(i) = 95 then
        if !(HL5(i) in 1900:HH5Y-95) then
          errmsg(0031,i);
        endif;
      endif;

      { Check eligible women listed as eligible }
      if HL4(i) = 2 and HL6(i) in minage:maxage then
        if HL7(i) <> HL1(i) then
          errmsg(0101,i,HL4(i),HL6(i),HL7(i));
        endif;
      else
        if HL7(i) <> 0 then
          errmsg(0102,i,HL4(i),HL6(i),HL7(i));
        endif;
      endif;

      { Check child labor eligibility correct }
      {MICS5 update; one child 5 - 17 years randomly selected for Child Labour Module, this check not applicable}
      
      {if HL6(i) in chlabl:chlabu then
        if HL8(i) = 0 or HL8(i) = HL1(i) then
          errmsg(0121,i,HL4(i),HL6(i),HL8(i));
        elseif HL8(i) > HH11 then
          errmsg(0120,i,HL8(i),HH11);
        endif;
      else
        if HL8(i) <> 0 then
          errmsg(0122,i,HL4(i),HL6(i),HL8(i));
        endif;
      endif;}

      { Check that HH member identified by HL12 could be child's mother }
      if HL12(i) >= 1 then
        if valid(HL12(i)) and (HL4(HL12(i)) <> 2 or HL6(HL12(i)) < HL6(i)+(minab/12)) then
         {+EN} errmsg(0164,i,HL4(HL12(i)),HL6(HL12(i)),"mother",     "HL12",HL12(i) ); {EN+}
         {{SP} errmsg(0164,i,HL4(HL12(i)),HL6(HL12(i)),"de la madre","HL12",HL12(i) ); {SP}}
         {{FR} errmsg(0164,i,HL4(HL12(i)),HL6(HL12(i)),"de la mère", "HL12",HL12(i) ); {FR}}
        endif;
      endif;
      if HL12(i) >= 1 then
        if valid(HL12(i)) and HL12(i) > HH11 then
          {+EN} errmsg(0161,i,"mother's",HL12(i),HH11);      {EN+}
          {{ES} errmsg(0161,i,"de la madre",HL12(i),HH11);   {ES}}
          {{FR} errmsg(0161,i,"de la mère",HL12(i),HH11);    {FR}}
        elseif HL12(i) = HL1(i) then
          {+EN} errmsg(0162,i,"mother's",HL12(i),HL1(i));    {EN+}
          {{ES} errmsg(0162,i,"de la madre",HL12(i),HL1(i)); {ES}}
          {{FR} errmsg(0162,i,"de la mère",HL12(i),HL1(i));  {FR}}
        elseif HL15(i) <> 0 then
          if frstrun and HL12(i) <> HL15(i) then
            errmsg(0163,i,HL12(i),"HL15",HL15(i));
          endif;
        endif;
      endif;

      { Check that HH member identified by HL14 could be child's father }
      if HL14(i) >= 1 then
        if valid(HL14(i)) and (HL4(HL14(i)) <> 1 or HL6(HL14(i)) < HL6(i)+(minab/12)) then
         {+EN} errmsg(0164,i,HL4(HL12(i)),HL6(HL12(i)),"father",     "HL12",HL12(i) ); {EN+}
         {{SP} errmsg(0164,i,HL4(HL12(i)),HL6(HL12(i)),"del padre","HL12",HL12(i) );   {SP}}
         {{FR} errmsg(0164,i,HL4(HL12(i)),HL6(HL12(i)),"du père", "HL12",HL12(i) );    {FR}}
        endif;
      endif;
      if HL14(i) >= 1 then
        if valid(HL14(i)) and HL14(i) > HH11 then
          {+EN} errmsg(0161,i,"father's", HL14(i),HH11);   {EN+}
          {{ES} errmsg(0161,i,"del padre",HL14(i),HH11);   {ES}}
          {{FR} errmsg(0161,i,"du père",  HL14(i),HH11);   {FR}}
        elseif HL14(i) = HL1(i) then
          {+EN} errmsg(0162,i,"father's", HL14(i),HL1(i)); {EN+}
          {{ES} errmsg(0162,i,"del padre",HL14(i),HL1(i)); {ES}}
          {{FR} errmsg(0162,i,"du père",  HL14(i),HL1(i)); {FR}}
        endif;
      endif;

      { Check that relationship code to mother consistent }
      xmother = HL12(i);  { Line number of household member's mother }
      memhl3  = HL3(i);   { Household member's relationship to head of household }
      mline_valid = 0;    { 1 if mother's relationship to HH head consistent with child's relationship to HH head }
      if xmother <> notappl & xmother <> 0 & xmother <> 99 then
        momhl3 = HL3(xmother);  { Mother of household member's relationship to head of household }
        recode memhl3 : momhl3  => err;{ CHILD                    - MOTHER                              }
                    1 : 6       => 0;  { Head                     - Parent                              }
                    2 : 7       => 0;  { Spouse                   - Parent-in-law                       }
                    3 : 1,2     => 0;  { Son/Daughter             - Head/Spouse                         }
                    4 : 12,96   => 0;  { Son/Daughter In-Law      - Other Relative/Not Related          }
                    5 : 3,4     => 0;  { Grandchild               - Son/Daughter/Son or Daughter In-law }
                    6 : 12      => 0;  { Parent                   - Other Relative (Grandparent)        }
                    7 : 96      => 0;  { Parent-In-Law            - Not Related                         }
                    8 : 6       => 0;  { Brother/Sister           - Parent                              }
                    9 : 96      => 0;  { Brother/Sister-In-Law    - Not Related                         }
                   10 : 12      => 0;  { Uncle/Aunt               - Other Relative                      }
                   11 : 8       => 0;  { Niece/Nephew by blood    - Brother or Sister                   }
                   12 : 12      => 0;  { Other Relative           - Other Relative                      }
                   13 : 2,12,96 => 0;  { Adopted/Foster/Stepchild - Spouse/Other Relative/Not related   }
                   96 : 96      => 0;  { Not Related              - Not Related                         }
                   97 :         => 0;  { Inconsistent             - Any                                 }
                      : 97      => 0;  { Any                      - Inconsistent                        }
                98,99 : 99,98   => 0;  { Unknown                  - Unknown                             }
                      :         => 1;  { All others are incorrect                                       }
        endrecode;
        if err then     { Relationship not OK }
         {+EN}  errmsg(0171,i,memhl3,"mother","HL12",xmother,momhl3)  {EN+}
         {{ES}  errmsg(0171,i,memhl3,"ES","HL12",xmother,momhl3)      {ES}}
         {{FR}  errmsg(0171,i,memhl3,"la mère","HL12",xmother,momhl3)    {FR}}
        else
          mline_valid = 1;
        endif;
      endif;

      { For Son/Daughter/Head/Spouse/Grandchild/Sibling, try to find (potential) mother's line number, compare it to HL12 }
      if xmother <> notappl {& mline_valid = 0} & (memhl3 in 1,2,3,8) then
       err = 0;
        { Loop through household members }
        do j = 1 while j <= HH11
          { store relationship to HH head of current HH member }
          momhl3 = HL3(j);
          box memhl3 : momhl3 => rok;
                   1 : 6      => 1;   { Head            - Parent                              }
                   2 : 7      => 1;   { Spouse          - Parent-in-law                       }
                   3 : 1,2    => 1;   { Son/Daughter    - Head/Spouse                         }
                   5 : 3,4    => 1;   { Grandchild      - Son/Daughter/Son or Daughter In-Law }
                   8 : 6      => 1;   { Brother/Sister  - Parent                              }
                     :        => 0;
          endbox;
          if HL4(j) = 2 & rok then    { Found potential mother }
            if xmother <> j then      { But HL12 doesn't equal potential mother's line number }
             err = j;
           elseif xmother = j then
             err = 0;
             j = HH11; { break out of while loop }
            endif;
           endif;
        enddo;
        if err then
          {+EN} errmsg(0172,i,"mother",xmother,err); {EN+}
          {{ES} errmsg(0172,i,"ES",xmother,err);     {ES}}
          {{FR} errmsg(0172,i,"mère",xmother,err);   {FR}}
        endif;
      endif;

      { Check that relationship code to father consistent }
      xfather = HL14(i);  { Line number of household member's father             }
      memhl3 = HL3(i);    { Household member's relationship to head of household }
      fline_valid = 0;    { 1 if father's relationship to HH head consistent with child's relationship to HH head }
      if xfather <> notappl & xfather <> 0 & xfather <> 99 then
        dadhl3 = HL3(xfather);  { Father of household member's relationship to head of household }
        recode memhl3 : dadhl3  => err;{ CHILD                    - FATHER                             }
                    1 : 6       => 0;  { Head                     - Parent                              }
                    2 : 7       => 0;  { Spouse                   - Parent-in-law                       }
                    3 : 1,2     => 0;  { Son/Daughter             - Head/Spouse                         }
                    4 : 12,96   => 0;  { Son/Daughter In-Law      - Other Relative/Not Related          }
                    5 : 3,4     => 0;  { Grandchild               - Son/Daughter/Son or Daughter In-law }
                    6 : 12      => 0;  { Parent                   - Other Relative (Grandparent)        }
                    7 : 96      => 0;  { Parent-In-Law            - Not Related                         }
                    8 : 6       => 0;  { Brother/Sister           - Parent                              }
                    9 : 96      => 0;  { Brother/Sister-In-Law    - Not Related                         }
                   10 : 12      => 0;  { Uncle/Aunt               - Other Relative                      }
                   11 : 8       => 0;  { Niece/Nephew by blood    - Brother or Sister                   }
                   12 : 12      => 0;  { Other Relative           - Other Relative                      }
                   13 : 2,12,96 => 0;  { Adopted/Foster/Stepchild - Spouse/Other Relative/Not related   }
                   96 : 96      => 0;  { Not Related              - Not Related                         }
                   97 :         => 0;  { Inconsistent             - Any                                 }
                      : 97      => 0;  { Any                      - Inconsistent                        }
                98,99 : 99,98   => 0;  { Unknown                  - Unknown                             }
                      :         => 1;  { All others are incorrect                                       }                                    
        endrecode;
        if err then     { Relationship not OK }
          {+EN} errmsg(0171,i,memhl3,"father","HL14",xfather,dadhl3)  {EN+}
          {{ES} errmsg(0171,i,memhl3,"ES","HL14",xfather,dadhl3)      {ES}}
          {{FR} errmsg(0171,i,memhl3,"le père","HL14",xfather,dadhl3)    {FR}}
        else
          fline_valid = 1;
        endif;
      endif;

      { For Son/Daughter/Head/Spouse/Grandchild/Sibling, try to find (potential) father's line number, compare it to HL14 }
      if xfather <> notappl {& fline_valid = 0} & (memhl3 in 1,2,3,8) then
        { Loop through household members }
        do j = 1 while j <= HH11
          { store relationship to HH head of current HH member }
          dadhl3 = HL3(j);
          box memhl3 : dadhl3 => rok;
                   1 : 6      => 1;   { Head            - Parent                              }
                   2 : 7      => 1;   { Spouse          - Parent-in-law                       }
                   3 : 1,2    => 1;   { Son/Daughter    - Head/Spouse                         }
                   5 : 3,4    => 1;   { Grandchild      - Son/Daughter/Son or Daughter In-Law }
                   8 : 6      => 1;   { Brother/Sister  - Parent                              }
                     :        => 0;
          endbox;
          if HL4(j) = 1 & rok then    { Found potential father }
            if xfather <> j then      { But HL14 doesn't equal potential father's line number }
              err = j;
            elseif xfather = j then
              err = 0;
              j = HH11; { break out of while loop }
            endif;
          endif;
        enddo;
        if err then
          {+EN} errmsg(0172,i,"father",xfather,err)  {EN+}
          {{ES} errmsg(0172,i,"ES",xfather,err)      {ES}}
          {{FR} errmsg(0172,i,"père",xfather,err)    {FR}}
        endif;
      endif;

      i = i + 1
    enddo;

    { Education module - MODED }

    i = 1;
    while i <= noccurs(MODED_EDT) do {loop through the education module }

      { Check consistency of highest level and grade }
      if ED4A(i) <> notappl then
        lev = ED4A(i);
        grd = ED4B(i);
        recode lev  : grd         => err; { Fix maximum grade for each possible level }
                    : 97,98,99    => 0;   { Inconsistent, missing, DK grade }
                  0 : 0-4         => 0;   { Preschool}
                  1 : 0-6         => 0;   { Primary }
                  2 : 0-6         => 0;   { Secondary }
                  3 : 0-5         => 0;   { Higher }
                  6 : 0-6         => 0;   { Non-standard curriculum }
                  8 :             => 0;   { DK level }
                  9 :             => 0;   { Missing level }
                    :             => 1;
        endrecode;
        if err then
          errmsg(0090,i,"ED4A",lev,"ED4B",grd);
        endif;
      endif;

      { Check current level not higher than highest level }
      if ED6A(i) <= 3 and ED4A(i) <= 3 and ED6A(i) > ED4A(i) then
        errmsg(0091,i,ED6A(i),ED4A(i));
      endif;

      { Check consistency of current level and grade }
      if ED6A(i) <> notappl then
        lev = ED6A(i);
        grd = ED6B(i);
        recode  lev : grd         => err; { Fix maximum grade for each possible level }
                    : 97,98,99    => 0;   { Inconsistent, missing, DK grade }
                  0 : 0-4         => 0;   { Preschool}
                  1 : 0-6         => 0;   { Primary }
                  2 : 0-6         => 0;   { Secondary }
                  3 : 0-5         => 0;   { Higher }
                  6 : 0-6         => 0;   { Non-standard curriculum }
                  8 :             => 0;   { DK level }
                  9 :             => 0;   { Missing level }
                    :             => 1;
        endrecode;
        if err then
          errmsg(0090,i,"ED6A",lev,"ED6B",grd);
        endif;
      endif;

      { Check current grade not higher than highest grade }
      if (ED4A(i) = ED6A(i)) and valid(ED6B(i)) and valid(ED4B(i)) and ED6B(i) > ED4B(i)+2 then
        errmsg(0092,i,ED6B(i),ED4B(i));
      endif;

      { Check previous year's level not higher than highest level }
      if ED8A(i) <= 3 and ED4A(i) <= 3 and ED8A(i) > ED4A(i) then
        errmsg(0093,i,ED8A(i),ED4A(i));
      endif;

      { Check consistency of highest level and grade }
      if ED8A(i) <> notappl then
        lev = ED8A(i);
        grd = ED8B(i);
        recode  lev : grd         => err; { Fix maximum grade for each possible level }
                    : 97,98,99    => 0;   { Inconsistent, missing, DK grade }
                  0 : 0-4         => 0;   { Preschool}
                  1 : 0-6         => 0;   { Primary }
                  2 : 0-6         => 0;   { Secondary }
                  3 : 0-5         => 0;   { Higher }
                  6 : 0-6         => 0;   { Non-standard curriculum }
                  8 :             => 0;   { DK level }
                  9 :             => 0;   { Missing level }
                    :             => 1;
        endrecode;
        if err then
          errmsg(0090,i,"ED8A",lev,"ED8B",grd);
        endif;
      endif;

      { Check previous year's grade not higher than highest grade }
      if (ED4A(i) = ED8A(i)) and valid(ED8B(i)) and valid(ED4B(i)) and ED8B(i) > ED4B(i)+2 then
        errmsg(0094,i,ED8B(i),ED4B(i));
      endif;

      i = i + 1;
    enddo;

    { Water and sanitation module }

    { Check WS4's value divisible by 0 or 5 }
    if frstrun and WS4 < 995 and WS4%10 <> 0 and WS4%10 <> 5 then
      errmsg(9993,"WS4",WS4);
    endif;

    { Child labor module }

    { Check total hours worked not greater than 80 }
    { Check whether still needed....
    if frstrun and (NAtoZero(CL4) + NAtoZero(CL6) + NAtoZero(CL10) + NAtoZero(CL8) > 80) then
      errmsg(0201,i,CL4, CL6, CL10,CL8);
    endif;
    ...}
    

    { Child discipline module }

    { For households with children aged 2-14 }
    cnt = count(MODHL_EDT where HL6 in 2:14);
    { ... }    

     

    

  endif; { End complete household result }

PROC WMMNCH
  { *** Level 2 ***  Women - children under 5 - men  }

  { Woman questionnaire     }

  { Woman information panel }

  { Check date of interview }
  if WM6D <> notappl then
    recode WM6Y   :     WM6M        : WM6D => err;
        2009-2012 : 1,3,5,7,8,10,12 : 1-31 => 0;
        2009-2012 : 4,6,9,11        : 1-30 => 0;
        2009-2012 : 2               : 1-28 => 0;
             2012 : 2               : 1-29 => 0;
                  :                 :      => 1;
    endrecode;
    if err then
     {+EN} errmsg(0016,"Woman's",    WM6D,WM6M,WM6Y); {EN+}
     {{ES} errmsg(0016,"ES",         WM6D,WM6M,WM6Y); {ES}}
     {{FR} errmsg(0016,"de la famme",WM6D,WM6M,WM6Y); {FR}}
    endif;
    dd = (HH5Y*100 + HH5M)*100 + HH5D;
    ddw= (WM6Y*100 + WM6M)*100 + WM6D;
    ss = sysdate("yyyymmdd");
    if ddw >= ss or ddw < dd then
    {+EN} errmsg(0016,"Woman's",    WM6D,WM6M,WM6Y); {EN+}
    {{ES} errmsg(0016,"ES",         WM6D,WM6M,WM6Y); {ES}}
    {{FR} errmsg(0016,"de la famme",WM6D,WM6M,WM6Y); {FR}}
    endif;
    diwm = cmcode(WM6M,WM6Y);
    di = diwm;
  endif;

  { If woman's interview complete }
  if WM7 = 1 then

    { Check date of birth against date of interview }
    udob = diwm - minage*12;
    ldob = diwm - maxage*12 - 11;

    mindb = ldob;      { Minimum date of birth - women - used in BH imputation }
    maxdb = udob;      { Maximum date of birth - women - used in BH imputation }


    if WB1Y < 9997 then
      ldob = setlb(WB1M,WB1Y,0);
      udob = setub(WB1M,WB1Y,9999);
      if udob < diwm - maxage*12 - 11 or ldob > diwm - minage*12 then
        if (WM6M = WB1M) and (WB1Y - 50 = WM6Y) then
          if frstrun then
            errmsg(1001,WM6M,WM6Y,WB1M,WB1Y);
          endif;
        else
          errmsg(1001,WM6M,WM6Y,WB1M,WB1Y);
        endif;
      endif;
    endif;

    { Check age, date of birth and date of interview }
    { Lower bound of CMC date of birth               }
    t = adjlba(ldob,udob,diwm,diwm,WB2);
    if t < 0 then
      if (WM6M = WB1M) and (WB1Y - WM6Y = WB2 + 1) then
        if frstrun then
          errmsg(1003,WB2,WB1M,WB1Y,WM6M,WM6Y);
        endif;
      else
        errmsg(1003,WB2,WB1M,WB1Y,WM6M,WM6Y);
      endif;
    else
      ldob = t
    endif;
    { Upper bound of CMC date of birth }
    t = adjuba(ldob,udob,diwm,diwm,WB2);
    if t < 0 then
      if (WM6M = WB1M) and (WB1Y - WM6Y = WB2 + 1) then
        if frstrun then
          errmsg(1003,WB2,WB1M,WB1Y,WM6M,WM6Y);
        endif;
      else
        errmsg(1003,WB2,WB1M,WB1Y,WM6M,WM6Y);
      endif;
    else
      udob = t
    endif;

    { Check age against age in household }
    if frstrun and WB2 <> HL6(LN) then
      errmsg(1002,WB2,HL6(LN));
    endif;

    { Initialize event table }
    do i = 1 while i <= maxevent
      norder(i)  = default;     { Birth order of children }
      twincode(i)= default;     { Twin code for children }
      surv(i)    = default;     { Survival status for children }
      deathl(i)  = default;     { Age at death of child - lower limit }
      deathu(i)  = default;     { Age at death of child - upper limit }
      sflag(i)   = default;     { Status code flag }
      errflag(i) = default;     { Error flag }
      flagdth(i) = 0;           { Flag for age at death of the child }
    enddo;

    inUnion = ( MA1 in 1,2 );

    { Set up event table entry for date of birth of woman }
    nevents = 1;
    ismonth = valid(WB1M);
    isyear  = validyr(WB1Y);
    isage   = valid(WB2);
    if ismonth then
      smonth(1) = WB1M;
    else
      smonth(1) = 0;
    endif;
    box isyear : ismonth : isage => flag;
             1 :       1 :       => 1;
               :       1 :     1 => 2;
             1 :         :     1 => 3;
             1 :         :       => 5;
               :         :     1 => 6;
               :       1 :       => 7;
               :         :       => 8;
    endbox;
    if ignorey & flag = 3 & WB1Y + WB2 = WM6Y then
      flag = 4
    endif;
    sflag(1)   = flag;
    errflag(1) = notappl;

    { Initial ranges for CMC date of birth }
    if validyr(WB1Y) & (flag <> 4 | !doimp) then
      lcmcb = setlb( WB1M, WB1Y, 0 );
      ucmcb = setub( WB1M, WB1Y, 9999 );
      if lcmcb < mindb then
        if ucmcb < mindb then
          errmsg( 1063, WB1M, WB1Y, WM6M, WM6Y, cmc2m(mindb), cmc2y(mindb), cmc2m(maxdb), cmc2y(maxdb) );
          errflag(1) = default;
          ucmcb = mindb;
        endif;
        lcmcb = mindb;
      endif;
      if ucmcb > maxdb then
        if lcmcb > maxdb then
          errmsg( 1063, WB1M, WB1Y, WM6M, WM6Y, cmc2m(mindb), cmc2y(mindb), cmc2m(maxdb), cmc2y(maxdb) );
          errflag(1) = default;
          lcmcb = maxdb;
        endif;
        ucmcb = maxdb;
      endif
    else
      lcmcb = mindb;
      ucmcb = maxdb;
    endif;

    type(1) = 1;
    interv(1) = 0;
    cdelay(1) = 0;

    { Adjust ranges for CMC date of birth based on age }
    if WB2 in minai:maxai then
      t = ndjlba( lcmcb, ucmcb, diwm, diwm, WB2 );
      if t < 0 then
        errmsg( 1062, WB1M, WB1Y, lcmcb, ucmcb, WB2, WM6M, WM6Y, diwm );
        errflag(1) = default;
      else
        lcmcb = t;
      endif;
      t = adjuba( lcmcb, ucmcb, diwm, diwm, WB2 );
      if t < 0 then
        errmsg( 1062, WB1M, WB1Y, lcmcb, ucmcb, WB2, WM6M, WM6Y, diwm );
        errflag(1) = default;
      else
        ucmcb = t;
      endif;
      x = diwm - (WB2*12 + 11);
      if lcmcb < x & x <= ucmcb then
        lcmcb = x
      endif
    endif;

    { For month only without year, make adjustment }
    if ismonth & !isyear then
      x = int((lcmcb - 1)/12) * 12 + smonth(1);
      if x < lcmcb then
        x = x + 12
      endif;
      if x > ucmcb then
        if frstrun then
          errmsg( 1064, smonth(1), lcmcb, ucmcb, cmc2m(lcmcb), cmc2y(lcmcb), cmc2m(ucmcb), cmc2y(ucmcb))
        endif;
      else
        lcmcb = x
      endif;
      x = int((ucmcb - 1)/12) * 12 + smonth(1);
      if x > ucmcb then
        x = x - 12
      endif;
      if x < lcmcb then
        if frstrun then
          errmsg( 1064, smonth(1), lcmcb, ucmcb, cmc2m(lcmcb), cmc2y(lcmcb), cmc2m(ucmcb), cmc2y(ucmcb) )
        endif;
      else
        ucmcb = x
      endif;
    endif;

    { Date of marriage }
    everUnion = ( MA1 in 1,2 | MA5 in 1,2 );
    chadj = 1;                     { Adjustment for children in event table }
    if everUnion then              { added to line number of child          }
      chadj = 2;
      nevents = nevents + 1;
      ismonth = valid(MA8M);
      isyear  = validyr(MA8Y);
      isage   = valid(MA9);
      if ismonth then
        smonth(2) = MA8M;
      else
        smonth(2) = 0;
      endif;
      box isyear : ismonth : isage => flag;
               1 :       1 :       => 1;
                 :       1 :     1 => 2;
               1 :         :     1 => 3;
               1 :         :       => 5;
                 :         :     1 => 6;
                 :       1 :       => 7;
                 :         :       => 8;
      endbox;
      sflag(2)   = flag;
      errflag(2) = notappl;
      type(2)    = 2;
      { No year of marriage given, check if age given }
      if flag in 7,8 then
        if frstrun then errmsg( 1935, MA9, MA8M, MA8Y ) endif;
      endif;

      { Initial ranges for date  of marriage }
      if validyr(MA8Y) then
        lcmcm = setlb( MA8M, MA8Y, 0 );
        ucmcm = setub( MA8M, MA8Y, 9999 );
        if ucmcm > diwm then ucmcm = diwm endif;
      else
        lcmcm = lcmcb + minam;
        ucmcm = diwm;
      endif;

      { Adjust ranges for date of marriage based on age at marriage }
      if valid(MA9) then

        { Adjust functions used with dates upside down to allow   }
        { adjustment of date of marriage based on age at marriage }
        { rather than adjusting date of birth                     }
        t = adjuba( diwm-ucmcm, diwm-lcmcm, diwm-ucmcb, diwm-lcmcb, MA9 );
        if t < 0 then
          errmsg( 1932, MA9, MA8M, MA8Y, WM6M, WM6Y, WB2, WB1M, WB1Y );
          errflag(2) = default;
        else
          lcmcm = diwm-t;
        endif;
        t = ndjlba( diwm-ucmcm, diwm-lcmcm, diwm-ucmcb, diwm-lcmcb, MA9 );
        if t < 0 then
          errmsg( 1932, MA9, MA8M, MA8Y, WM6M, WM6Y, WB2, WB1M, WB1Y );
          errflag(2) = default;
        else
          ucmcm = diwm-t;
        endif;

      { Adjust ranges for date of birth based on age at marriage }
        if errflag(2) <> default then
          t = ndjlba( lcmcb, ucmcb, lcmcm, ucmcm, MA9 );
          if t < 0 then
            errmsg( 1932, MA9, MA8M, MA8Y, WM6M, WM6Y, WB2, WB1M, WB1Y );
            errflag(2) = default;
          else
            lcmcb = t;
          endif;
          t = adjuba( lcmcb, ucmcb, lcmcm, ucmcm, MA9 );
          if t < 0 then
            errmsg( 1932, MA9, MA8M, MA8Y, WM6M, WM6Y, WB2, WB1M, WB1Y );
            errflag(2) = default;
          else
            ucmcb = t;
          endif
        endif

      endif;

      { Check date of marriage not after date of interview }
      if lcmcm > diwm then
        errmsg( 1930, MA9, WB2, WM6M, WM6Y, WB1M, WB1Y, MA8M, MA8Y );
        errflag(2) = default;
      elseif ucmcm > diwm then
        ucmcm = diwm
      endif;

      { For month only without year, make adjustment }
      if ismonth & !isyear then
        x = int((lcmcm - 1)/12) * 12 + smonth(2);
        if x < lcmcm then
          x = x + 12
        endif;
        if x > ucmcm then
          errmsg( 1926, smonth(2), lcmcm, ucmcm, cmc2m(lcmcm), cmc2y(lcmcm), cmc2m(ucmcm), cmc2y(ucmcm) );
        else
          lcmcm = x
        endif;
        x = int((ucmcm - 1)/12) * 12 + smonth(2);
        if x > ucmcm then
          x = x - 12
        endif;
        if x < lcmcm then
          errmsg( 1926, smonth(2), lcmcm, ucmcm, cmc2m(lcmcm), cmc2y(lcmcm), cmc2m(ucmcm), cmc2y(ucmcm) );
        else
          ucmcm = x
        endif;
      endif;

      { Adjust for minimum age at marriage }
      t = adjlbi( lcmcb, ucmcb, lcmcm, ucmcm, minam );
      if t < 0 then
        if frstrun then errmsg( 1921, int(minam/12), WB1M, WB1Y, WB2, MA8M, MA8Y, MA9 ) endif;
        errflag(2) = default;
      else
        lcmcm = t;
      endif;

      { Check date of marriage not after date of interview }
      if lcmcm > diwm then
        errmsg( 1920, MA8M, MA8Y, MA9, WM6M, WM6Y, WB1M, WB1Y, WB2 );
        errflag(2) = default;
      elseif ucmcm > diwm then
        ucmcm = diwm
      endif;

      { Use age at first sex as lower bound for date of marriage if no info. }
      if valid(SB1) & SB1 <> 0 & SB1 <= maxai then
        t = adjlbi( lcmcb, ucmcb, lcmcm, ucmcm, SB1*12 );
        if t < 0 then
          if frstrun then errmsg( 1993, SB1, MA8M,MA8Y, MA9, WB1M,WB1Y ) endif;
          fsexflag = 6;
        else
          lcmcm = t
        endif
      endif;

      lcmc(2) = lcmcm;
      ucmc(2) = ucmcm;
      interv(2) = minam;
      cdelay(2) = 0;

    endif;

    lcmc(1) = lcmcb;
    ucmc(1) = ucmcb;

    { Children ever born }
    ceb = 0;             { Only set below when implementing a birth history }

    { Following codes assumes the implementation of a birth history }
    {{BH}
    ceb = CM10;
    { Check to ensure that all children listed in HH are listed in BH }
    for i in MODHL_EDT do
      if HL12 = LN & count(MODBH_EDT where BH8 = i) <> 1 then
        errmsg( 1185, i )
      endif;
    enddo;

    for i in MODBH_EDT do
      j = BH8;
      if valid(j) & j <> 0 then
        if persline(j) then
          errmsg( 1200, i, persline(j), mothline(j) );
        else
          persline(j) = j;
          mothline(j) = LN;
        endif;
      endif;
    enddo;

    { Birth history }
    for i in MODBH_EDT do
      nevents    = nevents + 1;
      j          = nevents;
      type(j)    = 3;
      norder(j)  = i;
      twincode(j)= 0;
      surv(j)    = BH5;
      deathl(j)  = 0;
      deathu(j)  = 0;
      smonth(j)  = 0;

      isyear = 0; ismonth = 0; isage = 0;
      if valid(BH4M) then
        smonth(j) = BH4M;
        ismonth = 1
      endif;
      { Initialize logical ranges for date of birth of child }
      if validyr(BH4Y) then
        isyear = 1;
        lcmc(j) = setlb( BH4M, BH4Y, 0 );
        ucmc(j) = setub( BH4M, BH4Y, 9999 );
      else
        lcmc(j) = mindb + minab;
        ucmc(j) = diwm;
      endif;
      if valid(BH6) then
        isage = 1;
      endif;

      box isyear : ismonth : isage => flag;
               1 :       1 :       => 1;
                 :       1 :     1 => 2;
               1 :         :     1 => 3;
               1 :         :       => 5;
                 :         :     1 => 6;
                 :       1 :       => 7;
                 :         :       => 8;
      endbox;
      if ignorey & flag = 3 & BH4Y + BH6 = WM6Y then
        flag = 4;
        lcmc(j) = mindb + minab;
        ucmc(j) = diwm;
      endif;
      sflag(j)   = flag;
      errflag(j) = notappl;

      { Set up twin code variable coded as follows:
        0 - Single birth
        1 - 1st of multiple
        2 - 2nd of multiple
        3 - 3rd of multiple
        etc.
        This variable easier to use in controlling twins.
      }

      if BH2 = 1 then          { Single birth }
        twincode(j) = 0
      elseif BHLN = 1 then     { First birth }
        twincode(j) = 1
      else
        twincode(j) = twincode(j-1) + 1
      endif;

      { Update twin code variable in case of two pairs of twins together }
      { Twincode is 0-Single birth, 1-1st of multiple, 2-2nd of multiple, dicts. }
      if BH2 = 2 & i > 2 & twincode(j-1) >= 2 then
        if (BH4Y <> BH4Y(i-1) | BH4M <> BH4M(i-1)) then
          twincode(j) = 1
        endif
      endif;


      { Adjust ranges for date of birth of child based on age of child }
      if BH5 = 1 then
        { Living children }
        if valid(BH6) then
          { Lower bound of CMC date of birth }
          t = ndjlba( lcmc(j), ucmc(j), diwm, diwm, BH6 );
          if t < 0 then
            errmsg( 1171, i, BH6, BH4M, BH4Y, WM6M, WM6Y );
            errflag(j) = default;
          else
            lcmc(j) = t;
          endif;
          { Upper bound of CMC date of birth }
          t = adjuba( lcmc(j), ucmc(j), diwm, diwm, BH6 );
          if t < 0 then
            errmsg( 1171, i, BH6, BH4M, BH4Y, WM6M, WM6Y );
            errflag(j) = default;
          else
            ucmc(j) = t;
          endif;
          x = di - (BH6*12 + 11);
          if lcmc(j) < x & x <= ucmc(j) then
            lcmc(j) = x
          endif
        endif;

      else

        { Children who have died }
        agedu = BH9U;         { age at death - units }
        agedn = BH9N;         { age at death - number }

        { Check maximum and mininum values }
        box agedu => maxd;
                1 => 30;       { 0-30 days   }
                2 => 23;       { 1-23 months }
                3 => 40;       { 2-40 years  }
                  => 99;
        endbox;
        mind = agedu-1;
        if agedu = 9 then agedu = 0 endif;
        if !agedn in mind:maxd then
          if frstrun then errmsg( 1191, i, agedn, mind, maxd, agedu ) endif;
          flagdth(i+chadj) = 6;
        endif;

        { Check age at death plausible considering date of birth }
        box agedu: agedn   => aged;
                 : missing => 999;
                 : >= 97   => 999;
               1 :         => int(agedn/30);
               2 :         => agedn;
               3 :         => agedn*12;
                 :         => 999;
        endbox;
        if aged <> 999 then
          if lcmc(j) + aged > diwm then
            if frstrun then errmsg( 1192, i, BH9U, BH9N, BH4M, BH4Y, WM6M, WM6Y ) endif;
            errflag(j) = default;
            flagdth(j) = 1;
          elseif ucmc(j) + aged > diwm then
            ucmc(j) = diwm - aged
          endif;
          { Now make age at death as late as possible for those with }
          { age at death reported in years                           }
          deathl(j) = aged;               { lower limit of age at death }
          deathu(j) = aged;               { upper limit of age at death }
          if agedu = 3 then               { Age at death reported in years }
            deathu(j) = aged + 11;
            if flagdth(j) = 0 & lcmc(j) + deathu(j) > di then
              deathu(j) = di - lcmc(j)
            endif;
          endif
        else
          deathl(j) = 0;
          deathu(j) = diwm - lcmc(j);
        endif
      endif;

      { For month only without year, make adjustment }
      if ismonth & !isyear then
        x = int((lcmc(j) - 1)/12) * 12 + smonth(j);
        if x < lcmc(j) then
          x = x + 12
        endif;
        if x > ucmc(j) then
          if frstrun then
            errmsg( 1172, i, smonth(j), lcmc(j), ucmc(j), cmc2m(lcmc(j)), cmc2y(lcmc(j)), cmc2m(ucmc(j)), cmc2y(ucmc(j)) )
          endif;
        else
          lcmc(j) = x
        endif;
        x = int((ucmc(j) - 1)/12) * 12 + smonth(j);
        if x > ucmc(j) then
          x = x - 12
        endif;
        if x < lcmc(j) then
          if frstrun then
            errmsg( 1172, i, smonth(j), lcmc(j), ucmc(j), cmc2m(lcmc(j)), cmc2y(lcmc(j)), cmc2m(ucmc(j)), cmc2y(ucmc(j)) )
          endif;
        else
          ucmc(j) = x
        endif;
      endif;

      { Check first birth not before age at first sex }
      if i = 1 then
        if valid(SB1) & SB1 <> 0 & SB1 <= maxai then
          t = adjlbi( lcmc(1), ucmc(1), lcmc(j), ucmc(j), SB1*12+minpd );
          if t < 0 then
            if frstrun then errmsg( 1991, SB1, BH4M, BH4Y, WB1M, WB1Y )endif;
            fsexflag = 3;
            t = adjlbi( lcmc(1), ucmc(1), lcmc(j), ucmc(j), (SB1-1)*12+minpd );
            if t < 0 then
              fsexflag = 2
            endif
          else
            lcmc(j) = t;
          endif
        { Check minimum birth interval after marriage }
        elseif SB1 = 95 & everUnion then
          t = adjlbi( lcmc(2), ucmc(2), lcmc(j), ucmc(j), minpd );
          if t < 0 then
            if frstrun then errmsg( 1994, SB1, MA8M, MA8Y, BH4M, BH4Y, MA9 ) endif;
            fsexflag = 5;
          else
            lcmc(j) = t;
          endif
        endif
      endif;

      { Set minimum intervals }
      cdelay(j) = 0;
      if twincode(j) > 1 then
        interv(j) = 0;
      else
        if i = 1 then             { first birth }
          if j = 3 then           { woman ever married }
            interv(j) = 0
          else                    { woman never married }
            interv(j) = minab
          endif
        else                      { subsequent births }
          interv(j) = minpd;      { minimum pregnancy duration }
          cdelay(j) = mincd;      { minimum conception delay }
        endif
      endif;

      if BH8 > 0 then
        { check this code still works ???? }
        if count(MODBH_EDT where BH8 = BH8(i) & BHLN <> BHLN(i)) then
          errmsg( 1184, i, BH8(i) );
        endif;

        { Check mother's line number agrees with line number of mother in household questionnaire }
        if HL11(BH8(i)) <> notappl & HL12(BH8(i)) <> LN then
          errmsg( 1182, i, HL12(BH8(i)), LN );
        endif;

        { Check sex of child against sex in household questionnaire }
        if BH3(i) <> HL4(BH8(i)) then
          errmsg( 1141, i, BH3(i), HL4(BH8(i)) );
        endif;

        { Check age of child against age in household questionnaire }
        if valid(BH6(i)) & valid(HL6(BH8(i))) then
          x = BH6(i) - HL6(BH8(i));
          if !x in (-1):1 then
            errmsg( 1173, i, BH6(i), HL6(BH8(i)) );
          endif
        endif;

      endif;

    enddo;
    { Code above only for birth history editing/imputation }
    {BH}}

    { Date of conception                                                          }
    { This does not really work since duration of current pregnancy is not asked. }
    currpreg = (CP1 = 1);
    if currpreg then
      nevents = nevents + 1;
      errflag(nevents) = notappl;
      smonth(nevents) = 0;
      sflag(nevents) = 8;
      lcmc (nevents) = diwm - 9;
      ucmc (nevents) = diwm;
      norder(nevents) = ceb+1;
      type  (nevents) = 4;
      interv(nevents) = 0;
      if ceb then
        cdelay(nevents) = mincd   { minimum conception delay after last birth }
      else
        cdelay(nevents) = 0
      endif;
    endif;

    { Preparing for imputation }
    { Equalizing twins }
    umin = 9999;
    lmax = 0;
    ntwin = 0;
    do i = chadj+1 while i <= ceb+chadj
      j = i + 1;
      if special(twincode(j)) | twincode(j) <= 1 then
        if umin < lmax then
          errmsg( 9920, j-1, lmax, umin, cmc2m(lmax), cmc2y(lmax), cmc2m(umin), cmc2y(umin) )
        else
          do k = 1 while k <= ntwin
            lcmc(j-k) = lmax;
            ucmc(j-k) = umin;
          enddo;
        endif;
        umin = 9999;
        lmax = 0;
        ntwin = 0;
      endif;
      if !special(twincode(j)) & twincode(j) >= 1 then
        ntwin = ntwin + 1;
        if lcmc(j) > lmax then lmax = lcmc(j) endif;
        if ucmc(j) < umin then umin = ucmc(j) endif;
      endif;
    enddo;

    { Date of interview event and open birth interval }
    nevents = nevents + 1;
    lcmc(nevents)    = diwm;
    ucmc(nevents)    = diwm;
    type(nevents)    = 6;
    sflag(nevents)   = 1;
    smonth(nevents)  = 0;
    errflag(nevents) = notappl;

    if currpreg then
      interv(nevents) = mincd;
    else
      interv(nevents) = 0
    endif;
    cdelay (nevents) = 0;

    if ceb then
      { forward checking of date of first birth }
      i = chadj + 1;
      t = adjlbi( lcmc(1), ucmc(1), lcmc(i), ucmc(i), minab );
      if t < 0 then
        errmsg( 9902, 1, lcmc(1), ucmc(1), cmc2m(lcmc(1)), cmc2y(lcmc(1)), cmc2m(ucmc(1)),
                      cmc2y(ucmc(1)), i, lcmc(i), ucmc(i), cmc2m(lcmc(i)), cmc2y(lcmc(i)),
                      cmc2m(ucmc(i)), cmc2y(ucmc(i)), minab );
        errflag(i) = default;
      else
        lcmc(i) = t;
        { backward checking of date of first birth }
        t = adjubi( lcmc(1), ucmc(1), lcmc(i), ucmc(i), minab );
        if t < 0 then
          errmsg( 9902, i, lcmc(i), ucmc(i), cmc2m(lcmc(i)), cmc2y(lcmc(i)), cmc2m(ucmc(i)),
                        cmc2y(ucmc(i)), 1, lcmc(1), ucmc(1), cmc2m(lcmc(1)), cmc2y(lcmc(1)),
                        cmc2m(ucmc(1)), cmc2y(ucmc(1)), minab );
          errflag(1) = default;
        else
          ucmc(1) = t;
        endif;
      endif;
    endif;

    { forward checking of minimum interval }
    do i = 1 while i <= nevents - 1
      j = i + 1;
      t = adjlbi( lcmc(i), ucmc(i), lcmc(j), ucmc(j), interv(j)+cdelay(j) );
      if t < 0 then
        if type(i) = 2 & type(j) <> 6 then
          if SB1 = 95 & fsexflag = 0 then
            fsexflag = 5
          endif
        else
          x1 = type(i);
          x2 = type(j);
          box x1 : x2 => eno;
               1 :  2 => 9901;    { Between birth and first union }
               1 :  3 => 9902;    { Between birth and first child }
               2 :  3 => 9903;    { Between union and first child }
             1,2 :    => 9904;    { Between birth or union and other events }
               3 :  3 => 9905;    { Between children }
               3 :    => 9906;    { Between last child and later events }
                 :    => 9907;    { Between other events }
          endbox;
          if eno = 9905 then
            errmsg( eno, norder(i), i, lcmc(i), ucmc(i), cmc2m(lcmc(i)), cmc2y(lcmc(i)),
                         cmc2m(ucmc(i)), cmc2y(ucmc(i)), norder(j), j, lcmc(j), ucmc(j),
                         cmc2m(lcmc(j)), cmc2y(lcmc(j)), cmc2m(ucmc(j)), cmc2y(ucmc(j)),
                         interv(j)+cdelay(j) );
          else
            errmsg( eno, i, lcmc(i), ucmc(i), cmc2m(lcmc(i)), cmc2y(lcmc(i)), cmc2m(ucmc(i)),
                         cmc2y(ucmc(i)), j, lcmc(j), ucmc(j), cmc2m(lcmc(j)), cmc2y(lcmc(j)),
                         cmc2m(ucmc(j)), cmc2y(ucmc(j)), interv(j)+cdelay(j) );
          endif;
          errflag(j) = default;
        endif;
      else
        lcmc(j) = t;
      endif;
    enddo;

    { backward checking of minimum interval }
    do i = nevents while i >= 2 by (-1)
      j = i - 1;
      t = adjubi( lcmc(j), ucmc(j), lcmc(i), ucmc(i), interv(i)+cdelay(i) );
      if t < 0 then
        if type(j) = 2 & type(i) <> 6 then
          if SB1 = 95 & fsexflag = 0 then        { First sex when married }
            fsexflag = 5
          endif
        else
          x1 = type(j);
          x2 = type(i);
          box x1 : x2 => eno;
               1 :  2 => 9901;    { Between birth and first union }
               1 :  3 => 9902;    { Between birth and first child }
               2 :  3 => 9903;    { Between union and first child }
             1,2 :    => 9904;    { Between birth or union and other events }
               3 :  3 => 9905;    { Between children }
               3 :    => 9906;    { Between last child and later events }
                 :    => 9907;    { Between other events }
          endbox;
          if eno = 9905 then
            errmsg( eno, norder(i), i, lcmc(i), ucmc(i), cmc2m(lcmc(i)), cmc2y(lcmc(i)),
                         cmc2m(ucmc(i)), cmc2y(ucmc(i)), norder(j), j, lcmc(j), ucmc(j),
                         cmc2m(lcmc(j)), cmc2y(lcmc(j)), cmc2m(ucmc(j)), cmc2y(ucmc(j)),
                         interv(i)+cdelay(i) );
          else
            errmsg( eno, i, lcmc(i), ucmc(i), cmc2m(lcmc(i)), cmc2y(lcmc(i)), cmc2m(ucmc(i)),
                         cmc2y(ucmc(i)), j, lcmc(j), ucmc(j), cmc2m(lcmc(j)), cmc2y(lcmc(j)),
                         cmc2m(ucmc(j)), cmc2y(ucmc(j)), interv(i)+cdelay(i) );
          endif;
          errflag(j) = default;
        endif;
      else
        ucmc(j) = t;
      endif;
    enddo;

    { Sexual Intercourse }
    { checking of time since last sex with open interval }
    box SB3U : SB3N => lsex;
              :missing=> 0;
              : 97-98 => 0;
{           9 :    96 => -1;    code no longer used  }
            0 :       => -1;
            1 :       => int(SB3N/30);
            2 :       => int(SB3N/4.3);
            3 :       => SB3N;
            4 :       => SB3N*12;
              :       => 0;
    endbox;

    if lsex >= 0 then                     { last sex reported }
      if ceb then
        i = ceb+chadj;
        t = adjubi( lcmc(i), ucmc(i), diwm, diwm, lsex );
        if t < 0 then
          if lsex then
            if frstrun then
              errmsg( 1953, ceb, i, lcmc(i), ucmc(i), cmc2m(lcmc(i)), cmc2y(lcmc(i)),
                            cmc2m(ucmc(i)), cmc2y(ucmc(i)), diwm, WM6M, WM6Y, SB3U, SB3N )
            endif;
            lsexflag = 1;
          endif
        else
          ucmc(i) = t;
          if SB3U = 4 then
            t = adjubi( lcmc(i), ucmc(i), diwm, diwm, lsex+11 );
          endif;
        endif;
      endif;
    else                          { special responses to last sex }
    { This code is no longer needed, but is left here in case code of 96 is reinstated in a country }
      {
      if SB3N = 96 then          { last sex before last birth }
        if !CM10 then             { never given birth }
          if frstrun then errmsg( 1958, SB3U, SB3N, CM10 ) endif;
          lsexflag = 4;
        endif;
        if currpreg then          { currently pregnant, so since birth }
          if frstrun then errmsg( 1952, SB3U, SB3N, CP1 ) endif;
          lsexflag = 5
        endif;
      endif
      }
    endif;

    if SB1 = 0 then              { Never had sexual intercourse }
      if CM10 | CP1 <> 2 then   { but has had children or is/possibly pregnant }
        errmsg( 1950, SB1, CM10, CP1 );
      endif;
      if MA1 in 1,2 | MA5 in 1,2 then        { Ever in union }
        if frstrun then errmsg( 1951, SB1, MA1, MA5 ) endif
      endif;
    endif;

    { Equalizing twins }
    umin = 9999;
    lmax = 0;
    ntwin = 0;
    do i = 1 while i <= ceb+chadj
      j = i + 1;
      if special(twincode(j)) | twincode(j) <= 1 then
        if umin < lmax then
          errmsg( 9920, j-1, lmax, umin, cmc2m(lmax), cmc2y(lmax), cmc2m(umin), cmc2y(umin) )
        else
          do k = 1 while k <= ntwin
            lcmc(j-k) = lmax;
            ucmc(j-k) = umin;
          enddo;
        endif;
        umin = 9999;
        lmax = 0;
        ntwin = 0;
      endif;
      if !special(twincode(j)) & twincode(j) >= 1 then
        ntwin = ntwin + 1;
        if lcmc(j) > lmax then lmax = lcmc(j) endif;
        if ucmc(j) < umin then umin = ucmc(j) endif;
      endif;
    enddo;

    { Preparation for imputation }
    if doimp then
      do i = 1 while i <= nevents-1
        if special(twincode(i)) | twincode(i) <= 1 then
          do j = nevents while j > i by (-1)
            if special(twincode(j)) | twincode(j) <= 1 then
              jinterv = 0;
              if j = i + 1 | (!special(twincode(j-1)) & i = j-twincode(j-1)) then
                jinterv = interv(j) + cdelay(j);
              endif;
              gap=ucmc(i)+jinterv-lcmc(j);
              if gap < 0 | lcmc(i) > lcmc(j) | ucmc(i) > ucmc(j) |
              (j = i+1 & errflag(i) = default & errflag(i+1) = default) then
                gap = 0
              endif;
              gap2 = int(gap/2);
              xgap = 0;
              if gap <> gap2*2 then xgap = 1 endif;
              ucmc(i) = ucmc(i) - gap2;
              lcmc(j) = lcmc(j) + gap2;
              if xgap = 1 then
                if ucmc(i) > lcmc(i) then
                  ucmc(i) = ucmc(i) - 1
                else
                  if ucmc(j) > lcmc(j) then
                    lcmc(j) = lcmc(j) + 1
                  else
                    if !everUnion | i <> 2 | j <> 3 then
                      errmsg( 9918, i, lcmc(i), ucmc(i), cmc2m(lcmc(i)), cmc2y(lcmc(i)),
                                    cmc2m(ucmc(i)), cmc2y(ucmc(i)), j, lcmc(j), ucmc(j),
                                    cmc2m(lcmc(j)), cmc2y(lcmc(j)), cmc2m(ucmc(j)),
                                    cmc2y(ucmc(j)), jinterv );
                      errflag(i) = default
                    endif
                  endif
                endif
              endif;
            endif;
          enddo;
        else
          lcmc(i) = lcmc(i-1);
          ucmc(i) = ucmc(i-1);
        endif;
      enddo;

    { Re-Adjust ranges for date of birth based on adjusted date/age at marriage }
      if everUnion & errflag(2) <> default & valid(MA9) then
        t = ndjlba( lcmc(1), ucmc(1), lcmc(2), ucmc(2), MA9 );
        if t < 0 then
          errmsg( 1934, MA9, MA8M, MA8Y, WM6M, WM6Y, WB2, WB1M, WB1Y );
          errflag(2) = default;
        else
          lcmc(1) = t;
        endif;
        t = adjuba( lcmc(1), ucmc(1), lcmc(2), ucmc(2), MA9 );
        if t < 0 then
          errmsg( 1934, MA9, MA8M, MA8Y, WM6M, WM6Y, WB2, WB1M, WB1Y );
          errflag(2) = default;
        else
          ucmc(1) = t;
        endif
      endif;

      { Imputation - Random }

      { Impute date of birth of respondent }
      if lcmc(1) > ucmc(1) then
        errmsg( 9919, 1, lcmc(1), ucmc(1), cmc2m(lcmc(1)), cmc2y(lcmc(1)), cmc2m(ucmc(1)), cmc2y(ucmc(1)) );
        cmc(1) = default
      elseif lcmc(1) = ucmc(1) then
        cmc(1) = lcmc(1)
      else
        cmc(1) = random(lcmc(1),ucmc(1))
      endif;
      { Fix imputed date if a month given }
      if smonth(1) & (smonth(1) <> ((cmc(1) - 1) % 12) + 1) then
        x = int((cmc(1) - 1) / 12) * 12 + smonth(1);
        if x > ucmc(1) then x = x - 12 endif;
        if x < lcmc(1) then x = x + 12 endif;
        if x <= ucmc(1) then
          cmc(1) = x
        else
          errmsg( 9921, 1, smonth(1), lcmc(1), ucmc(1), cmc2m(lcmc(1)), cmc2y(lcmc(1)),
                           cmc2m(ucmc(1)), cmc2y(ucmc(1)), cmc(1), cmc2m(cmc(1)), cmc2y(cmc(1)) );
        endif;
      endif;

      { Re-adjust date of marriage based on       }
      { imputed date of birth and age at marriage }
      if valid(MA9) then
        { Adjust functions used with dates upside down to allow   }
        { adjustment of date of marriage based on age at marriage }
        { rather than adjusting date of birth                     }
        t = adjuba( diwm-ucmc(2), diwm-lcmc(2), diwm-cmc(1), diwm-cmc(1), MA9 );
        if t < 0 then
          if errflag(2) <> default then
            errmsg( 1933, MA9, MA8M, MA8Y, WB1M, WB1Y, WM6M, WM6Y, WB2 );
            errflag(2) = default;
          endif
        else
          lcmc(2) = diwm-t;
        endif;
        t = ndjlba( diwm-ucmc(2), diwm-lcmc(2), diwm-cmc(1), diwm-cmc(1), MA9 );
        if t < 0 then
          if errflag(2) <> default then
            errmsg( 1933, MA9, MA8M, MA8Y, WB1M, WB1Y, WM6M, WM6Y, WB2 );
            errflag(2) = default
          endif
        else
          ucmc(2) = diwm-t
        endif;
      endif;

      { Imputation - Random }

      do i = 2 while i <= nevents
        if lcmc(i) > ucmc(i) then
          { Inconsistent date }
          cmc(i) = default;
          errmsg( 9919, i, lcmc(i), ucmc(i), cmc2m(lcmc(i)), cmc2y(lcmc(i)),
                           cmc2m(ucmc(i)), cmc2y(ucmc(i)) )
        elseif lcmc(i) = ucmc(i) then
          { Exact date }
          cmc(i) = lcmc(i)
        else
          { Imputed date }
          cmc(i) = random( lcmc(i), ucmc(i) );
          if i > chadj & i <= ceb+chadj & twincode(i) >= 1 then
            { Set same date for twins }
            do j = i+1 while j <= ceb+chadj & twincode(j) > twincode(i)
              lcmc(j) = cmc(i);
              ucmc(j) = cmc(i);
            enddo;
          endif;
        endif;

        { Fix imputed date if a month given }
        if smonth(i) & (smonth(i) <> ((cmc(i) - 1) % 12) + 1) then
          x = int((cmc(i) - 1) / 12) * 12 + smonth(i);
          if x > ucmc(i) then x = x - 12 endif;
          if x < lcmc(i) then x = x + 12 endif;
          if x <= ucmc(i) then
            cmc(i) = x
          else
            errmsg( 9921, i, smonth(i), lcmc(i), ucmc(i), cmc2m(lcmc(i)), cmc2y(lcmc(i)),
                             cmc2m(ucmc(i)), cmc2y(ucmc(i)), cmc(i), cmc2m(cmc(i)), cmc2y(cmc(i)) );
          endif;
        endif;

        { Impute age at death if needed, otherwise update hot deck }
        {{BH}
        if type(i) = 3 & BH5(norder(i)) = 2 then

          { Hot Deck entries: }
          { LSTDU: Only elements 1-10 are used, representing birth orders 1-9,10+ }
          { LSTDN: Elements  1-10: duration in days   for birth orders 1-9,10+ }
          {        Elements 11-20: duration in months for birth orders 1-9,10+ }
          {        Elements 21-30: duration in years  for birth orders 1-9,10+ }

          j = i;
          if i > 10 then j = 10 endif;

          if BH9U(norder(i)) = 9 | special(BH9U(norder(i))) then
            du = lstdu(j);
            dn = lstdn(10*(du-1)+j);
            flagdth(i) = 8;
          else
            du = BH9U(norder(i));
            if valid(BH9N(norder(i))) then
              dn = BH9N(norder(i));
            else
              dn = lstdn(10*(du-1)+j);
              flagdth(i) = 7
            endif;
            lstdu(j) = du;
            lstdn(10*(du-1)+j) = dn;
          endif;
          box du => dmonths;
               1 => int(dn/30);
               2 => dn;
               3 => dn*12;
                 => dn;
          endbox;
          if dmonths < deathl(i) | dmonths > deathu(i) then
            if flagdth(i) = 7 | flagdth(i) = 8 |
               (du = 3 & dmonths < deathl(i) & dmonths+11 >= deathl(i)) then
              dmonths = deathl(i)
            endif
          endif;
          deathl(i) = dmonths;
          deathu(i) = dmonths;
        endif;
        {BH}}
      enddo;

      WB1C = cmc(1);                      { CMC date of birth }
      WB1F = sflag(1);                    { Flag for date of birth }
      WB2C = int( (diwm-WB1C)/12 );       { Computed age of respondent }
      if everUnion then
        MA8C = cmc(2);                   { CMC date of first union }
        MA8F = sflag(2);                 { Flag for date of first union }
        MA9C = int( (cmc(2)-cmc(1))/12 );{ Computed age at first union }
      endif;
      {{BH}
      do i = 1 while i <= ceb
        j = i + chadj;
        BH4C(i) = cmc(j);                { CMC date of birth of child }
        BH4F(i) = sflag(j);              { Flag for date of birth of child }
        if BH5(i) = 2 then
          BH9C(i) = deathl(j);           { Imputed age at death }
          BH9F(i) = flagdth(j);          { Flag for age at death }
        endif;
      enddo;
      {BH}}
    endif;      { end of imputation if no errors }

    { Check for errors and display event table }
    e = ( !doimp );
    do i = 1 while i <= nevents
      ETsuppress = ( !frstrun & type(i) = 5 );
      if !ETsuppress & ( errflag(i) = default |
         !doimp & frstrun & ( flagdth(i)) ) then
        e = 1
      endif;
    enddo;
    {{BH}
    if e then
      write( " " );
      write( "Cluster %03d    Household %03d      Woman's Line %02d", HH1, HH2, LN );
      write( " " );
      write( "                         Minimum       Maximum         Con   Age   ");
      write( "Ix  T Ord  M  S  F  E   Date    CMC   CMC   Date   Int cep  death f");
      { Type of event
        1       Date of birth of respondent
        2       Date of marriage
        3       Date of birth of children
        4       Date of conception of current pregnancy
        5       Date of sterilization/start of contraceptive use
        6       Date of interview
      }
      do i = 1 while i <= nevents
        if type(i) = 3 & surv(i) = 2 then
          xdeath = BH9U(norder(i))*100;
          if BH9N(norder(i)) = missing then
            xdeath = xdeath+99
          else
            xdeath = xdeath+BH9N(norder(i))
          endif;
          sdeath = edit("ZZ999",xdeath);
        else
          xdeath = notappl;
          sdeath = "     ";
        endif;
        xdatemin = ((lcmc(i)-1)%12 + 1)*10000 + int((lcmc(i)-1)/12)+1900;
        xdatemax = ((ucmc(i)-1)%12 + 1)*10000 + int((ucmc(i)-1)/12)+1900;
        if errflag(i) = default then
          asterisk = "*"
        else
          asterisk = " ";
        endif;
        if type(i) = 3 then
          write( "%2d%3d%4d%3d%3d%3d%3s%8d%6d%6d%8d%5d%3d%5s%3d",
                  i, type(i), norder(i),   twincode(i), surv(i),    sflag(i),
                  asterisk,   xdatemin,    lcmc(i),     ucmc(i),    xdatemax,
                  interv(i),  cdelay(i),   sdeath,     flagdth(i) );
        elseif type(i) = 5 then
          write( "%2d%3d%7s%3d%3d%3s%8d%6d%6d%8d%5d",
                  i, type(i), spaces,      surv(i),     sflag(i),    asterisk,    xdatemin,    lcmc(i),
                  ucmc(i),    xdatemax,    interv(i) );
        else
          write( "%2d%3d%10s%3d%3s%8d%6d%6d%8d%5d",
                  i, type(i), spaces,      sflag(i),    asterisk,    xdatemin,    lcmc(i),
                  ucmc(i),    xdatemax,    interv(i) );
        endif;
      enddo;

      lsex = SB3U*100;                   { Last sex }
      if SB3N = missing then
        lsex = lsex+99
      else
        lsex = lsex+SB3N
      endif;
      fsex = SB1;                        { First sex }
      write( " " );
      write( "Last sex: %03d       Age at first sex:  %02d",
              lsex, fsex );
      write( "Flag      %3d                          %2d",
              lsexflag, fsexflag );
    endif;

    {BH}}

    if frstrun then
      { Check school attendance against value in household }
      { Check whether needed...
      if WB3 <> ED3(LN) and ED4(LN) <> 0 then
        errmsg(1011,ED3(LN),WB3);
      endif;
      }

      { If ever attended school }
      if WB3 = 1 then
        { Check highest level against value in household }
        if WB4 <> ED4A(LN) then
          errmsg(1012,ED4A(LN),WB4);
        endif;

        { Check highest grade against value in household }
        if WB5 <> ED4B(LN) then
          errmsg(1013,ED4B(LN),WB5);
        endif;
      endif;
    endif;

    { If ever attended school }
    if WB3 = 1 then
      { Check highest level and grade consistent }
      lev = WB4;
      grd = WB5;
      recode lev  : grd         => err; { Fix maximum grade for each possible level }
                  : 97,98,99    => 0;   { Inconsistent, missing, DK grade }
                0 : 0-4         => 0;   { Preschool}
                1 : 0-6         => 0;   { Primary }
                2 : 0-6         => 0;   { Secondary }
                3 : 0-5         => 0;   { Higher }
                6 : 0-6         => 0;   { Non-standard curriculum }
                8 :             => 0;   { DK level }
                9 :             => 0;   { Missing level }
                  :             => 1;
      endrecode;
      if err then
        errmsg(1014,WB4,WB5);
      endif;
    endif;

    { CHILD MORTALITY MODULE }

    { If ever given birth }
    if CM1 = 1 then

      { Check date of first birth against mother's age }
      ldobfc = ldob + minab;
      udobfc = diwm;
      if CM2Y < 9997 then
        ldobfc = setlb(CM2M,CM2Y,0);
        udobfc = setub(CM2M,CM2Y,9999);
        if udobfc < ldob + minab then
          errmsg(1101,CM2M,CM2Y,int(minab/12));
        elseif ldobfc > diwm then
          errmsg(1102,CM2M,CM2Y,WM6M,WM6Y);
        endif;
      endif;

      { Check years since first birth against age }
      if CM2Y > 9996 and WB2 - CM3 < (minab/12) then
        errmsg(1103,minab/12,WB2,CM3);
      endif;

      { Check for at least one child living at home - otherwise CM4 must be 2 }
      if CM4 = 1 and CM5A = 0 and CM5B = 0 then
        errmsg(1110,"CM4=","CM5A+CM5B");
      endif;

      { Check for at least one child living away - otherwise CM6 must be 2 }
      if CM6 = 1 and CM7A = 0 and CM7B = 0 then
        errmsg(1110,"CM6=","CM7A+CM7B");
      endif;

      { Check for at least one child who died - otherwise CM8 must be 2 }
      if CM8 = 1 and CM9A = 0 and CM9B = 0 then
        errmsg(1110,"CM8=","CM9A+CM9B");
      endif;

      { Check count of children ever born with total }
      x = NAtoZero(CM5A)+NAtoZero(CM5B)+
          NAtoZero(CM7A)+NAtoZero(CM7B)+
          NAtoZero(CM9A)+NAtoZero(CM9B);
      if x <> CM10 then
        errmsg(1111,CM10,x);
      elseif CM10 = 0 then
        errmsg(1110,"CM4+CM6+CM8>=","CM10");
      endif;

      { Check date of last birth against mother's age }
      ldoblc = ldobfc;
      udoblc = diwm;
      if CM12Y < 9997 then
        ldoblc = setlb(CM12M,CM12Y,0);
        udoblc = setub(CM12M,CM12Y,9999);
        if udoblc < ldob + minab then
          errmsg(1121,CM12M,CM12Y,int(minab/12));
        elseif ldoblc > diwm then
          errmsg(1122,CM12M,CM12Y,WM6M,WM6Y);
        endif;
      endif;

      { Check date of first birth against date of last birth }
      if CM10 = 1 then
        if (CM12Y <> CM2Y or CM12M <> CM2M ) then
          errmsg(1123,CM2M,CM2Y,CM12M,CM12Y);
        endif;
      else
        if ldobfc > udoblc then
          errmsg(1124,CM12M,CM12Y,CM2M,CM2Y);
        endif;
      endif;

      { Check if birth in last 24 months }
      { Note use of parentheses for correct check }
      if CM12Y = WM6Y or CM12Y = WM6Y-1 or (CM12Y = WM6Y-2 and
       (CM12M > WM6M and CM12M <= 12)) then
        if CM13 <> "Y" and CM13 <> "O" and CM13 <> "S"  then
          errmsg(1131,CM12M,CM12Y,WM6D,WM6M,WM6Y,CM13);
        endif;
      else
        if CM13 <> "N" then
          errmsg(1132,CM12M,CM12Y,WM6D,WM6M,WM6Y,CM13);
        endif;
      endif;
    endif;

    { TETANUS TOXOID MODULE }

    if frstrun then
      { Check years since last TT injection against age }
      if valid(MN11) and WB2-MN11 < (minab/12) then
        errmsg(1201,MN11,minab/12,WB1M,WB1Y,WB2);
      endif;
    endif;

    { MATERNAL AND NEWBORN HEALTH MODULE }

    { Check special answers }
    if MN21 = 1 and (MN22A = 9 <=> MN22 < 9997) then
      errmsg(1301,MN22A,MN22);
    endif;

    { Check consistency between units and numbers }
    if MN24 = 1 then
      recode MN25U  : MN25N       => err;
                0   : 0           => 0;   { Immediately }
                1   : 0-23        => 0;   { Hours }
                2   : 1-90        => 0;   { Days }
                9   : 98-99       => 0;   { DK, Missing }
                    :             => 1;
      endrecode;
      if err then
        errmsg(9992,"MN25U",MN25U,"MN25N",MN25N);
      endif;
    endif;

    { MARRIAGE/UNION MODULE }

    { Check woman at least 0 and 4 when married (minam=min. age at marriage) }
    if frstrun then
      if MA8Y < 9996 and WB1Y < 9996 then
        if valid(MA8M) and valid(WB1M) then
          if cmcode(MA8M,MA8Y) - cmcode(WB1M,WB1Y) < 0 then
            errmsg(1401,WB1M,WB1Y,MA8M,MA8Y,0);
          elseif cmcode(MA8M,MA8Y) - cmcode(WB1M,WB1Y) < minam then
            errmsg(1401,WB1M,WB1Y,MA8M,MA8Y,minam/12);
          endif;
        else
          if MA8Y - WB1Y < 0 then
            errmsg(1401,WB1M,WB1Y,MA8M,MA8Y,0);
          elseif MA8Y - WB1Y < int(minam/12)-1 then
            errmsg(1401,WB1M,WB1Y,MA8M,MA8Y,minam/12);
          endif;
        endif;
      endif;
    endif;

    { Check date of first marriage consistent with age at first marriage }
    if MA8Y < 9997 and valid(MA9) then
      ldofm = setlb(1,MA8Y,0);
      udofm = setub(12,MA8Y,9999);
      { Lower bound of CMC date of first marriage }
      t = adjlba(ldob,udob,ldofm,udofm,MA9);
      if t < 0 then
        errmsg(1403,MA9,MA8M,MA8Y,WB1M,WB1Y);
      endif;
      { Upper bound of CMC date of first marriage }
      t = adjuba(ldob,udob,ldofm,udofm,MA9);
      if t < 0 then
        errmsg(1403,MA9,MA8M,MA8Y,WB1M,WB1Y);
      endif;
    endif;

    { Check age at first marriage against age }
    if valid(MA9) and MA9 > WB2 then
      errmsg(1404,MA9,WB2);
    endif;

    { CONTRACEPTION MODULE }

    { Check units and number consistent }
    if UN6 = 1 then
      recode UN7U  : UN7N       => err;
                1,2 : 0-90        => 0;   { Months, Years }
                9   : 93-96,98,99 => 0;   { Special, DK, Missing }
                    :             => 1;
      endrecode;
      if err then
        errmsg(9992,"UN7U",UN7U,"UN7N",UN7N);
      endif;
    endif;

    { FEMALE GENITAL CUTTING MODULE }

    { Check number of daughters consistent with number of living daughters in CM module}
    if FG9 > NAtoZero(CM5B)+NAtoZero(CM7B) then
      errmsg(1602,FG9,NAtoZero(CM5B)+NAtoZero(CM7B));
    endif;

    { Check daughter's age at circumcision consistent with woman's age }

    i = 1;
    while i <= noccurs(MODFC_EDT) do {loop through the FGM module }
      if valid(FG13(i)) and FG13(i) + (minab/12) > WB2 then
        errmsg(1601,WB2,minab/12,FG13(i));
      endif;
      i = i + 1;
    enddo;

    { SEXUAL BEHAVIOUR MODULE }

    { Check age at first sex not greater than current age }
    if SB1 < 95 and SB1 > WB2 then
      errmsg(1801,SB1,WB2);
    endif;

    if SB1 <> notappl and SB1 <> 0 then
      { Check units and number consistent }
      recode  SB3U  : SB3N        => err;
                 1  : 0-6         => 0;   { Days }
                 2  : 1-4         => 0;   { Weeks }
                 3  : 1-11        => 0;   { Months }
                 4  : 1-37        => 0;   { Years }
                 9  : 97-99       => 0;   { Inconsistent, DK, Missing }
                    :             => 1;
      endrecode;
      if err then
        errmsg(9992,"SB3U",SB3U,"SB3N",SB3N);
      endif;
    endif;

    { Compare maximum age at last sex to age at first intercourse }
    if SB1 < 95 and SB3U = 4 and WB2-SB3N < SB1 then
      errmsg(1802,WB2-SB3N,SB1);
    endif;

  endif; { END WOMEN'S INTERVIEW COMPLETE }


{{MM}
{ Maternal Mortality }
PROC MODMM_EDT
  swrt = 0;
  aold = 100;
  iold = 0;
  if MM3 = 0 then
    aold = WB2;
  endif;
  aoldest = aold;

  for i in $ do
    anew = aold;

    if MM6 = 1 then           { sibling is still alive }
      if valid(MM7) then      { sibling's age is valid }
        anew = MM7;
      endif
    elseif MM6 = 2 then       { sibling has died }
      if valid(MM9) then      { age when they died }
        anew = MM9;
        if valid(MM8) then    { how many yrs ago did they die }
          anew = anew + MM8
        endif;
      elseif valid(MM8) then  { # yrs ago when they died }
        anew = MM8            { Age would be at least this, probably more }
      endif;
    endif;

    if anew > aold then
      errmsg( 9000, i, anew, iold, aold );
      swrt = 1;
    elseif valid(MM7) | valid(MM8) & valid(MM9) then
      aold = anew;
      iold = i;
    endif;

    if MM3 = i then            { Check respondent against siblings }
      if WB2 > aold then
        errmsg( 9000, 0, WB2, iold, aold );
        swrt = 1;
      else
        aold = WB2;
        anew = WB2;
        iold = 0;
      endif;
    endif;

    if aoldest = 100 then
      aoldest = aold;
    endif;

  enddo;

  if MM1 > 1 and (aoldest - aold) > 30 then
    errmsg( 9001, aoldest, aold )
  endif;
  errmsg("MM1 = %d and MM3 = %d",MM1,MM3);
  if swrt then
    write( "" );
    write( "    Cluster %03d    Household %03d      Woman's Line %02d", HH1, HH2, LN );
    write( " " );
    write( "    Maternal mortality: Total ever born in       MM1: %2d",MM1);
    write( "                        Older than respondent in MM3: %2d",MM3);
    write( "                        Age of respondent in     WB2: %2d",WB2);
    write( " " );
    write( "                      Years     Age                 At      Within   Children ");
    write( "    Sex  Alive  Age    ago    at death   Pregnant  birth   2 months  ever born");
    write( "    MM5   MM6   MM7    MM8      MM9        MM10    MM11       MM12      MM13"  );
    write( "    __________________________________________________________________________");
    for j in $ do
      write("   %3d  %3d     %02d     %02d       %02d         %3d     %3d       %3d        %02d",
                  MM5, MM6, MM7, MM8, MM9, MM10, MM11, MM12, MM13 );
    enddo;
    write( "    __________________________________________________________________________");
    write( "" );
    write( "" );
  endif;
{MM}}


{ ****---------------------------------------------------------------------------------------------**** }


{ Man's Questionniare }

{ Man's Information panel }

{ Check date of interview }
if MWM6D <> notappl then
recode MWM6Y   :    MWM6M        : MWM6D => err;
     2012-2015 : 1,3,5,7,8,10,12 : 1-31  => 0;
     2012-2015 : 4,6,9,11        : 1-30  => 0;
     2012-2015 : 2               : 1-28  => 0;
          2012 : 2               : 1-29  => 0;
               :                 :       => 1;
  endrecode;
  if err then
     {+EN} errmsg(0016,"Man's",MWM6D,MWM6M,MWM6Y);       {EN+}
     {{ES} errmsg(0016,"ES",MWM6D,MWM6M,MWM6Y);          {ES}}
     {{FR} errmsg(0016,"de la homme",MWM6D,MWM6M,MWM6Y); {FR}}
  endif;
  dd = (HH5Y*100 + HH5M)*100 + HH5D;
  ddm= (MWM6Y*100 + MWM6M)*100 + MWM6D;
  ss = sysdate("yyyymmdd");
  if ddm >= ss or ddm < dd then
    {+EN} errmsg(0016,"Man's",MWM6D,MWM6M,MWM6Y);{EN+}
    {{ES} errmsg(0016,"ES",MWM6D,MWM6M,MWM6Y); {ES}}
    {{FR} errmsg(0016,"de la homme",MWM6D,MWM6M,MWM6Y); {FR}}
  endif;
  dimm = cmcode(MWM6M,MWM6Y);
endif;

{ IF MEN'S INTERVIEW COMPLETE }
if MWM7 = 1 then

  { Check date of birth against date of interview }
  udob = dimm - mminage*12;
  ldob = dimm - mmaxage*12 - 11;
  if MWB1Y < 9997 then
    ldob = setlb(MWB1M,MWB1Y,0);
    udob = setub(MWB1M,MWB1Y,9999);
    if udob < dimm - mmaxage*12 - 11 or ldob > dimm - mminage*12 then
      if (MWM6M = MWB1M) and (MWB1Y - 50 = MWM6Y) then
        if frstrun then
          errmsg(3001,MWM6M,MWM6Y,MWB1M,MWB1Y);
        endif;
      else
        errmsg(3001,MWM6M,MWM6Y,MWB1M,MWB1Y);
      endif;
    endif;
  endif;

  { Check age against age in household }
  if frstrun and MWB2 <> HL6(MWM4) then
    errmsg(3002,MWB2,HL6(LN));
  endif;

  { Check age, date of birth and date of interview }
  { Lower bound of CMC date of birth }
  t = adjlba(ldob,udob,dimm,dimm,MWB2);
  if t < 0 then
    if (MWM6M = MWB1M) and (MWB1Y - MWM6Y = MWB2 + 1) then
      if frstrun then
        errmsg(3003,MWB2,MWB1M,MWB1Y,MWM6M,MWM6Y);
      endif;
    else
      errmsg(3003,MWB2,MWB1M,MWB1Y,MWM6M,MWM6Y);
    endif;
  else
    ldob = t
  endif;
  { Upper bound of CMC date of birth }
  t = adjuba(ldob,udob,dimm,dimm,MWB2);
  if t < 0 then
    if (MWM6M = MWB1M) and (MWB1Y - MWM6Y = MWB2 + 1) then
      if frstrun then
        errmsg(3003,MWB2,MWB1M,MWB1Y,MWM6M,MWM6Y);
      endif;
    else
      errmsg(3003,MWB2,MWB1M,MWB1Y,MWM6M,MWM6Y);
    endif;
  else
    udob = t
  endif;

  if frstrun then
    { Check school attendance against value in household }
    { Check ...
    if MWB3 <> ED3(LN) and ED4(LN) <> 0 then
      errmsg(3011,ED3(LN),MWB3);
    endif;
    ... }

    { If ever attended school }
    if MWB3 = 1 then
      { Check highest level against value in household }
      if MWB4 <> ED4A(LN) then
        errmsg(3012,ED4A(LN),MWB4);
      endif;

      { Check highest grade against value in household }
      if MWB5 <> ED4B(LN) then
        errmsg (3013,ED4B(LN),MWB5);
      endif;
    endif;
  endif;

  { If ever attended school }
  if MWB3 = 1 then
    { Check highest level and grade consistent }
    mlev = MWB4;
    mgrd = MWB5;
    recode mlev  : mgrd        => err; { Fix maximum grade for each possible level }
                 : 97,98,99    => 0;   { Inconsistent, missing, DK grade }
               0 : 0-4         => 0;   { Preschool}
               1 : 0-6         => 0;   { Primary }
               2 : 0-6         => 0;   { Secondary }
               3 : 0-5         => 0;   { Higher }
               6 : 0-6         => 0;   { Non-standard curriculum }
               8 :             => 0;   { DK level }
               9 :             => 0;   { Missing level }
                 :             => 1;
    endrecode;
    if err then
      errmsg(3014,MWB4,MWB5);
    endif;
  endif;

  { CHILD MORTALITY MODULE }

  { If ever fathered any children }
  if MCM1 = 1 then

   { Check years since first birth against age }
    if MWB2 - MCM3 < (mminab/12) then
      errmsg(3103,mminab/12,MWB2,MCM3);
    endif;

    { Check for at least one child living at home - otherwise CM4 must be 2 }
    if MCM4 = 1 and MCM5A = 0 and MCM5B = 0 then
      errmsg(3110,"MCM4=","MCM5A+MCM5B");
    endif;

    { Check for at least one child living away - otherwise CM6 must be 2 }
    if MCM6 = 1 and MCM7A = 0 and MCM7B = 0 then
      errmsg(3110,"MCM6=","MCM7A+MCM7B");
    endif;

    { Check for at least one child who died - otherwise CM8 must be 2 }
    if MCM8 = 1 and MCM9A = 0 and MCM9B = 0 then
      errmsg(3110,"MCM8=","MCM9A+MCM9B");
    endif;

    { Check count of children ever fathered with total }
    x = NAtoZero(MCM5A)+NAtoZero(MCM5B)+
        NAtoZero(MCM7A)+NAtoZero(MCM7B)+
        NAtoZero(MCM9A)+NAtoZero(MCM9B);
    if x <> MCM10 then
      errmsg(3111,MCM10,x);
    elseif MCM10 = 0 then
      errmsg(3110,"CM4+CM6+CM8>=","CM10");
    endif;

    { Check date of last birth against mother's age }
    ldoblc = ldobfc;
    udoblc = dimm;
    if MCM12Y < 9997 then
      ldoblc = setlb(MCM12M,MCM12Y,0);
      udoblc = setub(MCM12M,MCM12Y,9999);
      if udoblc < ldob + mminab then
        errmsg(3121,MCM12M,MCM12Y,int(mminab/12));
      elseif ldoblc > dimm then
        errmsg(3122,MCM12M,MCM12Y,MWM6M,MWM6Y);
      endif;
    endif;

  endif;

  { MARRIAGE/UNION MODULE }

  { Check man at least 0 and 4 when married (mminam=min. age at marriage) }
  if frstrun then
    if MMA8Y < 9996 and MWB1Y < 9996 then
      if valid(MMA8M) and valid(MWB1M) then
        if cmcode(MMA8M,MMA8Y) - cmcode(MWB1M,MWB1Y) < 0 then
          errmsg(3401,MWB1M,MWB1Y,MMA8M,MMA8Y,0);
        elseif cmcode(MMA8M,MMA8Y) - cmcode(MWB1M,MWB1Y) < mminam then
          errmsg(3401,MWB1M,MWB1Y,MMA8M,MMA8Y,mminam/12);
        endif;
      else
        if MMA8Y - MWB1Y < 0 then
          errmsg(3401,MWB1M,MWB1Y,MMA8M,MMA8Y,0);
        elseif MMA8Y - MWB1Y < int(mminam/12)-1 then
          errmsg(3401,MWB1M,MWB1Y,MMA8M,MMA8Y,mminam/12);
        endif;
      endif;
    endif;
  endif;

  { Check date of first marriage consistent with age at first marriage }
  if MMA8Y < 9997 and valid(MMA9) then
    ldofm = setlb(1,MMA8Y,0);
    udofm = setub(12,MMA8Y,9999);
    { Lower bound of CMC date of first marriage }
    t = adjlba(ldob,udob,ldofm,udofm,MMA9);
    if t < 0 then
      errmsg(3403,MMA9,MMA8M,MMA8Y,MWB1M,MWB1Y);
    endif;

    { Upper bound of CMC date of first marriage }
    t = adjuba(ldob,udob,ldofm,udofm,MMA9);
    if t < 0 then
      errmsg(3403,MMA9,MMA8M,MMA8Y,MWB1M,MWB1Y);
    endif;
  endif;

  { Check age at first marriage against age }
  if valid(MMA9) and MMA9 > MWB2 then
    errmsg(3404,MMA9,MWB2);
  endif;


  { SEXUAL BEHAVIOUR MODULE }

  { Check age at first sex not greater than current age }
  if MSB1 < 95 and MSB1 > MWB2 then
    errmsg(3801,MSB1,MWB2);
  endif;

  if MSB1 <> notappl and MSB1 <> 0 then
    { Check units and number consistent }
    recode  MSB3U  : MSB3N        => err;
                1  : 0-6         => 0;   { Days }
                2  : 1-4         => 0;   { Weeks }
                3  : 1-11        => 0;   { Months }
                4  : 1-37        => 0;   { Years }
                9  : 97-99       => 0;   { Inconsistent, DK, Missing }
                   :             => 1;
    endrecode;
    if err then
      errmsg(9992,"MSB3U",MSB3U,"MSB3N",MSB3N);
    endif;
  endif;

  { Compare maximum age at last sex to age at first intercourse }
  if MSB1 < 95 and MSB3U = 4 and MWB2-SB3N < MSB1 then
    errmsg(3802,MWB2-MSB3N,MSB1);
  endif;

endif; { END MEN'S INTERVIEW COMPLETE }


{ CHILDREN'S QUESTIONNAIRE }

{ UNDER-FIVE CHILD INFORMATION PANEL }

{ Check caretaker's line number against value in household}
{ Check...
if UF6 <> notappl and HL9(LN) <> UF6 then
  errmsg(2004,UF6,LN,HL9(LN));
endif;
...}

{ Check date of interview consistent }
if UF8D <> notappl then
  recode  UF8Y  :     UF8M        : UF8D => err;
      2012-2015 : 1,3,5,7,8,10,12 : 1-31 => 0;
      2012-2015 : 4,6,9,11        : 1-30 => 0;
      2012-2015 : 2               : 1-28 => 0;
           2012 : 2               : 1-29 => 0;
                :                 :      => 1;
  endrecode;
  if err then
    {+EN} errmsg(0016,"Child's",UF8D,UF8M,UF8Y);   {EN+}
    {{ES} errmsg(0016,"ES",UF8D,UF8M,UF8Y);        {ES}}
    {{FR} errmsg(0016,"de l'enfant",UF8D,UF8M,UF8Y); {FR}}
  endif;
  dd = (HH5Y*100 + HH5M)*100 + HH5D;
  ddw= (UF8Y*100 + UF8M)*100 + UF8D;
  ss = sysdate("yyyymmdd");
  if ddw >= ss or ddw < dd then
    {+EN} errmsg(0016,"Child's",UF8D,UF8M,UF8Y);   {EN+}
    {{ES} errmsg(0016,"ES",UF8D,UF8M,UF8Y);        {ES}}
    {{FR} errmsg(0016,"de l'enfant",UF8D,UF8M,UF8Y); {FR}}
  endif;
  dich = cmcode(UF8M,UF8Y);
endif;

{ IF CHILD'S INTERVIEW COMPLETE }
if UF9 = 1 then

  { Check date of birth consistent with date of interview }
  udob = dich;
  ldob = dich - chhlth*12 - 11;
  if AG1Y < 9997 then
    ldob = setlb(AG1M,AG1Y,0);
    udob = setub(AG1M,AG1Y,9999);
    if udob < dich - chhlth*12 - 11 or ldob > dich then
      if (UF8M = AG1M) and (UF8Y - 5 = AG1Y) then
        { Do nothing if DOB valid given day }
        if valid(AG1d) and UF8D <= AG1D then
        { Error if DOB invalid given day }
        elseif valid(UF8D) and UF8D > AG1D then
          errmsg(2001,AG1M,AG1Y,UF8M,UF8Y);
        { If impossible to verify DOB since UF8D invalid, warn on first run }
        elseif !valid(UF8D) and frstrun then
          errmsg(2001,AG1M,AG1Y,UF8M,UF8Y);
        endif;
      else
        errmsg(2001,AG1M,AG1Y,UF8M,UF8Y);
      endif;
    endif;
  endif;

  { Check age consistent with value in household }
  if frstrun and AG2 <> HL6(UF4) then
    errmsg(2002,AG2,HL6(LN));
  endif;

  { Check age, date of birth and date of interview consistent }
  { If day, month and year of birth are valid }
  if valid(AG1D) and valid(AG1M) and AG1Y < 9997 then
    if (AG1M = UF8M and AG1D > UF8D) | (AG1M > UF8M) then
      age = UF8Y - AG1Y - 1;
    else
      age = UF8Y - AG1Y;
    endif;
    if age <> AG2 then
      errmsg(2003,AG2,AG1D,AG1M,AG1Y,UF8D,UF8M,UF8Y);
    endif;
  else
    { Lower bound of CMC date of birth }
    t = adjlba(ldob,udob,dich,dich,AG2);
    if t < 0 then
      if (UF8M = AG1M) and (UF8Y - 5 = AG1Y) then
        if frstrun then
          errmsg(2003,AG2,AG1D,AG1M,AG1Y,UF8D,UF8M,UF8Y);
        endif;
      else
        errmsg(2003,AG2,AG1D,AG1M,AG1Y,UF8D,UF8M,UF8Y);
      endif;
    else
      ldob = t
    endif;
    { Upper bound of CMC date of birth }
    t = adjuba(ldob,udob,dich,dich,AG2);
    if t < 0 then
      if (UF8M = AG1M) and (UF8Y - 5 = AG1Y) then
        if frstrun then
          errmsg(2003,AG2,AG1D,AG1M,AG1Y,UF8D,UF8M,UF8Y);
        endif;
      else
        errmsg(2003,AG2,AG1D,AG1M,AG1Y,UF8D,UF8M,UF8Y);
      endif;
    else
      udob = t
    endif;
  endif;

  { IMMUNIZATION MODULE }

  if IM1 = 1 then
    { Check BCG }
    if vdvalid(IM3BD,IM3BM,IM3BY) then
      errmsg(2701,"BCG",IM3BD,IM3BM,IM3BY);
    elseif vdoi(IM3BD,IM3BM,IM3BY) then
      errmsg(2702,"BCG",IM3BD,IM3BM,IM3BY,UF8D,UF8M,UF8Y);
    elseif vdob(IM3BD,IM3BM,IM3BY) then
      errmsg(2703,"BCG",IM3BD,IM3BM,IM3BY,AG1D,AG1M,AG1Y);
    endif;

    { Check Polio at birth }
    if vdvalid(IM3P0D,IM3P0M,IM3P0Y) then
      errmsg(2701,"Polio at birth",IM3P0D,IM3P0M,IM3P0Y);
    elseif vdoi(IM3P0D,IM3P0M,IM3P0Y) then
      errmsg(2702,"Polio at birth",IM3P0D,IM3P0M,IM3P0Y,UF8D,UF8M,UF8Y);
    elseif vdob(IM3P0D,IM3P0M,IM3P0Y) then
      errmsg(2703,"Polio at birth",IM3P0D,IM3P0M,IM3P0Y,AG1D,AG1M,AG1Y);
    endif;

    { Check Polio 1 }
    if vdvalid(IM3P1D,IM3P1M,IM3P1Y) then
      errmsg(2701,"Polio 1",IM3P1D,IM3P1M,IM3P1Y);
    elseif vdoi(IM3P1D,IM3P1M,IM3P1Y) then
      errmsg(2702,"Polio 1",IM3P1D,IM3P1M,IM3P1Y,UF8D,UF8M,UF8Y);
    elseif vdob(IM3P1D,IM3P1M,IM3P1Y) then
      errmsg(2703,"Polio 1",IM3P1D,IM3P1M,IM3P1Y,AG1D,AG1M,AG1Y);
    endif;

    { Check Polio 1 after Polio 0 }
    if vseq(IM3P0D,IM3P0M,IM3P0Y,IM3P1D,IM3P1M,IM3P1Y) then
      errmsg(2704,"Polio 0",IM3P0D,IM3P0M,IM3P0Y,"Polio 1",IM3P1D,IM3P1M,IM3P1Y);
    endif;

    { Check Polio 1 and DPT1 on same date }
    if frstrun and vmatch(IM3P1D,IM3P1M,IM3P1Y,IM3D1D,IM3D1M,IM3D1Y) then
      errmsg(2705,"Polio 1",IM3P1D,IM3P1M,IM3P1Y,"DPT1",IM3D1D,IM3D1M,IM3D1Y);
    endif;

    { Check Polio 2 }
    if vdvalid(IM3P2D,IM3P2M,IM3P2Y) then
      errmsg(2701,"Polio 2",IM3P2D,IM3P2M,IM3P2Y);
    elseif vdoi(IM3P2D,IM3P2M,IM3P2Y) then
      errmsg(2702,"Polio 2",IM3P2D,IM3P2M,IM3P2Y,UF8D,UF8M,UF8Y);
    elseif vdob(IM3P2D,IM3P2M,IM3P2Y) then
      errmsg(2703,"Polio 2",IM3P2D,IM3P2M,IM3P2Y,AG1D,AG1M,AG1Y);
    endif;

    { Check Polio 2 after Polio 0 }
    if vseq(IM3P0D,IM3P0M,IM3P0Y,IM3P2D,IM3P2M,IM3P2Y) then
      errmsg(2704,"Polio 0",IM3P0D,IM3P0M,IM3P0Y,"Polio 2",IM3P2D,IM3P2M,IM3P2Y);

    endif;
    { Check Polio 2 after Polio 1 }
    if vseq(IM3P1D,IM3P1M,IM3P1Y,IM3P2D,IM3P2M,IM3P2Y) then
      errmsg(2704,"Polio 1",IM3P1D,IM3P1M,IM3P1Y,"Polio 2",IM3P2D,IM3P2M,IM3P2Y);
    endif;
    { Check Polio 2 and DPT2 on same date }
    if frstrun and vmatch(IM3P2D,IM3P2M,IM3P2Y,IM3D2D,IM3D2M,IM3D2Y) then
      errmsg(2705,"Polio 2",IM3P2D,IM3P2M,IM3P2Y,"DPT2",IM3D2D,IM3D2M,IM3D2Y);
    endif;

    { Check Polio 3 }
    if vdvalid(IM3P3D,IM3P3M,IM3P3Y) then
      errmsg(2701,"Polio 3",IM3P3D,IM3P3M,IM3P3Y);
    elseif vdoi(IM3P3D,IM3P3M,IM3P3Y) then
      errmsg(2702,"Polio 3",IM3P3D,IM3P3M,IM3P3Y,UF8D,UF8M,UF8Y);
    elseif vdob(IM3P3D,IM3P3M,IM3P3Y) then
      errmsg(2703,"Polio 3",IM3P3D,IM3P3M,IM3P3Y,AG1D,AG1M,AG1Y);
    endif;
    { Check Polio 3 after Polio 0 }
    if vseq(IM3P0D,IM3P0M,IM3P0Y,IM3P3D,IM3P3M,IM3P3Y) then
      errmsg(2704,"Polio 0",IM3P0D,IM3P0M,IM3P0Y,"Polio 3",IM3P3D,IM3P3M,IM3P3Y);
    endif;
    { Check Polio 3 after Polio 1 }
    if vseq(IM3P1D,IM3P1M,IM3P1Y,IM3P3D,IM3P3M,IM3P3Y) then
      errmsg(2704,"Polio 1",IM3P1D,IM3P1M,IM3P1Y,"Polio 3",IM3P3D,IM3P3M,IM3P3Y);
    endif;
    { Check Polio 3 after Polio 2 }
    if vseq(IM3P2D,IM3P2M,IM3P2Y,IM3P3D,IM3P3M,IM3P3Y) then
      errmsg(2704,"Polio 2",IM3P2D,IM3P2M,IM3P2Y,"Polio 3",IM3P3D,IM3P3M,IM3P3Y);
    endif;
    { Check Polio 3 and DPT3 on same date }
    if frstrun and vmatch(IM3P3D,IM3P3M,IM3P3Y,IM3D3D,IM3D3M,IM3D3Y) then
      errmsg(2705,"Polio 3",IM3P3D,IM3P3M,IM3P3Y,"DPT3",IM3D3D,IM3D3M,IM3D3Y);
    endif;

    { Check DPT1 }
    if vdvalid(IM3D1D,IM3D1M,IM3D1Y) then
      errmsg(2701,"DPT1",IM3D1D,IM3D1M,IM3D1Y);
    elseif vdoi(IM3D1D,IM3D1M,IM3D1Y) then
      errmsg(2702,"DPT1",IM3D1D,IM3D1M,IM3D1Y,UF8D,UF8M,UF8Y);
    elseif vdob(IM3D1D,IM3D1M,IM3D1Y) then
      errmsg(2703,"DPT1",IM3D1D,IM3D1M,IM3D1Y,AG1D,AG1M,AG1Y);
    endif;
    { Check DPT1 and HepB1 on same date }
    if frstrun and vmatch(IM3D1D,IM3D1M,IM3D1Y,IM3H1D,IM3H1M,IM3H1Y) then
      errmsg(2705,"DPT1",IM3D1D,IM3D1M,IM3D1Y,"HepB1",IM3H1D,IM3H1M,IM3H1Y);
    endif;

    { Check DPT2 }
    if vdvalid(IM3D2D,IM3D2M,IM3D2Y) then
      errmsg(2701,"DPT2",IM3D2D,IM3D2M,IM3D2Y);
    elseif vdoi(IM3D2D,IM3D2M,IM3D2Y) then
      errmsg(2702,"DPT2",IM3D2D,IM3D2M,IM3D2Y,UF8D,UF8M,UF8Y);
    elseif vdob(IM3D2D,IM3D2M,IM3D2Y) then
      errmsg(2703,"DPT2",IM3D2D,IM3D2M,IM3D2Y,AG1D,AG1M,AG1Y);
    endif;
    { Check DPT2 after DPT1 }
    if vseq(IM3D1D,IM3D1M,IM3D1Y,IM3D2D,IM3D2M,IM3D2Y) then
      errmsg(2704,"DPT1",IM3D1D,IM3D1M,IM3D1Y,"DPT3",IM3D2D,IM3D2M,IM3D2Y);
    endif;
    { Check DPT2 and HepB2 on same date }
    if frstrun and vmatch(IM3D2D,IM3D2M,IM3D2Y,IM3H2D,IM3H2M,IM3H2Y) then
      errmsg(2705,"DPT2",IM3D2D,IM3D2M,IM3D2Y,"HepB2",IM3H2D,IM3H2M,IM3H2Y);
    endif;

    { Check DPT3 }
    if vdvalid(IM3D3D,IM3D3M,IM3D3Y) then
      errmsg(2701,"DPT3",IM3D3D,IM3D3M,IM3D3Y);
    elseif vdoi(IM3D3D,IM3D3M,IM3D3Y) then
      errmsg(2702,"DPT3",IM3D3D,IM3D3M,IM3D3Y,UF8D,UF8M,UF8Y);
    elseif vdob(IM3D3D,IM3D3M,IM3D3Y) then
      errmsg(2703,"DPT3",IM3D3D,IM3D3M,IM3D3Y,AG1D,AG1M,AG1Y);
    endif;
    { Check DPT3 after DPT1 }
    if vseq(IM3D1D,IM3D1M,IM3D1Y,IM3D3D,IM3D3M,IM3D3Y) then
      errmsg(2704,"DPT1",IM3D1D,IM3D1M,IM3D1Y,"DPT3",IM3D3D,IM3D3M,IM3D3Y);
    endif;
    { Check DPT3 after DPT2 }
    if vseq(IM3D2D,IM3D2M,IM3D2Y,IM3D3D,IM3D3M,IM3D3Y) then
      errmsg(2704,"DPT2",IM3D2D,IM3D2M,IM3D2Y,"DPT3",IM3D3D,IM3D3M,IM3D3Y);
    endif;
    { Check DPT3 and HepB3 on same date }
    if frstrun and vmatch(IM3D3D,IM3D3M,IM3D3Y,IM3H3D,IM3H3M,IM3H3Y) then
      errmsg(2705,"DPT3",IM3D3D,IM3D3M,IM3D3Y,"HepB3",IM3H3D,IM3H3M,IM3H3Y);
    endif;

    { Check HepB1 }
    if vdvalid(IM3H1D,IM3H1M,IM3H1Y) then
      errmsg(2701,"HepB1",IM3H1D,IM3H1M,IM3H1Y);
    elseif vdoi(IM3H1D,IM3H1M,IM3H1Y) then
      errmsg(2702,"HepB1",IM3H1D,IM3H1M,IM3H1Y,UF8D,UF8M,UF8Y);
    elseif vdob(IM3H1D,IM3H1M,IM3H1Y) then
      errmsg(2703,"HepB1",IM3H1D,IM3H1M,IM3H1Y,AG1D,AG1M,AG1Y);
    endif;

    { Check HepB2 }
    if vdvalid(IM3H2D,IM3H2M,IM3H2Y) then
      errmsg(2701,"HepB2",IM3H2D,IM3H2M,IM3H2Y);
    elseif vdoi(IM3H2D,IM3H2M,IM3H2Y) then
      errmsg(2702,"HepB2",IM3H2D,IM3H2M,IM3H2Y,UF8D,UF8M,UF8Y);
    elseif vdob(IM3H2D,IM3H2M,IM3H2Y) then
      errmsg(2703,"HepB2",IM3H2D,IM3H2M,IM3H2Y,AG1D,AG1M,AG1Y);
    endif;
    { Check HepB2 after HepB1 }
    if vseq(IM3H1D,IM3H1M,IM3H1Y,IM3H2D,IM3H2M,IM3H2Y) then
      errmsg(2704,"HepB1",IM3H1D,IM3H1M,IM3H1Y,"HepB2",IM3H2D,IM3H2M,IM3H2Y);
    endif;

    { Check HepB3}
    if vdvalid(IM3H3D,IM3H3M,IM3H3Y) then
      errmsg(2701,"HepB3",IM3H3D,IM3H3M,IM3H3Y);
    elseif vdoi(IM3H3D,IM3H3M,IM3H3Y) then
      errmsg(2702,"HepB3",IM3H3D,IM3H3M,IM3H3Y,UF8D,UF8M,UF8Y);
    elseif vdob(IM3H3D,IM3H3M,IM3H3Y) then
      errmsg(2703,"HepB3",IM3H3D,IM3H3M,IM3H3Y,AG1D,AG1M,AG1Y);
    endif;
    { Check HepB3 after HepB1 }
    if vseq(IM3H1D,IM3H1M,IM3H1Y,IM3H3D,IM3H3M,IM3H3Y) then
      errmsg(2704,"HepB1",IM3H1D,IM3H1M,IM3H1Y,"HepB3",IM3H3D,IM3H3M,IM3H3Y);
    { Check HepB3 after HepB2 }
    endif;
    if vseq(IM3H2D,IM3H2M,IM3H2Y,IM3H3D,IM3H3M,IM3H3Y) then
      errmsg(2704,"HepB2",IM3H2D,IM3H2M,IM3H2Y,"HepB3",IM3H3D,IM3H3M,IM3H3Y);
    endif;

    { Check Measles }
    if vdvalid(IM3MD,IM3MM,IM3MY) then
      errmsg(2701,"Measles",IM3MD,IM3MM,IM3MY);
    elseif vdoi(IM3MD,IM3MM,IM3MY) then
      errmsg(2702,"Measles",IM3MD,IM3MM,IM3MY,UF8D,UF8M,UF8Y);
    elseif vdob(IM3MD,IM3MM,IM3MY) then
      errmsg(2703,"Measles",IM3MD,IM3MM,IM3MY,AG1D,AG1M,AG1Y);
    endif;

    { Check Yellow Fever }
    if vdvalid(IM3YD,IM3YM,IM3YY) then
      errmsg(2701,"Yellow Fever",IM3YD,IM3YM,IM3YY);
    elseif vdoi(IM3YD,IM3YM,IM3YY) then
      errmsg(2702,"Yellow Fever",IM3YD,IM3YM,IM3YY,UF8D,UF8M,UF8Y);
    elseif vdob(IM3YD,IM3YM,IM3YY) then
      errmsg(2703,"Yellow Fever",IM3YD,IM3YM,IM3YY,AG1D,AG1M,AG1Y);
    endif;

    { Check Vitamin A 1 }
   if vdvalid(IM3V1D,IM3V1M,IM3V1Y) then
      errmsg(2701,"Vitamin A (1)",IM3V1D,IM3V1M,IM3V1Y);
    elseif vdoi(IM3V1D,IM3V1M,IM3V1Y) then
      errmsg(2702,"Vitamin A (1)",IM3V1D,IM3V1M,IM3V1Y,UF8D,UF8M,UF8Y);
    elseif vdob(IM3V1D,IM3V1M,IM3V1Y) then
      errmsg(2703,"Vitamin A (1)",IM3V1D,IM3V1M,IM3V1Y,AG1D,AG1M,AG1Y);
    endif;
    
     { Check Vitamin A 2 }
   if vdvalid(IM3V2D,IM3V2M,IM3V2Y) then
      errmsg(2701,"Vitamin A (2)",IM3V2D,IM3V2M,IM3V2Y);
    elseif vdoi(IM3V2D,IM3V2M,IM3V2Y) then
      errmsg(2702,"Vitamin A (2)",IM3V2D,IM3V2M,IM3V2Y,UF8D,UF8M,UF8Y);
    elseif vdob(IM3V2D,IM3V2M,IM3V2Y) then
      errmsg(2703,"Vitamin A (2)",IM3V2D,IM3V2M,IM3V2Y,AG1D,AG1M,AG1Y);
    endif;

  endif;


  { Check receipt of vaccinations against recorded vaccinations }
  if frstrun then
    if IM1 = 1 and (IM3BD = 0 and
                    IM3P0D = 0 and IM3P1D = 0 and IM3P2D = 0 and IM3P3D = 0 and
                                   IM3D1D = 0 and IM3D2D = 0 and IM3D3D = 0 and
                    IM3H0D = 0 and IM3H1D = 0 and IM3H2D = 0 and IM3H3D = 0 and
                    IM3MD  = 0 and IM3YD  = 0) then
      errmsg(2706);
    endif;
  endif;

  { Check receipt of other vaccinations against recorded vaccinations }
  if frstrun and IM1 = 1 then
    if IM5 = 1 <=> (IM3BD  <> 66 and
                    IM3P0D <> 66 and IM3P1D <> 66 and IM3P2D <> 66 and IM3P3D <> 66 and
                                     IM3D1D <> 66 and IM3D2D <> 66 and IM3D3D <> 66 and
                    IM3H0D <> 66 and IM3H1D <> 66 and IM3H2D <> 66 and IM3H3D <> 66 and
                    IM3MD  <> 66 and IM3YD  <> 66) then
      errmsg(2707);
    endif;
  endif;

  { ANTHROPOMETRY MODULE }

  if frstrun then

   if AN2 = 1 then

    { Check weight }
    hwsex = HL4(UF4);
    hwage = dich - ldob;
    if hwsex = 1 then
      recode  hwage : AN3        => hwerr;
               0- 2 :  0.5- 10.0 => 0;
               3- 5 :  1.0- 13.0 => 0;
               6- 8 :  2.0- 15.0 => 0;
               9-11 :  3.0- 16.5 => 0;
              12-14 :  4.0- 17.5 => 0;
              15-17 :  4.0- 18.5 => 0;
              18-20 :  4.0- 19.5 => 0;
              21-23 :  4.5- 20.5 => 0;
              24-26 :  4.5- 23.0 => 0;
              27-29 :  5.0- 24.0 => 0;
              30-32 :  5.0- 24.5 => 0;
              33-35 :  5.0- 25.5 => 0;
              36-38 :  5.0- 26.0 => 0;
              39-41 :  5.0- 27.0 => 0;
              42-44 :  5.0- 29.0 => 0;
              45-47 :  5.0- 29.0 => 0;
              48-50 :  5.0- 30.0 => 0;
              51-53 :  5.0- 31.0 => 0;
              54-56 :  5.5- 32.0 => 0;
              57-60 :  5.5- 33.0 => 0;
              61-72 :  5.5- 34.0 => 0;
               0-72 :  99.9		 => 0;
                    :            => 1;
      endrecode
    else
      recode  hwage : AN3        => hwerr;
               0- 2 :  0.5-  9.0 => 0;
               3- 5 :  1.0- 12.0 => 0;
               6- 8 :  2.0- 14.0 => 0;
               9-11 :  2.5- 15.5 => 0;
              12-14 :  3.0- 16.5 => 0;
              15-17 :  3.5- 17.5 => 0;
              18-20 :  3.5- 18.5 => 0;
              21-23 :  4.0- 19.5 => 0;
              24-26 :  4.5- 21.5 => 0;
              27-29 :  5.0- 23.0 => 0;
              30-32 :  5.0- 24.5 => 0;
              33-35 :  5.0- 25.5 => 0;
              36-38 :  5.0- 27.0 => 0;
              39-41 :  5.0- 29.0 => 0;
              42-44 :  5.5- 29.0 => 0;
              45-47 :  5.5- 30.0 => 0;
              48-50 :  5.5- 31.0 => 0;
              51-53 :  5.5- 32.0 => 0;
              54-56 :  6.0- 33.0 => 0;
              57-60 :  6.0- 34.5 => 0;
              61-72 :  6.0- 36.0 => 0;
               0-72 :  99.9		 => 0;
                    :            => 1;
      endrecode
    endif;
    if hwerr then
      errmsg(2801,AN3)
    endif;

    { Check how child was measured against age }
    {if (hwage >= 24 and AN4A = 1) or (hwage < 24 and AN4A = 2) then}
    if hwage >= 24 <=> AN4A = 1 then
      errmsg(2803,hwage,AN4A)
    endif;

    { Check height }
    hwsex = HL4(UF4);
    hwage = dich - ldob;
    if hwsex = 1 then
      recode  hwage : AN4        => hwerr;
               0- 2 : 36.0- 74.0 => 0;
               3- 5 : 45.0- 83.0 => 0;
               6- 8 : 51.0- 87.0 => 0;
               9-11 : 56.0- 91.0 => 0;
              12-14 : 59.0- 96.0 => 0;
              15-17 : 62.0-100.0 => 0;
              18-20 : 64.0-104.0 => 0;
              21-23 : 65.0-107.0 => 0;
              24-26 : 67.0-109.0 => 0;
              27-29 : 69.0-112.0 => 0;
              30-32 : 70.0-115.0 => 0;
              33-35 : 71.0-119.0 => 0;
              36-38 : 73.0-121.0 => 0;
              39-41 : 74.0-124.0 => 0;
              42-44 : 75.0-127.0 => 0;
              45-47 : 77.0-129.9 => 0;
              48-50 : 79.0-132.0 => 0;
              51-53 : 79.0-134.0 => 0;
              54-56 : 90.0-136.0 => 0;
              57-60 : 82.0-139.0 => 0;
              61-72 : 82.0-140.0 => 0;
               0-72 : 999.9		 => 0;
                    :            => 1;
      endrecode
    else
      recode  hwage : AN4        => hwerr;
               0- 2 : 36.0- 72.0 => 0;
               3- 5 : 44.0- 90.0 => 0;
               6- 8 : 50.0- 86.0 => 0;
               9-11 : 54.0- 90.0 => 0;
              12-14 : 57.0- 95.0 => 0;
              15-17 : 60.0- 99.0 => 0;
              18-20 : 62.0-102.0 => 0;
              21-23 : 64.0-106.0 => 0;
              24-26 : 66.0-107.0 => 0;
              27-29 : 69.0-111.0 => 0;
              30-32 : 69.0-114.0 => 0;
              33-35 : 71.0-117.0 => 0;
              36-38 : 72.0-120.0 => 0;
              39-41 : 74.0-122.0 => 0;
              42-44 : 75.0-124.0 => 0;
              45-47 : 77.0-126.9 => 0;
              48-50 : 79.0-129.0 => 0;
              51-53 : 79.0-131.0 => 0;
              54-56 : 81.0-133.0 => 0;
              57-60 : 81.0-136.0 => 0;
              61-72 : 81.0-137.0 => 0;
               0-72 : 999.9		 => 0;
                    :            => 1;
      endrecode
    endif;
    if hwerr then
      errmsg(2802,AN4)
    endif;

    { Check z-scores against flags }
    birthd = AG1D; if AG1D >= 97 then birthd = missing endif;
    birthm = AG1M; if AG1M >= 97 then birthm = missing endif;
    birthy = AG1Y; if AG1Y >= 9997 then birthy = missing endif;
    age = agemth(birthd,birthm,birthy,UF8D,UF8M,UF8Y);
    if AN4 < 997.0 and age <> 9999 and (ZSFLAG in 1,3,5,7) then
      errmsg(2802,AN4);
    endif;
    if AN3 <  97.0 and age <> 9999 and (ZSFLAG in 4,5,6,7) then
      errmsg(2801,AN4);
    endif;
    if AN4 < 997.0 and AN3 < 97.0 and (ZSFLAG in 2,3,6,7) then
      errmsg(2804,AN4,AN3);
    endif;

   endif;

  endif; { End frstrun }

  { Check result of measurement against z-scores }
  {if (AN2  = 1 and (AN3 >= 97.0 or AN4 >= 997.0)) or
     (AN2 <> 1 and (AN3 <  97.0 and AN4 <  997.0)) then}
  if AN2  = 1 and (AN3 >= 97.0 and AN4 >= 997.0) then
    errmsg(2805,AN2,AN4,AN3);
  endif;

endif; { END CHILD'S INTERVIEW COMPLETE }
